@@ -3,8 +3,7 @@
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
-"""
-Bio.AlignIO support for the "nexus" file format.
+"""Bio.AlignIO support for the "nexus" file format.
 
 You are expected to use this module via the Bio.AlignIO functions (or the
 Bio.SeqIO functions if you want to work directly with the gapped sequences).
@@ -14,10 +13,12 @@ as this offers more than just accessing the alignment or its
 sequences as SeqRecord objects.
 """
 
+from __future__ import print_function
+
 from Bio.SeqRecord import SeqRecord
 from Bio.Nexus import Nexus
 from Bio.Align import MultipleSeqAlignment
-from Interfaces import AlignmentWriter
+from .Interfaces import AlignmentWriter
 from Bio import Alphabet
 
 #You can get a couple of example files here:
@@ -75,7 +76,7 @@ class NexusWriter(AlignmentWriter):
         """
         align_iter = iter(alignments)  # Could have been a list
         try:
-            first_alignment = align_iter.next()
+            first_alignment = next(align_iter)
         except StopIteration:
             first_alignment = None
         if first_alignment is None:
@@ -84,7 +85,7 @@ class NexusWriter(AlignmentWriter):
 
         #Check there is only one alignment...
         try:
-            second_alignment = align_iter.next()
+            second_alignment = next(align_iter)
         except StopIteration:
             second_alignment = None
         if second_alignment is not None:
@@ -99,7 +100,8 @@ class NexusWriter(AlignmentWriter):
         #and then gets Nexus to prepare the output.
         if len(alignment) == 0:
             raise ValueError("Must have at least one sequence")
-        if alignment.get_alignment_length() == 0:
+        columns = alignment.get_alignment_length()
+        if columns == 0:
             raise ValueError("Non-empty sequences are required")
         minimal_record = "#NEXUS\nbegin data; dimensions ntax=0 nchar=0; " \
                          + "format datatype=%s; end;"  \
@@ -108,7 +110,11 @@ class NexusWriter(AlignmentWriter):
         n.alphabet = alignment._alphabet
         for record in alignment:
             n.add_sequence(record.id, str(record.seq))
-        n.write_nexus_data(self.handle)
+        #For smaller alignments, don't bother to interleave.
+        #For larger alginments, interleave to avoid very long lines
+        #in the output - something MrBayes can't handle.
+        #TODO - Default to always interleaving?
+        n.write_nexus_data(self.handle, interleave=(columns > 1000))
 
     def _classify_alphabet_for_nexus(self, alphabet):
         """Returns 'protein', 'dna', 'rna' based on the alphabet (PRIVATE).
@@ -131,10 +137,10 @@ class NexusWriter(AlignmentWriter):
             raise ValueError("Need a DNA, RNA or Protein alphabet")
 
 if __name__ == "__main__":
-    from StringIO import StringIO
-    print "Quick self test"
-    print
-    print "Repeated names without a TAXA block"
+    from Bio._py3k import StringIO
+    print("Quick self test")
+    print("")
+    print("Repeated names without a TAXA block")
     handle = StringIO("""#NEXUS
     [TITLE: NoName]
 
@@ -151,13 +157,13 @@ if __name__ == "__main__":
     end; 
     """)
     for a in NexusIterator(handle):
-        print a
+        print(a)
         for r in a:
-            print repr(r.seq), r.name, r.id
-    print "Done"
+            print("%r %s %s" % (r.seq, r.name, r.id))
+    print("Done")
 
-    print
-    print "Repeated names with a TAXA block"
+    print("")
+    print("Repeated names with a TAXA block")
     handle = StringIO("""#NEXUS
     [TITLE: NoName]
 
@@ -181,21 +187,21 @@ if __name__ == "__main__":
     end; 
     """)
     for a in NexusIterator(handle):
-        print a
+        print(a)
         for r in a:
-            print repr(r.seq), r.name, r.id
-    print "Done"
-    print
-    print "Reading an empty file"
+            print("%r %s %s" % (r.seq, r.name, r.id))
+    print("Done")
+    print("")
+    print("Reading an empty file")
     assert 0 == len(list(NexusIterator(StringIO())))
-    print "Done"
-    print
-    print "Writing..."
+    print("Done")
+    print("")
+    print("Writing...")
 
     handle = StringIO()
     NexusWriter(handle).write_file([a])
     handle.seek(0)
-    print handle.read()
+    print(handle.read())
 
     handle = StringIO()
     try:
