@@ -12,6 +12,18 @@ This is used by sequences which contain a finite number of similar words.
 
 
 class Alphabet(object):
+    """Generic alphabet base class.
+
+    This class is used as a base class for other types of alphabets.
+
+    Attributes:
+    letters -- list-like object containing the letters of the alphabet.
+               Usually it is a string when letters are single characters.
+    size    -- size of the alphabet's letters (e.g. 1 when letters are
+               single characters).
+
+    """
+
     size = None     # default to no fixed size for words
     letters = None  # default to no fixed alphabet
                     # In general, a list-like object. However,
@@ -32,13 +44,13 @@ class Alphabet(object):
         return isinstance(other, self.__class__)
 
     def _case_less(self):
-        """Return an case-less variant of the current alphabet (PRIVATE)."""
+        """Return a case-less variant of the current alphabet (PRIVATE)."""
         #TODO - remove this method by dealing with things in subclasses?
         if isinstance(self, ProteinAlphabet):
             return generic_protein
         elif isinstance(self, DNAAlphabet):
             return generic_dna
-        elif isinstance(self, NucleotideAlphabet):
+        elif isinstance(self, RNAAlphabet):
             return generic_rna
         elif isinstance(self, NucleotideAlphabet):
             return generic_nucleotide
@@ -69,6 +81,7 @@ generic_alphabet = Alphabet()
 
 
 class SingleLetterAlphabet(Alphabet):
+    """Generic alphabet with letters of size one."""
     size = 1
     letters = None   # string of all letters in the alphabet
 
@@ -78,6 +91,7 @@ single_letter_alphabet = SingleLetterAlphabet()
 
 
 class ProteinAlphabet(SingleLetterAlphabet):
+    """Generic single letter protein alphabet."""
     pass
 
 generic_protein = ProteinAlphabet()
@@ -86,12 +100,14 @@ generic_protein = ProteinAlphabet()
 
 
 class NucleotideAlphabet(SingleLetterAlphabet):
+    """Generic single letter nucleotide alphabet."""
     pass
 
 generic_nucleotide = NucleotideAlphabet()
 
 
 class DNAAlphabet(NucleotideAlphabet):
+    """Generic single letter DNA alphabet."""
     pass
 
 generic_dna = DNAAlphabet()
@@ -101,6 +117,7 @@ generic_dna = DNAAlphabet()
 
 
 class RNAAlphabet(NucleotideAlphabet):
+    """Generic single letter RNA alphabet."""
     pass
 
 generic_rna = RNAAlphabet()
@@ -109,10 +126,15 @@ generic_rna = RNAAlphabet()
 
 
 class SecondaryStructure(SingleLetterAlphabet):
+    """Alphabet used to describe secondary structure.
+
+    Letters are 'H' (helix), 'S' (strand), 'T' (turn) and 'C' (coil).
+    """
     letters = "HSTC"
 
 
 class ThreeLetterProtein(Alphabet):
+    """Three letter protein alphabet."""
     size = 3
     letters = [
         "Ala", "Asx", "Cys", "Asp", "Glu", "Phe", "Gly", "His", "Ile",
