@@ -32,6 +32,8 @@ Camacho et al. BLAST+: architecture and applications
 BMC Bioinformatics 2009, 10:421
 doi:10.1186/1471-2105-10-421
 """
+from __future__ import print_function
+
 from Bio import BiopythonDeprecationWarning
 
 from Bio.Application import _Option, AbstractCommandline, _Switch
@@ -206,7 +208,7 @@ class BlastallCommandline(_BlastAllOrPgpCommandLine):
     ...                             database="nr", expectation=0.001)
     >>> cline
     BlastallCommandline(cmd='blastall', database='nr', infile='m_cold.fasta', expectation=0.001, program='blastx')
-    >>> print cline
+    >>> print(cline)
     blastall -d nr -i m_cold.fasta -e 0.001 -p blastx
 
     You would typically run the command line with cline() or via the Python
@@ -310,7 +312,7 @@ class BlastpgpCommandline(_BlastAllOrPgpCommandLine):
     >>> cline = BlastpgpCommandline(help=True)
     >>> cline
     BlastpgpCommandline(cmd='blastpgp', help=True)
-    >>> print cline
+    >>> print(cline)
     blastpgp --help
 
     You would typically run the command line with cline() or via the Python
@@ -379,7 +381,7 @@ class RpsBlastCommandline(_BlastCommandLine):
     With the release of BLAST+ (BLAST rewritten in C++ instead of C), the NCBI
     are replacing the old rpsblast with a new version of the same name plus a
     second tool rpstblastn, both taking different command line arguments. This
-    module provides NcbirpsblastCommandline and NcbirpsblasntCommandline as
+    module provides NcbirpsblastCommandline and NcbirpsblastCommandline as
     wrappers for the new tools.
 
     Like the old rpsblast (and blastall), this wrapper is now obsolete, and will
@@ -389,7 +391,7 @@ class RpsBlastCommandline(_BlastCommandLine):
     >>> cline = RpsBlastCommandline(help=True)
     >>> cline
     RpsBlastCommandline(cmd='rpsblast', help=True)
-    >>> print cline
+    >>> print(cline)
     rpsblast --help
 
     You would typically run the command line with cline() or via the Python
@@ -455,15 +457,15 @@ class _NcbibaseblastCommandline(AbstractCommandline):
                     "(differs from classic BLAST which used 7 for XML).",
                     equate=False),
                     #TODO - Document and test the column options
-            _Switch(["-show_gis","show_gis"],
+            _Switch(["-show_gis", "show_gis"],
                     "Show NCBI GIs in deflines?"),
-            _Option(["-num_descriptions","num_descriptions"],
+            _Option(["-num_descriptions", "num_descriptions"],
                     """Number of database sequences to show one-line descriptions for.
 
                     Integer argument (at least zero). Default is 500.
                     See also num_alignments.""",
                     equate=False),
-            _Option(["-num_alignments","num_alignments"],
+            _Option(["-num_alignments", "num_alignments"],
                     """Number of database sequences to show num_alignments for.
 
                     Integer argument (at least zero). Default is 200.
@@ -491,7 +493,7 @@ class _NcbibaseblastCommandline(AbstractCommandline):
                 for b in incompatibles[a]:
                     if self._get_parameter(b):
                         raise ValueError("Options %s and %s are incompatible."
-                                         % (a,b))
+                                         % (a, b))
 
 
 class _NcbiblastCommandline(_NcbibaseblastCommandline):
@@ -518,7 +520,7 @@ class _NcbiblastCommandline(_NcbibaseblastCommandline):
             _Option(["-evalue", "evalue"],
                     "Expectation value cutoff.",
                     equate=False),
-            _Option(["-word_size","word_size"],
+            _Option(["-word_size", "word_size"],
                     """Word size for wordfinder algorithm.
 
                     Integer. Minimum 2.""",
@@ -697,7 +699,7 @@ class _Ncbiblast2SeqCommandline(_NcbiblastCommandline):
 
     def _validate(self):
         incompatibles = {"subject_loc":["db", "gilist", "negative_gilist", "seqidlist", "remote"],
-                         "culling_limit":["best_hit_overhang","best_hit_score_edge"],
+                         "culling_limit":["best_hit_overhang", "best_hit_score_edge"],
                          "subject":["db", "gilist", "negative_gilist", "seqidlist"]}
         self._validate_incompatibilities(incompatibles)
         _NcbiblastCommandline._validate(self)
@@ -757,7 +759,7 @@ class NcbiblastpCommandline(_NcbiblastMain2SeqCommandline):
     ...                               evalue=0.001, remote=True, ungapped=True)
     >>> cline
     NcbiblastpCommandline(cmd='blastp', query='rosemary.pro', db='nr', evalue=0.001, remote=True, ungapped=True)
-    >>> print cline
+    >>> print(cline)
     blastp -query rosemary.pro -db nr -evalue 0.001 -remote -ungapped
 
     You would typically run the command line with cline() or via the Python
@@ -820,7 +822,7 @@ class NcbiblastnCommandline(_NcbiblastMain2SeqCommandline):
     ...                               evalue=0.001, out="m_cold.xml", outfmt=5)
     >>> cline
     NcbiblastnCommandline(cmd='blastn', out='m_cold.xml', outfmt=5, query='m_cold.fasta', db='nt', evalue=0.001, strand='plus')
-    >>> print cline
+    >>> print(cline)
     blastn -out m_cold.xml -outfmt 5 -query m_cold.fasta -db nt -evalue 0.001 -strand plus
 
     You would typically run the command line with cline() or via the Python
@@ -889,7 +891,7 @@ class NcbiblastnCommandline(_NcbiblastMain2SeqCommandline):
 
                     Allowed values: 'coding', 'coding_and_optimal' or 'optimal'
                     Requires: template_length.""",
-                    checker_function=lambda value : value in ['coding', 'coding_and_optimal','optimal'],
+                    checker_function=lambda value : value in ['coding', 'coding_and_optimal', 'optimal'],
                     equate=False),
             _Option(["-template_length", "template_length"],
                     """Discontiguous MegaBLAST template length (integer).
@@ -897,7 +899,7 @@ class NcbiblastnCommandline(_NcbiblastMain2SeqCommandline):
                     Allowed values: 16, 18, 21
 
                     Requires: template_type.""",
-                    checker_function=lambda value : value in [16,18,21,'16','18','21'],
+                    checker_function=lambda value : value in [16, 18, 21, '16', '18', '21'],
                     equate=False),
             #Extension options:
             _Switch(["-no_greedy", "no_greedy"],
@@ -937,7 +939,7 @@ class NcbiblastxCommandline(_NcbiblastMain2SeqCommandline):
     >>> cline = NcbiblastxCommandline(query="m_cold.fasta", db="nr", evalue=0.001)
     >>> cline
     NcbiblastxCommandline(cmd='blastx', query='m_cold.fasta', db='nr', evalue=0.001)
-    >>> print cline
+    >>> print(cline)
     blastx -query m_cold.fasta -db nr -evalue 0.001
 
     You would typically run the command line with cline() or via the Python
@@ -980,14 +982,15 @@ class NcbiblastxCommandline(_NcbiblastMain2SeqCommandline):
                     equate=False),
             _Option(["-comp_based_stats", "comp_based_stats"],
                     """Use composition-based statistics for blastp, blastx, or tblastn:
-                        D or d: default (equivalent to 2 )
-                        0 or F or f: no composition-based statistics
-                        1: Composition-based statistics as in NAR 29:2994-3005, 2001
-                        2 or T or t : Composition-based score adjustment as in Bioinformatics 21:902-911, 2005, conditioned on sequence properties
-                        3: Composition-based score adjustment as in Bioinformatics 21:902-911, 2005, unconditionally
 
-                        For programs other than tblastn, must either be absent or be D, F or 0
-                        Default = `2'
+                    D or d: default (equivalent to 2 )
+                    0 or F or f: no composition-based statistics
+                    1: Composition-based statistics as in NAR 29:2994-3005, 2001
+                    2 or T or t : Composition-based score adjustment as in Bioinformatics 21:902-911, 2005, conditioned on sequence properties
+                    3: Composition-based score adjustment as in Bioinformatics 21:902-911, 2005, unconditionally
+
+                    For programs other than tblastn, must either be absent or be D, F or 0
+                    Default = `2'
                     """,
                     equate=False),
             #Query filtering options:
@@ -1017,7 +1020,7 @@ class NcbitblastnCommandline(_NcbiblastMain2SeqCommandline):
     >>> cline = NcbitblastnCommandline(help=True)
     >>> cline
     NcbitblastnCommandline(cmd='tblastn', help=True)
-    >>> print cline
+    >>> print(cline)
     tblastn -help
 
     You would typically run the command line with cline() or via the Python
@@ -1097,7 +1100,7 @@ class NcbitblastxCommandline(_NcbiblastMain2SeqCommandline):
     >>> cline = NcbitblastxCommandline(help=True)
     >>> cline
     NcbitblastxCommandline(cmd='tblastx', help=True)
-    >>> print cline
+    >>> print(cline)
     tblastx -help
 
     You would typically run the command line with cline() or via the Python
@@ -1160,7 +1163,7 @@ class NcbipsiblastCommandline(_Ncbiblast2SeqCommandline):
     >>> cline = NcbipsiblastCommandline(help=True)
     >>> cline
     NcbipsiblastCommandline(cmd='psiblast', help=True)
-    >>> print cline
+    >>> print(cline)
     psiblast -help
 
     You would typically run the command line with cline() or via the Python
@@ -1265,10 +1268,10 @@ class NcbipsiblastCommandline(_Ncbiblast2SeqCommandline):
         _Ncbiblast2SeqCommandline.__init__(self, cmd, **kwargs)
 
     def _validate(self):
-        incompatibles = {"num_iterations":["remote"],
-                         "in_msa":["in_pssm", "query"],
-                         "in_pssm":["in_msa","query","phi_pattern"],
-                         "ignore_msa_master":["msa_master_idx", "in_pssm",
+        incompatibles = {"num_iterations": ["remote"],
+                         "in_msa": ["in_pssm", "query"],
+                         "in_pssm": ["in_msa", "query", "phi_pattern"],
+                         "ignore_msa_master": ["msa_master_idx", "in_pssm",
                                  "query", "query_loc", "phi_pattern"],
                          }
         self._validate_incompatibilities(incompatibles)
@@ -1286,7 +1289,7 @@ class NcbirpsblastCommandline(_NcbiblastCommandline):
     >>> cline = NcbirpsblastCommandline(help=True)
     >>> cline
     NcbirpsblastCommandline(cmd='rpsblast', help=True)
-    >>> print cline
+    >>> print(cline)
     rpsblast -help
 
     You would typically run the command line with cline() or via the Python
@@ -1325,11 +1328,27 @@ class NcbirpsblastCommandline(_NcbiblastCommandline):
 
                     Incompatible with: culling_limit.""",
                     equate=False),
+            #General search options:
+            _Option(["-comp_based_stats", "comp_based_stats"],
+                    """Use composition-based statistics.
+
+                    D or d: default (equivalent to 0 )
+                    0 or F or f: Simplified Composition-based statistics as in
+                                 Bioinformatics 15:1000-1011, 1999
+                    1 or T or t: Composition-based statistics as in NAR 29:2994-3005, 2001
+
+                    Default = `0'
+                    """,
+                    checker_function=lambda value : value in "Dd0Ff1Tt",
+                    equate=False),
+            #Misc options:
+            _Switch(["-use_sw_tback", "use_sw_tback"],
+                    "Compute locally optimal Smith-Waterman alignments?"),
             ]
         _NcbiblastCommandline.__init__(self, cmd, **kwargs)
 
     def _validate(self):
-        incompatibles = {"culling_limit":["best_hit_overhang","best_hit_score_edge"]}
+        incompatibles = {"culling_limit":["best_hit_overhang", "best_hit_score_edge"]}
         self._validate_incompatibilities(incompatibles)
         _NcbiblastCommandline._validate(self)
 
@@ -1345,7 +1364,7 @@ class NcbirpstblastnCommandline(_NcbiblastCommandline):
     >>> cline = NcbirpstblastnCommandline(help=True)
     >>> cline
     NcbirpstblastnCommandline(cmd='rpstblastn', help=True)
-    >>> print cline
+    >>> print(cline)
     rpstblastn -help
 
     You would typically run the command line with cline() or via the Python
@@ -1396,7 +1415,7 @@ class NcbiblastformatterCommandline(_NcbibaseblastCommandline):
     >>> cline = NcbiblastformatterCommandline(archive="example.asn", outfmt=5, out="example.xml")
     >>> cline
     NcbiblastformatterCommandline(cmd='blast_formatter', out='example.xml', outfmt=5, archive='example.asn')
-    >>> print cline
+    >>> print(cline)
     blast_formatter -out example.xml -outfmt 5 -archive example.asn
 
     You would typically run the command line with cline() or via the Python
@@ -1441,3 +1460,4 @@ def _test():
 if __name__ == "__main__":
     #Run the doctests
     _test()
+
