@@ -21,9 +21,12 @@ parse               Incremental parser, this is an iterator that returns
                     Blast records.  It uses the BlastParser internally.
 read                Returns a single Blast record. Uses the BlastParser internally.
 """
+from __future__ import print_function
+
 from Bio.Blast import Record
 import xml.sax
 from xml.sax.handler import ContentHandler
+from functools import reduce
 
 
 class _XMLparser(ContentHandler):
@@ -70,11 +73,11 @@ class _XMLparser(ContentHandler):
         if hasattr(self, method):
             eval("self.%s()" % method)
             if self._debug > 4:
-                print "NCBIXML: Parsed:  " + method
+                print("NCBIXML: Parsed:  " + method)
         elif self._debug > 3:
             # Doesn't exist (yet) and may want to warn about it
             if method not in self._debug_ignore_list:
-                print "NCBIXML: Ignored: " + method
+                print("NCBIXML: Ignored: " + method)
                 self._debug_ignore_list.append(method)
 
         #We don't care about white space in parent tags like Hsp,
@@ -105,11 +108,11 @@ class _XMLparser(ContentHandler):
         if hasattr(self, method):
             eval("self.%s()" % method)
             if self._debug > 2:
-                print "NCBIXML: Parsed:  " + method, self._value
+                print("NCBIXML: Parsed:  %s %s" % (method, self._value))
         elif self._debug > 1:
             # Doesn't exist (yet) and may want to warn about it
             if method not in self._debug_ignore_list:
-                print "NCBIXML: Ignored: " + method, self._value
+                print("NCBIXML: Ignored: %s %s" % (method, self._value))
                 self._debug_ignore_list.append(method)
 
         # Reset character buffer
@@ -209,7 +212,7 @@ class BlastParser(_XMLparser):
         self._blast = None
 
         if self._debug:
-            print "NCBIXML: Added Blast record to results"
+            print("NCBIXML: Added Blast record to results")
 
     # Header
     def _end_BlastOutput_program(self):
@@ -575,13 +578,13 @@ def read(handle, debug=0):
     """
     iterator = parse(handle, debug)
     try:
-        first = iterator.next()
+        first = next(iterator)
     except StopIteration:
         first = None
     if first is None:
         raise ValueError("No records found in handle")
     try:
-        second = iterator.next()
+        second = next(iterator)
     except StopIteration:
         second = None
     if second is not None:
@@ -659,7 +662,7 @@ def parse(handle, debug=0):
                 # one XML file for each query!
 
                 # Finish the old file:
-                text, pending = (text+pending).split("\n" + XML_START,1)
+                text, pending = (text+pending).split("\n" + XML_START, 1)
                 pending = XML_START + pending
 
                 expat_parser.Parse(text, True) # End of XML record
@@ -689,28 +692,28 @@ def parse(handle, debug=0):
 
 if __name__ == '__main__':
     import sys
-    handle = open(sys.argv[1])
-    r_list = parse(handle)
+    with open(sys.argv[1]) as handle:
+        r_list = parse(handle)
 
     for r in r_list:
         # Small test
-        print 'Blast of', r.query
-        print 'Found %s alignments with a total of %s HSPs' % (len(r.alignments),
-                  reduce(lambda a,b: a+b,
-                         [len(a.hsps) for a in r.alignments]))
+        print('Blast of %s' % r.query)
+        print('Found %s alignments with a total of %s HSPs' % (len(r.alignments),
+                  reduce(lambda a, b: a+b,
+                         [len(a.hsps) for a in r.alignments])))
 
         for al in r.alignments:
-            print al.title[:50], al.length, 'bp', len(al.hsps), 'HSPs'
+            print("%s %i bp %i HSPs" % (al.title[:50], al.length, len(al.hsps)))
 
         # Cookbook example
         E_VALUE_THRESH = 0.04
         for alignment in r.alignments:
             for hsp in alignment.hsps:
                 if hsp.expect < E_VALUE_THRESH:
-                    print '*****'
-                    print 'sequence', alignment.title
-                    print 'length', alignment.length
-                    print 'e value', hsp.expect
-                    print hsp.query[:75] + '...'
-                    print hsp.match[:75] + '...'
-                    print hsp.sbjct[:75] + '...'
+                    print('*****')
+                    print('sequence %s' % alignment.title)
+                    print('length %i' % alignment.length)
+                    print('e value %f' % hsp.expect)
+                    print(hsp.query[:75] + '...')
+                    print(hsp.match[:75] + '...')
+                    print(hsp.sbjct[:75] + '...')
