@@ -9,6 +9,8 @@ ftp://ftp.ncbi.nih.gov/entrez/misc/data/gc.prt
 Last updated for Version 3.9
 """
 
+from __future__ import print_function
+
 from Bio import Alphabet
 from Bio.Alphabet import IUPAC
 from Bio.Data import IUPACData
@@ -66,8 +68,8 @@ class CodonTable(object):
 
         e.g.
         >>> import Bio.Data.CodonTable
-        >>> print Bio.Data.CodonTable.standard_dna_table
-        >>> print Bio.Data.CodonTable.generic_by_id[1]
+        >>> print(Bio.Data.CodonTable.standard_dna_table)
+        >>> print(Bio.Data.CodonTable.generic_by_id[1])
         """
 
         if self.id:
@@ -75,7 +77,7 @@ class CodonTable(object):
         else:
             answer = "Table ID unknown"
         if self.names:
-            answer += " " + ", ".join(filter(None, self.names))
+            answer += " " + ", ".join([x for x in self.names if x])
 
         #Use the main four letters (and the conventional ordering)
         #even for ambiguous tables
@@ -89,19 +91,16 @@ class CodonTable(object):
             letters = "UCAG"
 
         #Build the table...
-        answer=answer + "\n\n  |" + "|".join(
-            ["  %s      " % c2 for c2 in letters]
-            ) + "|"
-        answer=answer + "\n--+" \
-               + "+".join(["---------" for c2 in letters]) + "+--"
+        answer += "\n\n  |" + "|".join("  %s      " % c2 for c2 in letters) + "|"
+        answer += "\n--+" + "+".join("---------" for c2 in letters) + "+--"
         for c1 in letters:
             for c3 in letters:
                 line = c1 + " |"
                 for c2 in letters:
                     codon = c1+c2+c3
-                    line = line + " %s" % codon
+                    line += " %s" % codon
                     if codon in self.stop_codons:
-                        line = line + " Stop|"
+                        line += " Stop|"
                     else:
                         try:
                             amino = self.forward_table[codon]
@@ -110,13 +109,12 @@ class CodonTable(object):
                         except TranslationError:
                             amino = "?"
                         if codon in self.start_codons:
-                            line = line + " %s(s)|" % amino
+                            line += " %s(s)|" % amino
                         else:
-                            line = line + " %s   |" % amino
-                line = line + " " + c3
-                answer = answer + "\n"+ line
-            answer=answer + "\n--+" \
-                  + "+".join(["---------" for c2 in letters]) + "+--"
+                            line += " %s   |" % amino
+                line += " " + c3
+                answer += "\n"+ line
+            answer += "\n--+" + "+".join("---------" for c2 in letters) + "+--"
         return answer
 
 
@@ -204,7 +202,7 @@ def list_possible_proteins(codon, forward_table, ambiguous_nucleotide_values):
                                        + "for both proteins and stop codons")
             # This is a true stop codon - tell the caller about it
             raise KeyError(codon)
-        return possible.keys()
+        return list(possible.keys())
 
 
 def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
@@ -225,14 +223,14 @@ def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
     #This will generate things like 'TRR' from ['TAG', 'TGA'], which
     #we don't want to include:
     c1_list = sorted(letter for (letter, meanings)
-               in ambiguous_nucleotide_values.iteritems()
-               if set([codon[0] for codon in codons]).issuperset(set(meanings)))
+               in ambiguous_nucleotide_values.items()
+               if set(codon[0] for codon in codons).issuperset(set(meanings)))
     c2_list = sorted(letter for (letter, meanings)
-               in ambiguous_nucleotide_values.iteritems()
-               if set([codon[1] for codon in codons]).issuperset(set(meanings)))
+               in ambiguous_nucleotide_values.items()
+               if set(codon[1] for codon in codons).issuperset(set(meanings)))
     c3_list = sorted(letter for (letter, meanings)
-               in ambiguous_nucleotide_values.iteritems()
-               if set([codon[2] for codon in codons]).issuperset(set(meanings)))
+               in ambiguous_nucleotide_values.items()
+               if set(codon[2] for codon in codons).issuperset(set(meanings)))
     #candidates is a list (not a set) to preserve the iteration order
     candidates = []
     for c1 in c1_list:
@@ -290,13 +288,13 @@ class AmbiguousForwardTable(object):
         self.ambiguous_protein = ambiguous_protein
 
         inverted = {}
-        for name, val in ambiguous_protein.iteritems():
+        for name, val in ambiguous_protein.items():
             for c in val:
                 x = inverted.get(c, {})
                 x[name] = 1
                 inverted[c] = x
-        for name, val in inverted.iteritems():
-            inverted[name] = val.keys()
+        for name, val in inverted.items():
+            inverted[name] = list(val.keys())
         self._inverted = inverted
 
         self._cache = {}
@@ -353,7 +351,7 @@ class AmbiguousForwardTable(object):
 
         n = len(possible)
         possible = []
-        for amino, val in ambiguous_possible.iteritems():
+        for amino, val in ambiguous_possible.items():
             if val == n:
                 possible.append(amino)
 
@@ -384,7 +382,7 @@ def register_ncbi_table(name, alt_name, id,
     """Turns codon table data into objects, and stores them in the dictionaries (PRIVATE)."""
     #In most cases names are divided by "; ", however there is also
     #'Bacterial and Plant Plastid' (which used to be just 'Bacterial')
-    names = [x.strip() for x in name.replace(" and ","; ").split("; ")]
+    names = [x.strip() for x in name.replace(" and ", "; ").split("; ")]
 
     dna = NCBICodonTableDNA(id, names + [alt_name], table, start_codons,
                             stop_codons)
@@ -398,7 +396,7 @@ def register_ncbi_table(name, alt_name, id,
     # replace all T's with U's for the RNA tables
     rna_table = {}
     generic_table = {}
-    for codon, val in table.iteritems():
+    for codon, val in table.items():
         generic_table[codon] = val
         codon = codon.replace("T", "U")
         generic_table[codon] = val
@@ -422,7 +420,7 @@ def register_ncbi_table(name, alt_name, id,
                              generic_start_codons, generic_stop_codons)
 
     #The following isn't very elegant, but seems to work nicely.
-    _merged_values = dict(IUPACData.ambiguous_rna_values.iteritems())
+    _merged_values = dict(IUPACData.ambiguous_rna_values.items())
     _merged_values["T"] = "U"
     ambig_generic = AmbiguousCodonTable(generic,
                                         Alphabet.NucleotideAlphabet(),
@@ -863,9 +861,9 @@ register_ncbi_table(name = 'Thraustochytrium Mitochondrial',
                     )
 
 #Basic sanity test,
-for key, val in generic_by_name.iteritems():
+for key, val in generic_by_name.items():
     assert key in ambiguous_generic_by_name[key].names
-for key, val in generic_by_id.iteritems():
+for key, val in generic_by_id.items():
     assert ambiguous_generic_by_id[key].id == key
 del key, val
 
@@ -879,7 +877,7 @@ for n in ambiguous_generic_by_id:
     if "UAA" in unambiguous_rna_by_id[n].stop_codons \
     and "UGA" in unambiguous_rna_by_id[n].stop_codons:
         try:
-            print ambiguous_dna_by_id[n].forward_table["TRA"]
+            print(ambiguous_dna_by_id[n].forward_table["TRA"])
             assert False, "Should be a stop only"
         except KeyError:
             pass
