@@ -36,9 +36,9 @@ except ImportError:
     renderPM=None
 
 # GenomeDiagram
-from _LinearDrawer import LinearDrawer
-from _CircularDrawer import CircularDrawer
-from _Track import Track
+from ._LinearDrawer import LinearDrawer
+from ._CircularDrawer import CircularDrawer
+from ._Track import Track
 
 from Bio.Graphics import _write
 
@@ -315,7 +315,7 @@ class Diagram(object):
         #just uses a cStringIO or StringIO handle with the drawToFile method.
         #In order to put all our complicated file format specific code in one
         #place we'll just use a StringIO handle here:
-        from StringIO import StringIO
+        from Bio._py3k import StringIO
         handle = StringIO()
         self.write(handle, output, dpi)
         return handle.getvalue()
@@ -335,8 +335,7 @@ class Diagram(object):
         if track_level not in self.tracks:     # No track at that level
             self.tracks[track_level] = track   # so just add it
         else:       # Already a track there, so shunt all higher tracks up one
-            occupied_levels = self.get_levels() # Get list of occupied levels...
-            occupied_levels.sort()              # ...sort it...
+            occupied_levels = sorted(self.get_levels()) # Get list of occupied levels...
             occupied_levels.reverse()           # ...reverse it (highest first)
             for val in occupied_levels:
                 # If track value >= that to be added
@@ -360,8 +359,7 @@ class Diagram(object):
         if track_level not in self.tracks:        # No track at that level
             self.tracks[track_level] = newtrack   # so just add it
         else:       # Already a track there, so shunt all higher tracks up one
-            occupied_levels = self.get_levels() # Get list of occupied levels...
-            occupied_levels.sort()              # ...sort it...
+            occupied_levels = sorted(self.get_levels()) # Get list of occupied levels...
             occupied_levels.reverse()           # ...reverse (highest first)...
             for val in occupied_levels:
                 if val >= track_level:        # Track value >= that to be added
@@ -384,7 +382,7 @@ class Diagram(object):
 
             Returns a list of the tracks contained in the diagram
         """
-        return self.tracks.values()
+        return list(self.tracks.values())
 
     def move_track(self, from_level, to_level):
         """ move_track(self, from_level, to_level)
@@ -425,9 +423,7 @@ class Diagram(object):
 
             Return a sorted list of levels occupied by tracks in the diagram
         """
-        levels = self.tracks.keys()
-        levels.sort()
-        return levels
+        return sorted(self.tracks)
 
     def get_drawn_levels(self):
         """ get_drawn_levels(self) -> [int, int, ...]
@@ -435,10 +431,7 @@ class Diagram(object):
             Return a sorted list of levels occupied by tracks that are not
             explicitly hidden
         """
-        drawn_levels = [key for key in self.tracks.keys() if
-                        not self.tracks[key].hide] # get list of shown levels
-        drawn_levels.sort()
-        return drawn_levels
+        return sorted(key for key in self.tracks if not self.tracks[key].hide)
 
     def range(self):
         """ range(self) -> (int, int)
