@@ -1,3 +1,8 @@
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+#
+
 """Deal with representations of Markov Models.
 """
 # standard modules
@@ -8,7 +13,8 @@ import random
 #TODO - Take advantage of defaultdict once Python 2.4 is dead?
 #from collections import defaultdict
 
-# biopython
+from Bio._py3k import range
+
 from Bio.Seq import MutableSeq
 
 
@@ -191,7 +197,7 @@ class MarkovModelBuilder(object):
         self.initial_prob = copy.copy(initial_prob)
 
         # ensure that all referenced states are valid
-        for state in initial_prob.iterkeys():
+        for state in initial_prob:
             assert state in self._state_alphabet.letters, \
                    "State %s was not found in the sequence alphabet" % state
 
@@ -264,7 +270,7 @@ class MarkovModelBuilder(object):
                             "allow_transition or allow_all_transitions first.")
 
         transitions_from = _calculate_from_transitions(self.transition_prob)
-        for from_state in transitions_from.keys():
+        for from_state in transitions_from:
             freqs = _gen_random_array(len(transitions_from[from_state]))
             for to_state in transitions_from[from_state]:
                 self.transition_prob[(from_state, to_state)] = freqs.pop()
@@ -282,7 +288,7 @@ class MarkovModelBuilder(object):
                             "Allow some or all emissions.")
 
         emissions = _calculate_emissions(self.emission_prob)
-        for state in emissions.iterkeys():
+        for state in emissions:
             freqs = _gen_random_array(len(emissions[state]))
             for symbol in emissions[state]:
                 self.emission_prob[(state, symbol)] = freqs.pop()
@@ -617,7 +623,7 @@ class HiddenMarkovModel(object):
         # --- traceback
         traceback_seq = MutableSeq('', state_alphabet)
 
-        loop_seq = range(1, len(sequence))
+        loop_seq = list(range(1, len(sequence)))
         loop_seq.reverse()
 
         # last_state is the last state in the most probable state sequence.
