@@ -1,3 +1,8 @@
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+#
+
 """
 The KD tree data structure can be used for all kinds of searches that
 involve N-dimensional vectors. For example, neighbor searches (find all points
@@ -7,4 +12,4 @@ Algorithms and Applications" (Mark de Berg, Marc van Kreveld, Mark Overmars,
 Otfried Schwarzkopf).
 """
 
-from KDTree import KDTree
+from .KDTree import KDTree
