@@ -59,10 +59,10 @@ def __read_database_and_motifs(record, handle):
     for line in handle:
         if line.startswith('DATABASE AND MOTIFS'):
             break
-    line = handle.next()
+    line = next(handle)
     if not line.startswith('****'):
         raise ValueError("Line does not start with '****':\n%s" % line)
-    line = handle.next()
+    line = next(handle)
     if not 'DATABASE' in line:
         raise ValueError("Line does not contain 'DATABASE':\n%s" % line)
     words = line.strip().split()
@@ -74,7 +74,7 @@ def __read_database_and_motifs(record, handle):
     for line in handle:
         if 'MOTIF WIDTH' in line:
             break
-    line = handle.next()
+    line = next(handle)
     if not '----' in line:
         raise ValueError("Line does not contain '----':\n%s" % line)
     for line in handle:
@@ -96,7 +96,7 @@ def __read_section_i(record, handle):
     for line in handle:
         if line.startswith('SEQUENCE NAME'):
             break
-    line = handle.next()
+    line = next(handle)
     if not line.startswith('---'):
         raise ValueError("Line does not start with '---':\n%s" % line)
     for line in handle:
@@ -105,7 +105,7 @@ def __read_section_i(record, handle):
         else:
             sequence, description_evalue_length = line.split(None, 1)
             record.sequences.append(sequence)
-    line = handle.next()
+    line = next(handle)
     if not line.startswith('****'):
         raise ValueError("Line does not start with '****':\n%s" % line)
 
@@ -117,7 +117,7 @@ def __read_section_ii(record, handle):
     for line in handle:
         if line.startswith('SEQUENCE NAME'):
             break
-    line = handle.next()
+    line = next(handle)
     if not line.startswith('---'):
         raise ValueError("Line does not start with '---':\n%s" % line)
     for line in handle:
@@ -129,7 +129,7 @@ def __read_section_ii(record, handle):
         else:
             sequence, pvalue, diagram = line.split()
             record.diagrams[sequence] = diagram
-    line = handle.next()
+    line = next(handle)
     if not line.startswith('****'):
         raise ValueError("Line does not start with '****':\n%s" % line)
 
