@@ -1,3 +1,8 @@
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+#
+
 """Classes to help deal with stopping training a neural network.
 
 One of the key issues with training a neural network is knowning when to
@@ -13,6 +18,8 @@ of the classes passed to the network.
 """
 
 
+from __future__ import print_function
+
 class ValidationIncreaseStop(object):
     """Class to stop training on a network when the validation error increases.
 
@@ -51,20 +58,20 @@ class ValidationIncreaseStop(object):
         """
         if num_iterations % 10 == 0:
             if self.verbose:
-                print "%s; Training Error:%s; Validation Error:%s"\
-                      % (num_iterations, training_error, validation_error)
+                print("%s; Training Error:%s; Validation Error:%s"\
+                      % (num_iterations, training_error, validation_error))
 
         if num_iterations > self.min_iterations:
             if self.last_error is not None:
                 if validation_error > self.last_error:
                     if self.verbose:
-                        print "Validation Error increasing -- Stop"
+                        print("Validation Error increasing -- Stop")
                     return 1
 
         if self.max_iterations is not None:
             if num_iterations > self.max_iterations:
                 if self.verbose:
-                    print "Reached maximum number of iterations -- Stop"
+                    print("Reached maximum number of iterations -- Stop")
                 return 1
 
         self.last_error = validation_error
