@@ -79,7 +79,7 @@ class Atom(object):
             # isdigit() check on last two characters to avoid mis-assignment of
             # hydrogens atoms (GLN HE21 for example)
 
-            if self.fullname[0] != " " and not self.fullname[2:].isdigit():
+            if self.fullname[0].isalpha() and not self.fullname[2:].isdigit():
                 putative_element = self.name.strip()
             else:
                 # Hs may have digit in [0]
@@ -124,7 +124,7 @@ class Atom(object):
         @type other: L{Atom}
         """
         diff=self.coord-other.coord
-        return numpy.sqrt(numpy.dot(diff,diff))
+        return numpy.sqrt(numpy.dot(diff, diff))
 
     # set methods
 
@@ -262,8 +262,8 @@ class Atom(object):
         Apply rotation and translation to the atomic coordinates.
 
         Example:
-                >>> rotation=rotmat(pi, Vector(1,0,0))
-                >>> translation=array((0,0,1), 'f')
+                >>> rotation=rotmat(pi, Vector(1, 0, 0))
+                >>> translation=array((0, 0, 1), 'f')
                 >>> atom.transform(rotation, translation)
 
         @param rot: A right multiplying rotation matrix
@@ -281,8 +281,8 @@ class Atom(object):
         @return: coordinates as 3D vector
         @rtype: Vector
         """
-        x,y,z=self.coord
-        return Vector(x,y,z)
+        x, y, z=self.coord
+        return Vector(x, y, z)
 
     def copy(self):
         """
@@ -333,3 +333,4 @@ class DisorderedAtom(DisorderedEntityWrapper):
         if occupancy>self.last_occupancy:
             self.last_occupancy=occupancy
             self.disordered_select(altloc)
+
