@@ -5,10 +5,12 @@
 """Phylogenetics command line tool wrappers."""
 __docformat__ = "restructuredtext en"
 
-from _Phyml import PhymlCommandline
-from _Raxml import RaxmlCommandline
+from ._Phyml import PhymlCommandline
+from ._Raxml import RaxmlCommandline
+from ._Fasttree import FastTreeCommandline
 
 #Make this explicit, then they show up in the API docs
 __all__ = ["PhymlCommandline",
            "RaxmlCommandline",
+           "FastTreeCommandline",
            ]
