@@ -9,15 +9,13 @@ See classes in `Bio.Nexus`: Trees.Tree, Trees.NodeData, and Nodes.Chain.
 """
 __docformat__ = "restructuredtext en"
 
-import warnings
-
 from Bio.Phylo import BaseTree
 
 
 class Tree(BaseTree.Tree):
     """Newick Tree object."""
 
-    def __init__(self, root=None, rooted=False, id=None, name='', weight=1.0):
+    def __init__(self, root=None, rooted=False, id=None, name=None, weight=1.0):
         BaseTree.Tree.__init__(self, root=root or Clade(),
                 rooted=rooted, id=id, name=name)
         self.weight = weight
@@ -31,4 +29,3 @@ class Clade(BaseTree.Clade):
         BaseTree.Clade.__init__(self, branch_length=branch_length,
                 name=name, clades=clades, confidence=confidence)
         self.comment = comment
-
