@@ -10,20 +10,18 @@ This module allows you to control Simcoal2.
 
 import os
 import sys
-import tempfile
-from shutil import copyfile
-from logging import debug
 
-class SimCoalController:
+
+class SimCoalController(object):
     def __init__(self, simcoal_dir):
         """Initializes the controller.
-        
+
         simcoal_dir is the directory where simcoal is.
-        
+
         The initializer checks for existance and executability of binaries.
         """
         self.simcoal_dir = simcoal_dir
-        self.os_name = os.name #remove this?
+        self.os_name = os.name  # remove this?
         dir_contents = os.listdir(self.simcoal_dir)
         #We expect the tool to be installed as simcoal2(.exe)
         #without any trailing version number.
@@ -43,7 +41,7 @@ class SimCoalController:
     def run_simcoal(self, par_file, num_sims, ploydi = '1', par_dir = '.'):
         """Executes SimCoal.
         """
-        if par_dir == None:
+        if par_dir is None:
             par_dir = os.sep.join([".", 'SimCoal', 'runs'])
         curr_dir = os.getcwd()
         #TODO - Make sure we change drive on Windows as well?
@@ -60,5 +58,3 @@ class SimCoalController:
             cmd += ' >/dev/null 2>&1'
         os.system(cmd)
         os.chdir(curr_dir)
-    
-
