@@ -283,10 +283,12 @@ The following SearchIO objects attributes are provided:
 
 """
 
-from hmmer2_text import *
-from hmmer3_domtab import *
-from hmmer3_text import *
-from hmmer3_tab import *
+from .hmmer2_text import Hmmer2TextParser, Hmmer2TextIndexer
+from .hmmer3_domtab import Hmmer3DomtabParser, Hmmer3DomtabHmmhitParser, Hmmer3DomtabHmmqueryParser
+from .hmmer3_domtab import Hmmer3DomtabHmmhitIndexer, Hmmer3DomtabHmmqueryIndexer
+from .hmmer3_domtab import Hmmer3DomtabHmmhitWriter, Hmmer3DomtabHmmqueryWriter
+from .hmmer3_text import Hmmer3TextParser, Hmmer3TextIndexer
+from .hmmer3_tab import Hmmer3TabParser, Hmmer3TabIndexer, Hmmer3TabWriter
 
 
 # if not used as a module, run the doctest
