@@ -11,11 +11,17 @@ See also U{http://biopython.org/wiki/Seq} and the chapter in our tutorial:
  - U{http://biopython.org/DIST/docs/tutorial/Tutorial.html}
  - U{http://biopython.org/DIST/docs/tutorial/Tutorial.pdf}
 """
+from __future__ import print_function
+
 __docformat__ ="epytext en"  # Don't just use plain text in epydoc API pages!
 
 import string  # for maketrans only
 import array
 import sys
+import warnings
+
+from Bio._py3k import range
+from Bio._py3k import basestring
 
 from Bio import Alphabet
 from Bio.Alphabet import IUPAC
@@ -89,7 +95,7 @@ class Seq(object):
         ...              IUPAC.protein)
         >>> my_seq
         Seq('MKQHKAMIVALIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF', IUPACProtein())
-        >>> print my_seq
+        >>> print(my_seq)
         MKQHKAMIVALIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF
         >>> my_seq.alphabet
         IUPACProtein()
@@ -131,6 +137,13 @@ class Seq(object):
 
         See the __cmp__ documentation - we plan to change this!
         """
+        warnings.warn("In future comparing Seq objects will use string "
+                      "comparison (not object comparison). Please use "
+                      "hash(id(my_seq)) or my_dict[id(my_seq)] if you "
+                      "want the current behaviour, or for string hashing "
+                      "use hash(str(my_seq)) or my_dict[str(my_seq)] to "
+                      "to make your code explicit and to avoid this "
+                      "warning.", FutureWarning)
         return id(self)  # Currently use object identity for equality testing
 
     def __cmp__(self, other):
@@ -158,7 +171,6 @@ class Seq(object):
         """
         if hasattr(other, "alphabet"):
             #other should be a Seq or a MutableSeq
-            import warnings
             warnings.warn("In future comparing Seq objects will use string "
                           "comparison (not object comparison). Incompatible "
                           "alphabets will trigger a warning (not an exception). "
@@ -329,7 +341,7 @@ class Seq(object):
         #Return as a string
         return str(other_sequence)
 
-    def count(self, sub, start=0, end=sys.maxint):
+    def count(self, sub, start=0, end=sys.maxsize):
         """Non-overlapping count method, like that of a python string.
 
         This behaves like the python string method of the same name,
@@ -349,13 +361,13 @@ class Seq(object):
 
         >>> from Bio.Seq import Seq
         >>> my_seq = Seq("AAAATGA")
-        >>> print my_seq.count("A")
+        >>> print(my_seq.count("A"))
         5
-        >>> print my_seq.count("ATG")
+        >>> print(my_seq.count("ATG"))
         1
-        >>> print my_seq.count(Seq("AT"))
+        >>> print(my_seq.count(Seq("AT")))
         1
-        >>> print my_seq.count("AT", 2, -1)
+        >>> print(my_seq.count("AT", 2, -1))
         1
 
         HOWEVER, please note because python strings and Seq objects (and
@@ -364,7 +376,7 @@ class Seq(object):
 
         >>> "AAAA".count("AA")
         2
-        >>> print Seq("AAAA").count("AA")
+        >>> print(Seq("AAAA").count("AA"))
         2
 
         A non-overlapping search would give the answer as three!
@@ -404,7 +416,7 @@ class Seq(object):
         sub_str = self._get_seq_str_and_check_alphabet(char)
         return sub_str in str(self)
 
-    def find(self, sub, start=0, end=sys.maxint):
+    def find(self, sub, start=0, end=sys.maxsize):
         """Find method, like that of a python string.
 
         This behaves like the python string method of the same name.
@@ -430,7 +442,7 @@ class Seq(object):
         sub_str = self._get_seq_str_and_check_alphabet(sub)
         return str(self).find(sub_str, start, end)
 
-    def rfind(self, sub, start=0, end=sys.maxint):
+    def rfind(self, sub, start=0, end=sys.maxsize):
         """Find from right method, like that of a python string.
 
         This behaves like the python string method of the same name.
@@ -456,7 +468,7 @@ class Seq(object):
         sub_str = self._get_seq_str_and_check_alphabet(sub)
         return str(self).rfind(sub_str, start, end)
 
-    def startswith(self, prefix, start=0, end=sys.maxint):
+    def startswith(self, prefix, start=0, end=sys.maxsize):
         """Does the Seq start with the given prefix?  Returns True/False.
 
         This behaves like the python string method of the same name.
@@ -475,7 +487,7 @@ class Seq(object):
         False
         >>> my_rna.startswith("AUG", 3)
         True
-        >>> my_rna.startswith(("UCC","UCA","UCG"),1)
+        >>> my_rna.startswith(("UCC", "UCA", "UCG"), 1)
         True
         """
         #If it has one, check the alphabet:
@@ -487,7 +499,7 @@ class Seq(object):
             prefix_str = self._get_seq_str_and_check_alphabet(prefix)
             return str(self).startswith(prefix_str, start, end)
 
-    def endswith(self, suffix, start=0, end=sys.maxint):
+    def endswith(self, suffix, start=0, end=sys.maxsize):
         """Does the Seq end with the given suffix?  Returns True/False.
 
         This behaves like the python string method of the same name.
@@ -506,7 +518,7 @@ class Seq(object):
         False
         >>> my_rna.endswith("AUG", 0, 18)
         True
-        >>> my_rna.endswith(("UCC","UCA","UUG"))
+        >>> my_rna.endswith(("UCC", "UCA", "UUG"))
         True
         """
         #If it has one, check the alphabet:
@@ -541,12 +553,12 @@ class Seq(object):
         Seq('VMAIVMGR*KGAR*L', HasStopCodon(ExtendedIUPACProtein(), '*'))
         >>> my_aa.split("*")
         [Seq('VMAIVMGR', HasStopCodon(ExtendedIUPACProtein(), '*')), Seq('KGAR', HasStopCodon(ExtendedIUPACProtein(), '*')), Seq('L', HasStopCodon(ExtendedIUPACProtein(), '*'))]
-        >>> my_aa.split("*",1)
+        >>> my_aa.split("*", 1)
         [Seq('VMAIVMGR', HasStopCodon(ExtendedIUPACProtein(), '*')), Seq('KGAR*L', HasStopCodon(ExtendedIUPACProtein(), '*'))]
 
         See also the rsplit method:
 
-        >>> my_aa.rsplit("*",1)
+        >>> my_aa.rsplit("*", 1)
         [Seq('VMAIVMGR*KGAR', HasStopCodon(ExtendedIUPACProtein(), '*')), Seq('L', HasStopCodon(ExtendedIUPACProtein(), '*'))]
         """
         #If it has one, check the alphabet:
@@ -570,7 +582,7 @@ class Seq(object):
         white space (tabs, spaces, newlines) but this is unlikely to
         apply to biological sequences.
 
-        e.g. print my_seq.rsplit("*",1)
+        e.g. print(my_seq.rsplit("*",1))
 
         See also the split method.
         """
@@ -588,7 +600,7 @@ class Seq(object):
         omitted or None (default) then as for the python string method,
         this defaults to removing any white space.
 
-        e.g. print my_seq.strip("-")
+        e.g. print(my_seq.strip("-"))
 
         See also the lstrip and rstrip methods.
         """
@@ -605,7 +617,7 @@ class Seq(object):
         omitted or None (default) then as for the python string method,
         this defaults to removing any white space.
 
-        e.g. print my_seq.lstrip("-")
+        e.g. print(my_seq.lstrip("-"))
 
         See also the strip and rstrip methods.
         """
@@ -1053,7 +1065,7 @@ class UnknownSeq(Seq):
     Seq('NNNNN', Alphabet())
     >>> len(my_seq)
     5
-    >>> print my_seq
+    >>> print(my_seq)
     NNNNN
 
     However, this is rather wasteful of memory (especially for large
@@ -1176,13 +1188,13 @@ class UnknownSeq(Seq):
         """Get a subsequence from the UnknownSeq object.
 
         >>> unk = UnknownSeq(8, character="N")
-        >>> print unk[:]
+        >>> print(unk[:])
         NNNNNNNN
-        >>> print unk[5:3]
+        >>> print(unk[5:3])
         <BLANKLINE>
-        >>> print unk[1:-1]
+        >>> print(unk[1:-1])
         NNNNNN
-        >>> print unk[1:-1:2]
+        >>> print(unk[1:-1:2])
         NNN
         """
         if isinstance(index, int):
@@ -1217,7 +1229,7 @@ class UnknownSeq(Seq):
         #        new_length, len(("X"*old_length)[index]))
         return UnknownSeq(new_length, self.alphabet, self._character)
 
-    def count(self, sub, start=0, end=sys.maxint):
+    def count(self, sub, start=0, end=sys.maxsize):
         """Non-overlapping count method, like that of a python string.
 
         This behaves like the python string (and Seq object) method of the
@@ -1279,11 +1291,11 @@ class UnknownSeq(Seq):
         >>> my_nuc = UnknownSeq(8)
         >>> my_nuc
         UnknownSeq(8, alphabet = Alphabet(), character = '?')
-        >>> print my_nuc
+        >>> print(my_nuc)
         ????????
         >>> my_nuc.complement()
         UnknownSeq(8, alphabet = Alphabet(), character = '?')
-        >>> print my_nuc.complement()
+        >>> print(my_nuc.complement())
         ????????
         """
         if isinstance(Alphabet._get_base_alphabet(self.alphabet),
@@ -1297,11 +1309,11 @@ class UnknownSeq(Seq):
         >>> my_nuc = UnknownSeq(10)
         >>> my_nuc
         UnknownSeq(10, alphabet = Alphabet(), character = '?')
-        >>> print my_nuc
+        >>> print(my_nuc)
         ??????????
         >>> my_nuc.reverse_complement()
         UnknownSeq(10, alphabet = Alphabet(), character = '?')
-        >>> print my_nuc.reverse_complement()
+        >>> print(my_nuc.reverse_complement())
         ??????????
         """
         if isinstance(Alphabet._get_base_alphabet(self.alphabet),
@@ -1315,12 +1327,12 @@ class UnknownSeq(Seq):
         >>> my_dna = UnknownSeq(10, character="N")
         >>> my_dna
         UnknownSeq(10, alphabet = Alphabet(), character = 'N')
-        >>> print my_dna
+        >>> print(my_dna)
         NNNNNNNNNN
         >>> my_rna = my_dna.transcribe()
         >>> my_rna
         UnknownSeq(10, alphabet = RNAAlphabet(), character = 'N')
-        >>> print my_rna
+        >>> print(my_rna)
         NNNNNNNNNN
         """
         #Offload the alphabet stuff
@@ -1333,12 +1345,12 @@ class UnknownSeq(Seq):
         >>> my_rna = UnknownSeq(20, character="N")
         >>> my_rna
         UnknownSeq(20, alphabet = Alphabet(), character = 'N')
-        >>> print my_rna
+        >>> print(my_rna)
         NNNNNNNNNNNNNNNNNNNN
         >>> my_dna = my_rna.back_transcribe()
         >>> my_dna
         UnknownSeq(20, alphabet = DNAAlphabet(), character = 'N')
-        >>> print my_dna
+        >>> print(my_dna)
         NNNNNNNNNNNNNNNNNNNN
         """
         #Offload the alphabet stuff
@@ -1353,11 +1365,11 @@ class UnknownSeq(Seq):
         >>> my_seq = UnknownSeq(20, generic_dna, character="n")
         >>> my_seq
         UnknownSeq(20, alphabet = DNAAlphabet(), character = 'n')
-        >>> print my_seq
+        >>> print(my_seq)
         nnnnnnnnnnnnnnnnnnnn
         >>> my_seq.upper()
         UnknownSeq(20, alphabet = DNAAlphabet(), character = 'N')
-        >>> print my_seq.upper()
+        >>> print(my_seq.upper())
         NNNNNNNNNNNNNNNNNNNN
 
         This will adjust the alphabet if required. See also the lower method.
@@ -1374,11 +1386,11 @@ class UnknownSeq(Seq):
         >>> my_seq = UnknownSeq(20, IUPAC.extended_protein)
         >>> my_seq
         UnknownSeq(20, alphabet = ExtendedIUPACProtein(), character = 'X')
-        >>> print my_seq
+        >>> print(my_seq)
         XXXXXXXXXXXXXXXXXXXX
         >>> my_seq.lower()
         UnknownSeq(20, alphabet = ProteinAlphabet(), character = 'x')
-        >>> print my_seq.lower()
+        >>> print(my_seq.lower())
         xxxxxxxxxxxxxxxxxxxx
 
         See also the upper method.
@@ -1390,24 +1402,24 @@ class UnknownSeq(Seq):
 
         e.g.
 
-        >>> my_seq = UnknownSeq(11, character="N")
-        >>> print my_seq
-        NNNNNNNNNNN
+        >>> my_seq = UnknownSeq(9, character="N")
+        >>> print(my_seq)
+        NNNNNNNNN
         >>> my_protein = my_seq.translate()
         >>> my_protein
         UnknownSeq(3, alphabet = ProteinAlphabet(), character = 'X')
-        >>> print my_protein
+        >>> print(my_protein)
         XXX
 
         In comparison, using a normal Seq object:
 
-        >>> my_seq = Seq("NNNNNNNNNNN")
-        >>> print my_seq
-        NNNNNNNNNNN
+        >>> my_seq = Seq("NNNNNNNNN")
+        >>> print(my_seq)
+        NNNNNNNNN
         >>> my_protein = my_seq.translate()
         >>> my_protein
         Seq('XXX', ExtendedIUPACProtein())
-        >>> print my_protein
+        >>> print(my_protein)
         XXX
 
         """
@@ -1424,7 +1436,7 @@ class UnknownSeq(Seq):
 
         >>> from Bio.Seq import UnknownSeq
         >>> from Bio.Alphabet import Gapped, generic_dna
-        >>> my_dna = UnknownSeq(20, Gapped(generic_dna,"-"))
+        >>> my_dna = UnknownSeq(20, Gapped(generic_dna, "-"))
         >>> my_dna
         UnknownSeq(20, alphabet = Gapped(DNAAlphabet(), '-'), character = 'N')
         >>> my_dna.ungap()
@@ -1435,7 +1447,7 @@ class UnknownSeq(Seq):
         If the UnknownSeq is using the gap character, then an empty Seq is
         returned:
 
-        >>> my_gap = UnknownSeq(20, Gapped(generic_dna,"-"), character="-")
+        >>> my_gap = UnknownSeq(20, Gapped(generic_dna, "-"), character="-")
         >>> my_gap
         UnknownSeq(20, alphabet = Gapped(DNAAlphabet(), '-'), character = '-')
         >>> my_gap.ungap()
@@ -1668,7 +1680,7 @@ class MutableSeq(object):
                 return
         raise ValueError("MutableSeq.remove(x): x not in list")
 
-    def count(self, sub, start=0, end=sys.maxint):
+    def count(self, sub, start=0, end=sys.maxsize):
         """Non-overlapping count method, like that of a python string.
 
         This behaves like the python string method of the same name,
@@ -1688,13 +1700,13 @@ class MutableSeq(object):
 
         >>> from Bio.Seq import MutableSeq
         >>> my_mseq = MutableSeq("AAAATGA")
-        >>> print my_mseq.count("A")
+        >>> print(my_mseq.count("A"))
         5
-        >>> print my_mseq.count("ATG")
+        >>> print(my_mseq.count("ATG"))
         1
-        >>> print my_mseq.count(Seq("AT"))
+        >>> print(my_mseq.count(Seq("AT")))
         1
-        >>> print my_mseq.count("AT", 2, -1)
+        >>> print(my_mseq.count("AT", 2, -1))
         1
 
         HOWEVER, please note because that python strings, Seq objects and
@@ -1703,7 +1715,7 @@ class MutableSeq(object):
 
         >>> "AAAA".count("AA")
         2
-        >>> print MutableSeq("AAAA").count("AA")
+        >>> print(MutableSeq("AAAA").count("AA"))
         2
 
         A non-overlapping search would give the answer as three!
@@ -1762,9 +1774,9 @@ class MutableSeq(object):
             d = ambiguous_rna_complement
         else:
             d = ambiguous_dna_complement
-        c = dict([(x.lower(), y.lower()) for x, y in d.iteritems()])
+        c = dict([(x.lower(), y.lower()) for x, y in d.items()])
         d.update(c)
-        self.data = map(lambda c: d[c], self.data)
+        self.data = [d[c] for c in self.data]
         self.data = array.array(self.array_indicator, self.data)
 
     def reverse_complement(self):
@@ -1797,11 +1809,11 @@ class MutableSeq(object):
         Because str(my_seq) will give you the full sequence as a python string,
         there is often no need to make an explicit conversion.  For example,
 
-        print "ID={%s}, sequence={%s}" % (my_name, my_seq)
+        print("ID={%s}, sequence={%s}" % (my_name, my_seq))
 
         On Biopython 1.44 or older you would have to have done this:
 
-        print "ID={%s}, sequence={%s}" % (my_name, my_seq.tostring())
+        print("ID={%s}, sequence={%s}" % (my_name, my_seq.tostring()))
         """
         return "".join(self.data)
 
@@ -1909,6 +1921,16 @@ def _translate_str(sequence, table, stop_symbol="*", to_stop=False,
     Traceback (most recent call last):
        ...
     TranslationError: Codon 'TA?' is invalid
+
+    In a change to older verions of Biopython, partial codons are now
+    always regarded as an error (previously only checked if cds=True)
+    and will trigger a warning (likely to become an exception in a
+    future release).
+
+    If cds=True, the start and stop codons are checked, and the start
+    codon will be translated at methionine. The sequence must be an
+    while number of codons.
+
     >>> _translate_str("ATGCCCTAG", table, cds=True)
     'MP'
     >>> _translate_str("AAACCCTAG", table, cds=True)
@@ -1930,21 +1952,29 @@ def _translate_str(sequence, table, stop_symbol="*", to_stop=False,
         #Assume the worst case, ambiguous DNA or RNA:
         valid_letters = set(IUPAC.ambiguous_dna.letters.upper() +
                             IUPAC.ambiguous_rna.letters.upper())
+    n = len(sequence)
     if cds:
         if str(sequence[:3]).upper() not in table.start_codons:
             raise CodonTable.TranslationError(
                 "First codon '%s' is not a start codon" % sequence[:3])
-        if len(sequence) % 3 != 0:
+        if n % 3 != 0:
             raise CodonTable.TranslationError(
-                "Sequence length %i is not a multiple of three" % len(sequence))
+                "Sequence length %i is not a multiple of three" % n) 
         if str(sequence[-3:]).upper() not in stop_codons:
             raise CodonTable.TranslationError(
                 "Final codon '%s' is not a stop codon" % sequence[-3:])
         #Don't translate the stop symbol, and manually translate the M
         sequence = sequence[3:-3]
+        n -= 6
         amino_acids = ["M"]
-    n = len(sequence)
-    for i in xrange(0, n-n%3, 3):
+    elif n % 3 != 0:
+        import warnings
+        from Bio import BiopythonWarning
+        warnings.warn("Partial codon, len(sequence) not a multiple of three. "
+                      "Explicitly trim the sequence or add trailing N before "
+                      "translation. This may become an error in future.",
+                      BiopythonWarning)
+    for i in range(0, n - n%3, 3):
         codon = sequence[i:i+3]
         try:
             amino_acids.append(forward_table[codon])
@@ -2092,13 +2122,14 @@ def reverse_complement(sequence):
 def _test():
     """Run the Bio.Seq module's doctests (PRIVATE)."""
     if sys.version_info[0:2] == (3, 1):
-        print "Not running Bio.Seq doctest on Python 3.1"
-        print "See http://bugs.python.org/issue7490"
+        print("Not running Bio.Seq doctest on Python 3.1")
+        print("See http://bugs.python.org/issue7490")
     else:
-        print "Running doctests..."
+        print("Running doctests...")
         import doctest
         doctest.testmod(optionflags=doctest.IGNORE_EXCEPTION_DETAIL)
-        print "Done"
+        print("Done")
 
 if __name__ == "__main__":
     _test()
+
