@@ -6,6 +6,10 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 """Represent a Sequence Record, a sequence with annotation."""
+
+
+from Bio._py3k import basestring
+
 __docformat__ = "epytext en"  # Simple markup to show doctests nicely
 
 # NEEDS TO BE SYNCH WITH THE REST OF BIOPYTHON AND BIOPERL
@@ -81,7 +85,7 @@ class _RestrictedDict(dict):
 
     def update(self, new_dict):
         #Force this to go via our strict __setitem__ method
-        for (key, value) in new_dict.iteritems():
+        for (key, value) in new_dict.items():
             self[key] = value
 
 
@@ -117,7 +121,7 @@ class SeqRecord(object):
     ...                         IUPAC.protein),
     ...                    id="YP_025292.1", name="HokC",
     ...                    description="toxic membrane protein")
-    >>> print record
+    >>> print(record)
     ID: YP_025292.1
     Name: HokC
     Description: toxic membrane protein
@@ -129,7 +133,7 @@ class SeqRecord(object):
     a string in a particular file format there is a format method which uses
     Bio.SeqIO internally:
 
-    >>> print record.format("fasta")
+    >>> print(record.format("fasta"))
     >YP_025292.1 toxic membrane protein
     MKQHKAMIVALIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF
     <BLANKLINE>
@@ -139,9 +143,9 @@ class SeqRecord(object):
     >>> len(record)
     44
     >>> edited = record[:10] + record[11:]
-    >>> print edited.seq
+    >>> print(edited.seq)
     MKQHKAMIVAIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF
-    >>> print record.seq
+    >>> print(record.seq)
     MKQHKAMIVALIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF
 
     """
@@ -249,23 +253,21 @@ class SeqRecord(object):
         variant FASTQ file as a SeqRecord:
 
         >>> from Bio import SeqIO
-        >>> handle = open("Quality/solexa_faked.fastq", "rU")
-        >>> record = SeqIO.read(handle, "fastq-solexa")
-        >>> handle.close()
-        >>> print record.id, record.seq
+        >>> record = SeqIO.read("Quality/solexa_faked.fastq", "fastq-solexa")
+        >>> print("%s %s" % (record.id, record.seq))
         slxa_0001_1_0001_01 ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNN
-        >>> print record.letter_annotations.keys()
+        >>> print(list(record.letter_annotations.keys()))
         ['solexa_quality']
-        >>> print record.letter_annotations["solexa_quality"]
+        >>> print(record.letter_annotations["solexa_quality"])
         [40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 0, -1, -2, -3, -4, -5]
 
         The letter_annotations get sliced automatically if you slice the
         parent SeqRecord, for example taking the last ten bases:
 
         >>> sub_record = record[-10:]
-        >>> print sub_record.id, sub_record.seq
+        >>> print("%s %s" % (sub_record.id, sub_record.seq))
         slxa_0001_1_0001_01 ACGTNNNNNN
-        >>> print sub_record.letter_annotations["solexa_quality"]
+        >>> print(sub_record.letter_annotations["solexa_quality"])
         [4, 3, 2, 1, 0, -1, -2, -3, -4, -5]
 
         Any python sequence (i.e. list, tuple or string) can be recorded in
@@ -342,43 +344,43 @@ class SeqRecord(object):
         ...                 id="1JOY", name="EnvZ",
         ...                 description="Homodimeric domain of EnvZ from E. coli")
         >>> rec.letter_annotations["secondary_structure"] = "  S  SSSSSSHHHHHTTTHHHHHHHHHHHHHHHHHHHHHHTHHHHHHHHHHHHHHHHHHHHHTT  "
-        >>> rec.features.append(SeqFeature(FeatureLocation(20,21),
+        >>> rec.features.append(SeqFeature(FeatureLocation(20, 21),
         ...                     type = "Site"))
 
         Now let's have a quick look at the full record,
 
-        >>> print rec
+        >>> print(rec)
         ID: 1JOY
         Name: EnvZ
         Description: Homodimeric domain of EnvZ from E. coli
         Number of features: 1
         Per letter annotation for: secondary_structure
         Seq('MAAGVKQLADDRTLLMAGVSHDLRTPLTRIRLATEMMSEQDGYLAESINKDIEE...YLR', IUPACProtein())
-        >>> print rec.letter_annotations["secondary_structure"]
+        >>> print(rec.letter_annotations["secondary_structure"])
           S  SSSSSSHHHHHTTTHHHHHHHHHHHHHHHHHHHHHHTHHHHHHHHHHHHHHHHHHHHHTT  
-        >>> print rec.features[0].location
+        >>> print(rec.features[0].location)
         [20:21]
 
         Now let's take a sub sequence, here chosen as the first (fractured)
         alpha helix which includes the histidine phosphorylation site:
 
         >>> sub = rec[11:41]
-        >>> print sub
+        >>> print(sub)
         ID: 1JOY
         Name: EnvZ
         Description: Homodimeric domain of EnvZ from E. coli
         Number of features: 1
         Per letter annotation for: secondary_structure
         Seq('RTLLMAGVSHDLRTPLTRIRLATEMMSEQD', IUPACProtein())
-        >>> print sub.letter_annotations["secondary_structure"]
+        >>> print(sub.letter_annotations["secondary_structure"])
         HHHHHTTTHHHHHHHHHHHHHHHHHHHHHH
-        >>> print sub.features[0].location
+        >>> print(sub.features[0].location)
         [9:10]
 
         You can also of course omit the start or end values, for
         example to get the first ten letters only:
 
-        >>> print rec[:10]
+        >>> print(rec[:10])
         ID: 1JOY
         Name: EnvZ
         Description: Homodimeric domain of EnvZ from E. coli
@@ -388,7 +390,7 @@ class SeqRecord(object):
 
         Or for the last ten letters:
 
-        >>> print rec[-10:]
+        >>> print(rec[-10:])
         ID: 1JOY
         Name: EnvZ
         Description: Homodimeric domain of EnvZ from E. coli
@@ -399,7 +401,7 @@ class SeqRecord(object):
         If you omit both, then you get a copy of the original record (although
         lacking the annotations and dbxrefs):
 
-        >>> print rec[:]
+        >>> print(rec[:])
         ID: 1JOY
         Name: EnvZ
         Description: Homodimeric domain of EnvZ from E. coli
@@ -434,7 +436,7 @@ class SeqRecord(object):
 
             #Don't copy the annotation dict and dbxefs list,
             #they may not apply to a subsequence.
-            #answer.annotations = dict(self.annotations.iteritems())
+            #answer.annotations = dict(self.annotations.items())
             #answer.dbxrefs = self.dbxrefs[:]
             #TODO - Review this in light of adding SeqRecord objects?
 
@@ -457,7 +459,7 @@ class SeqRecord(object):
 
             #Slice all the values to match the sliced sequence
             #(this should also work with strides, even negative strides):
-            for key, value in self.letter_annotations.iteritems():
+            for key, value in self.letter_annotations.items():
                 answer._per_letter_annotations[key] = value[index]
 
             return answer
@@ -471,25 +473,25 @@ class SeqRecord(object):
         >>> from Bio import SeqIO
         >>> record = SeqIO.read("Fasta/loveliesbleeding.pro", "fasta")
         >>> for amino in record:
-        ...     print amino
+        ...     print(amino)
         ...     if amino == "L": break
         X
         A
         G
         L
-        >>> print record.seq[3]
+        >>> print(record.seq[3])
         L
 
         This is just a shortcut for iterating over the sequence directly:
 
         >>> for amino in record.seq:
-        ...     print amino
+        ...     print(amino)
         ...     if amino == "L": break
         X
         A
         G
         L
-        >>> print record.seq[3]
+        >>> print(record.seq[3])
         L
 
         Note that this does not facilitate iteration together with any
@@ -498,15 +500,14 @@ class SeqRecord(object):
         per-letter-annotation:
 
         >>> from Bio import SeqIO
-        >>> rec = SeqIO.read(open("Quality/solexa_faked.fastq", "rU"),
-        ...                  "fastq-solexa")
-        >>> print rec.id, rec.seq
+        >>> rec = SeqIO.read("Quality/solexa_faked.fastq", "fastq-solexa")
+        >>> print("%s %s" % (rec.id, rec.seq))
         slxa_0001_1_0001_01 ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNN
-        >>> print rec.letter_annotations.keys()
+        >>> print(list(rec.letter_annotations.keys()))
         ['solexa_quality']
-        >>> for nuc, qual in zip(rec,rec.letter_annotations["solexa_quality"]):
+        >>> for nuc, qual in zip(rec, rec.letter_annotations["solexa_quality"]):
         ...     if qual > 35:
-        ...         print nuc, qual
+        ...         print("%s %i" % (nuc, qual))
         A 40
         C 39
         G 38
@@ -563,7 +564,7 @@ class SeqRecord(object):
         ...                         IUPAC.protein),
         ...                    id="YP_025292.1", name="HokC",
         ...                    description="toxic membrane protein, small")
-        >>> print str(record)
+        >>> print(str(record))
         ID: YP_025292.1
         Name: HokC
         Description: toxic membrane protein, small
@@ -573,7 +574,7 @@ class SeqRecord(object):
         In this example you don't actually need to call str explicity, as the
         print command does this automatically:
 
-        >>> print record
+        >>> print(record)
         ID: YP_025292.1
         Name: HokC
         Description: toxic membrane protein, small
@@ -620,7 +621,7 @@ class SeqRecord(object):
         ...                 id="NP_418483.1", name="b4059",
         ...                 description="ssDNA-binding protein",
         ...                 dbxrefs=["ASAP:13298", "GI:16131885", "GeneID:948570"])
-        >>> print repr(rec)
+        >>> print(repr(rec))
         SeqRecord(seq=Seq('MASRGVNKVILVGNLGQDPEVRYMPNGGAVANITLATSESWRDKATGEMKEQTE...IPF', ProteinAlphabet()), id='NP_418483.1', name='b4059', description='ssDNA-binding protein', dbxrefs=['ASAP:13298', 'GI:16131885', 'GeneID:948570'])
 
         At the python prompt you can also use this shorthand:
@@ -653,7 +654,7 @@ class SeqRecord(object):
         ...                    description="toxic membrane protein")
         >>> record.format("fasta")
         '>YP_025292.1 toxic membrane protein\nMKQHKAMIVALIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF\n'
-        >>> print record.format("fasta")
+        >>> print(record.format("fasta"))
         >YP_025292.1 toxic membrane protein
         MKQHKAMIVALIVICITAVVAALVTRKDLCEVHIRTGQTEVAVF
         <BLANKLINE>
@@ -678,6 +679,9 @@ class SeqRecord(object):
         Python 2.6/3.0.  The format_spec should be a lower case string
         supported by Bio.SeqIO as an output file format. See also the
         SeqRecord's format() method.
+
+        Under Python 3 please note that for binary formats a bytes
+        string is returned, otherwise a (unicode) string is returned.
         """
         if not format_spec:
             #Follow python convention and default to using __str__
@@ -685,16 +689,10 @@ class SeqRecord(object):
         from Bio import SeqIO
         if format_spec in SeqIO._BinaryFormats:
             #Return bytes on Python 3
-            try:
-                #This is in Python 2.6+, but we need it on Python 3
-                from io import BytesIO
-                handle = BytesIO()
-            except ImportError:
-                #Must be on Python 2.5 or older
-                from StringIO import StringIO
-                handle = StringIO()
+            from io import BytesIO
+            handle = BytesIO()
         else:
-            from StringIO import StringIO
+            from Bio._py3k import StringIO
             handle = StringIO()
         SeqIO.write(self, handle, format_spec)
         return handle.getvalue()
@@ -713,8 +711,9 @@ class SeqRecord(object):
         """
         return len(self.seq)
 
-    def __nonzero__(self):
-        """Returns True regardless of the length of the sequence.
+    #Python 3:
+    def __bool__(self):
+        """Boolean value of an instance of this class (True).
 
         This behaviour is for backwards compatibility, since until the
         __len__ method was added, a SeqRecord always evaluated as True.
@@ -728,6 +727,9 @@ class SeqRecord(object):
         """
         return True
 
+    #Python 2:
+    __nonzero__= __bool__
+
     def __add__(self, other):
         """Add another sequence or string to this sequence.
 
@@ -738,18 +740,16 @@ class SeqRecord(object):
         annotation will be lost:
 
         >>> from Bio import SeqIO
-        >>> handle = open("Quality/solexa_faked.fastq", "rU")
-        >>> record = SeqIO.read(handle, "fastq-solexa")
-        >>> handle.close()
-        >>> print record.id, record.seq
+        >>> record = SeqIO.read("Quality/solexa_faked.fastq", "fastq-solexa")
+        >>> print("%s %s" % (record.id, record.seq))
         slxa_0001_1_0001_01 ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNN
-        >>> print record.letter_annotations.keys()
+        >>> print(list(record.letter_annotations.keys()))
         ['solexa_quality']
 
         >>> new = record + "ACT"
-        >>> print new.id, new.seq
+        >>> print("%s %s" % (new.id, new.seq))
         slxa_0001_1_0001_01 ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNNACT
-        >>> print new.letter_annotations.keys()
+        >>> print(list(new.letter_annotations.keys()))
         []
 
         The new record will attempt to combine the annotation, but for any
@@ -757,10 +757,9 @@ class SeqRecord(object):
         annotation.
 
         >>> from Bio import SeqIO
-        >>> handle = open("GenBank/pBAD30.gb")
-        >>> plasmid = SeqIO.read(handle, "gb")
-        >>> handle.close()
-        >>> print plasmid.id, len(plasmid)
+        >>> with open("GenBank/pBAD30.gb") as handle:
+        ...     plasmid = SeqIO.read(handle, "gb")
+        >>> print("%s %i" % (plasmid.id, len(plasmid)))
         pBAD30 4923
 
         Now let's cut the plasmid into two pieces, and join them back up the
@@ -771,7 +770,7 @@ class SeqRecord(object):
         >>> left = plasmid[:3765]
         >>> right = plasmid[3765:]
         >>> new = right + left
-        >>> print new.id, len(new)
+        >>> print("%s %i" % (new.id, len(new)))
         pBAD30 4923
         >>> str(new.seq) == str(right.seq + left.seq)
         True
@@ -829,11 +828,11 @@ class SeqRecord(object):
             answer.name = self.name
         if self.description == other.description:
             answer.description = self.description
-        for k, v in self.annotations.iteritems():
+        for k, v in self.annotations.items():
             if k in other.annotations and other.annotations[k] == v:
                 answer.annotations[k] = v
         #Can append matching per-letter-annotation
-        for k, v in self.letter_annotations.iteritems():
+        for k, v in self.letter_annotations.items():
             if k in other.letter_annotations:
                 answer.letter_annotations[k] = v + other.letter_annotations[k]
         return answer
@@ -846,18 +845,16 @@ class SeqRecord(object):
         See the __add__ method for more details, but for example:
 
         >>> from Bio import SeqIO
-        >>> handle = open("Quality/solexa_faked.fastq", "rU")
-        >>> record = SeqIO.read(handle, "fastq-solexa")
-        >>> handle.close()
-        >>> print record.id, record.seq
+        >>> record = SeqIO.read("Quality/solexa_faked.fastq", "fastq-solexa")
+        >>> print("%s %s" % (record.id, record.seq))
         slxa_0001_1_0001_01 ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNN
-        >>> print record.letter_annotations.keys()
+        >>> print(list(record.letter_annotations.keys()))
         ['solexa_quality']
 
         >>> new = "ACT" + record
-        >>> print new.id, new.seq
+        >>> print("%s %s" % (new.id, new.seq))
         slxa_0001_1_0001_01 ACTACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNN
-        >>> print new.letter_annotations.keys()
+        >>> print(list(new.letter_annotations.keys()))
         []
         """
         if isinstance(other, SeqRecord):
@@ -883,8 +880,8 @@ class SeqRecord(object):
         >>> from Bio.SeqRecord import SeqRecord
         >>> record = SeqRecord(Seq("acgtACGT", generic_dna), id="Test",
         ...                    description = "Made up for this example")
-        >>> record.letter_annotations["phred_quality"] = [1,2,3,4,5,6,7,8]
-        >>> print record.upper().format("fastq")
+        >>> record.letter_annotations["phred_quality"] = [1, 2, 3, 4, 5, 6, 7, 8]
+        >>> print(record.upper().format("fastq"))
         @Test Made up for this example
         ACGTACGT
         +
@@ -893,7 +890,7 @@ class SeqRecord(object):
 
         Naturally, there is a matching lower method:
 
-        >>> print record.lower().format("fastq")
+        >>> print(record.lower().format("fastq"))
         @Test Made up for this example
         acgtacgt
         +
@@ -915,12 +912,12 @@ class SeqRecord(object):
 
         >>> from Bio import SeqIO
         >>> record = SeqIO.read("Fasta/aster.pro", "fasta")
-        >>> print record.format("fasta")
+        >>> print(record.format("fasta"))
         >gi|3298468|dbj|BAA31520.1| SAMIPF
         GGHVNPAVTFGAFVGGNITLLRGIVYIIAQLLGSTVACLLLKFVTNDMAVGVFSLSAGVG
         VTNALVFEIVMTFGLVYTVYATAIDPKKGSLGTIAPIAIGFIVGANI
         <BLANKLINE>
-        >>> print record.lower().format("fasta")
+        >>> print(record.lower().format("fasta"))
         >gi|3298468|dbj|BAA31520.1| SAMIPF
         gghvnpavtfgafvggnitllrgivyiiaqllgstvaclllkfvtndmavgvfslsagvg
         vtnalvfeivmtfglvytvyataidpkkgslgtiapiaigfivgani
@@ -971,26 +968,24 @@ class SeqRecord(object):
         read in as a SeqRecord:
 
         >>> from Bio import SeqIO
-        >>> handle = open("Quality/solexa_faked.fastq", "rU")
-        >>> record = SeqIO.read(handle, "fastq-solexa")
-        >>> handle.close()
-        >>> print record.id, record.seq
+        >>> record = SeqIO.read("Quality/solexa_faked.fastq", "fastq-solexa")
+        >>> print("%s %s" % (record.id, record.seq))
         slxa_0001_1_0001_01 ACGTACGTACGTACGTACGTACGTACGTACGTACGTACGTNNNNNN
-        >>> print record.letter_annotations.keys()
+        >>> print(list(record.letter_annotations.keys()))
         ['solexa_quality']
-        >>> print record.letter_annotations["solexa_quality"]
+        >>> print(record.letter_annotations["solexa_quality"])
         [40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 0, -1, -2, -3, -4, -5]
 
         Now take the reverse complement,
 
         >>> rc_record = record.reverse_complement(id=record.id+"_rc")
-        >>> print rc_record.id, rc_record.seq
+        >>> print("%s %s" % (rc_record.id, rc_record.seq))
         slxa_0001_1_0001_01_rc NNNNNNACGTACGTACGTACGTACGTACGTACGTACGTACGTACGT
 
         Notice that the per-letter-annotations have also been reversed,
         although this may not be appropriate for all cases.
 
-        >>> print rc_record.letter_annotations["solexa_quality"]
+        >>> print(rc_record.letter_annotations["solexa_quality"])
         [-5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40]
 
         Now for the features, we need a different example. Parsing a GenBank
@@ -998,10 +993,9 @@ class SeqRecord(object):
         in it...
 
         >>> from Bio import SeqIO
-        >>> handle = open("GenBank/pBAD30.gb")
-        >>> plasmid = SeqIO.read(handle, "gb")
-        >>> handle.close()
-        >>> print plasmid.id, len(plasmid)
+        >>> with open("GenBank/pBAD30.gb") as handle:
+        ...     plasmid = SeqIO.read(handle, "gb")
+        >>> print("%s %i" % (plasmid.id, len(plasmid)))
         pBAD30 4923
         >>> plasmid.seq
         Seq('GCTAGCGGAGTGTATACTGGCTTACTATGTTGGCACTGATGAGGGTGTCAGTGA...ATG', IUPACAmbiguousDNA())
@@ -1011,7 +1005,7 @@ class SeqRecord(object):
         Now, let's take the reverse complement of this whole plasmid:
 
         >>> rc_plasmid = plasmid.reverse_complement(id=plasmid.id+"_rc")
-        >>> print rc_plasmid.id, len(rc_plasmid)
+        >>> print("%s %i" % (rc_plasmid.id, len(rc_plasmid)))
         pBAD30_rc 4923
         >>> rc_plasmid.seq
         Seq('CATGGGCAAATATTATACGCAAGGCGACAAGGTGCTGATGCCGCTGGCGATTCA...AGC', IUPACAmbiguousDNA())
@@ -1022,7 +1016,7 @@ class SeqRecord(object):
         second feature (index 1) to the second last feature (index -2), its
         strand has changed, and the location switched round.
 
-        >>> print plasmid.features[1]
+        >>> print(plasmid.features[1])
         type: CDS
         location: [1081:1960](-)
         qualifiers: 
@@ -1030,7 +1024,7 @@ class SeqRecord(object):
             Key: note, Value: ['araC regulator of the arabinose BAD promoter']
             Key: vntifkey, Value: ['4']
         <BLANKLINE>
-        >>> print rc_plasmid.features[-2]
+        >>> print(rc_plasmid.features[-2])
         type: CDS
         location: [2963:3842](+)
         qualifiers: 
@@ -1069,10 +1063,10 @@ class SeqRecord(object):
         >>> from Bio.Alphabet import generic_dna
         >>> rec = SeqRecord(MutableSeq("ACGT", generic_dna), id="Test")
         >>> rec.seq[0] = "T"
-        >>> print rec.id, rec.seq
+        >>> print("%s %s" % (rec.id, rec.seq))
         Test TCGT
         >>> rc = rec.reverse_complement(id=True)
-        >>> print rc.id, rc.seq
+        >>> print("%s %s" % (rc.id, rc.seq))
         Test ACGA
         """
         from Bio.Seq import MutableSeq  # Lazy to avoid circular imports
@@ -1119,7 +1113,7 @@ class SeqRecord(object):
             answer.letter_annotations = letter_annotations
         elif letter_annotations:
             #Copy the old per letter annotations, reversing them
-            for key, value in self.letter_annotations.iteritems():
+            for key, value in self.letter_annotations.items():
                 answer._per_letter_annotations[key] = value[::-1]
         return answer
 
@@ -1127,3 +1121,5 @@ class SeqRecord(object):
 if __name__ == "__main__":
     from Bio._utils import run_doctest
     run_doctest()
+
+
