@@ -1,12 +1,13 @@
 # Copyright 2003, 2007 by Sebastian Bassi. sbassi@genesdigitales.com
-# All rights reserved.  This code is part of the Biopython 
+# All rights reserved.  This code is part of the Biopython
 # distribution and governed by its license.
 # Please see the LICENSE file that should have been included as part
 # of this package.
 
 import math
 
-def lcc_mult(seq,wsize):
+
+def lcc_mult(seq, wsize):
     """Local Composition Complexity (LCC) values over sliding window.
 
     Returns a list of floats, the LCC values for a sliding window over
@@ -25,7 +26,7 @@ def lcc_mult(seq,wsize):
         upper = seq.upper()
     except AttributeError:
         #Should be a Seq object then
-        upper = seq.tostring().upper()
+        upper = str(seq).upper()
     compone = [0]
     lccsal = [0]
     for i in range(wsize):
@@ -42,11 +43,11 @@ def lcc_mult(seq,wsize):
     term_g = compone[cant_g]
     lccsal.append(-(term_a+term_c+term_t+term_g))
     tail = seq[0]
-    for x in range (tamseq-wsize):
+    for x in range(tamseq-wsize):
         window = upper[x+1:wsize+x+1]
-        if tail==window[-1]:
+        if tail == window[-1]:
             lccsal.append(lccsal[-1])
-        elif tail=='A':
+        elif tail == 'A':
             cant_a -= 1
             if window.endswith('C'):
                 cant_c += 1
@@ -63,7 +64,7 @@ def lcc_mult(seq,wsize):
                 term_a = compone[cant_a]
                 term_g = compone[cant_g]
                 lccsal.append(-(term_a+term_c+term_t+term_g))
-        elif tail=='C':
+        elif tail == 'C':
             cant_c -= 1
             if window.endswith('A'):
                 cant_a += 1
@@ -80,7 +81,7 @@ def lcc_mult(seq,wsize):
                 term_c = compone[cant_c]
                 term_g = compone[cant_g]
                 lccsal.append(-(term_a+term_c+term_t+term_g))
-        elif tail=='T':
+        elif tail == 'T':
             cant_t -= 1
             if window.endswith('A'):
                 cant_a += 1
@@ -97,7 +98,7 @@ def lcc_mult(seq,wsize):
                 term_t = compone[cant_t]
                 term_g = compone[cant_g]
                 lccsal.append(-(term_a+term_c+term_t+term_g))
-        elif tail=='G':
+        elif tail == 'G':
             cant_g -= 1
             if window.endswith('A'):
                 cant_a += 1
@@ -117,11 +118,12 @@ def lcc_mult(seq,wsize):
         tail = window[0]
     return lccsal
 
+
 def lcc_simp(seq):
     """Local Composition Complexity (LCC) for a sequence.
 
     seq - an unambiguous DNA sequence (a string or Seq object)
-    
+
     Returns the Local Composition Complexity (LCC) value for the entire
     sequence (as a float).
 
@@ -135,7 +137,7 @@ def lcc_simp(seq):
         upper = seq.upper()
     except AttributeError:
         #Should be a Seq object then
-        upper = seq.tostring().upper()
+        upper = str(seq).upper()
     l2 = math.log(2)
     if 'A' not in seq:
         term_a = 0
