@@ -1,3 +1,8 @@
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+#
+
 from Bio import Alphabet
 COUNT = 1
 FREQ = 2
@@ -52,7 +57,7 @@ class FreqTable(dict):
 
     def _freq_from_count(self):
         total = float(sum(self.count.values()))
-        for i, v in self.count.iteritems():
+        for i, v in self.count.items():
             self[i] = v / total
 
     def _alphabet_from_input(self):
