@@ -19,6 +19,8 @@ parse             Parses the keywlist.txt file and returns an iterator to
 """
 
 
+from __future__ import print_function
+
 class Record(dict):
     """
     This record stores the information of one keyword or category in the
@@ -75,7 +77,7 @@ def parse(handle):
             elif key in ("DE", "SY", "GO", "HI", "WW"):
                 record[key].append(value)
             else:
-                print "Ignoring: %s" % line.strip()
+                print("Ignoring: %s" % line.strip())
     # Read the footer and throw it away
     for line in handle:
         pass
