@@ -2,9 +2,8 @@
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
-"""
-This module provides code to work with the sprotXX.dat file from
-SwissProt.
+"""Code to work with the sprotXX.dat file from SwissProt.
+
 http://www.expasy.ch/sprot/sprot-top.html
 
 Tested with:
@@ -21,6 +20,8 @@ parse              Read multiple SwissProt records
 
 """
 
+from __future__ import print_function
+
 from Bio._py3k import _as_string
 
 
@@ -489,10 +490,6 @@ def _read_cc(record, line):
 
 
 def _read_dr(record, value):
-    # Remove the comments at the end of the line
-    i = value.find(' [')
-    if i >= 0:
-        value = value[:i]
     cols = value.rstrip(".").split('; ')
     record.cross_references.append(tuple(cols))
 
@@ -547,22 +544,21 @@ def _read_ft(record, line):
 
 
 if __name__ == "__main__":
-    print "Quick self test..."
+    print("Quick self test...")
 
     example_filename = "../../Tests/SwissProt/sp008"
 
     import os
     if not os.path.isfile(example_filename):
-        print "Missing test file %s" % example_filename
+        print("Missing test file %s" % example_filename)
     else:
         #Try parsing it!
 
-        handle = open(example_filename)
-        records = parse(handle)
-        for record in records:
-            print record.entry_name
-            print ",".join(record.accessions)
-            print record.keywords
-            print repr(record.organism)
-            print record.sequence[:20] + "..."
-        handle.close()
+        with open(example_filename) as handle:
+            records = parse(handle)
+            for record in records:
+                print(record.entry_name)
+                print(",".join(record.accessions))
+                print(record.keywords)
+                print(repr(record.organism))
+                print(record.sequence[:20] + "...")
