@@ -1,31 +1,25 @@
+# Copyright 2001 by Katharine Lindner. All Rights Reserved.
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
 
-# Permission to use, copy, modify, and distribute this software and
-# its documentation with or without modifications and for any purpose
-# and without fee is hereby granted, provided that any copyright
-# notices appear in all copies and that both those copyright notices
-# and this permission notice appear in supporting documentation, and
-# that the names of the contributors or copyright holders not be used
-# in advertising or publicity pertaining to distribution of the software
-# without specific prior permission.
-#
-# THE CONTRIBUTORS AND COPYRIGHT HOLDERS OF THIS SOFTWARE DISCLAIM ALL
-# WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL THE
-# CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL, INDIRECT
-# OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
-# LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
-# NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
-# WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+from __future__ import print_function
+
+import warnings
+from Bio import BiopythonDeprecationWarning
+
+warnings.warn("The module Bio.UniGene.UniGene is now deprecated, "
+              "and will be removed in a future release of Biopython."
+              "To parse UniGene flat files, please use the parser in "
+              "Bio.UniGene instead",
+              BiopythonDeprecationWarning)
 
 import string
-import operator
-import urllib
 import sgmllib
 import UserDict
 import Bio.File
 
 
-
 class UniGeneParser( sgmllib.SGMLParser ):
 
     def reset( self ):
@@ -57,7 +51,7 @@ class UniGeneParser( sgmllib.SGMLParser ):
         else:
             uhandle = Bio.File.UndoHandle(handle)
         text = ''
-        while 1:
+        while True:
             line = uhandle.readline()
             line = string.strip( line )
             if( line == '' ):
@@ -66,8 +60,6 @@ class UniGeneParser( sgmllib.SGMLParser ):
 
         sgmllib.SGMLParser.feed( self, text )
 
-
-
     def handle_data(self, newtext ):
         newtext = string.strip( newtext )
         self.text = self.text + newtext
@@ -122,15 +114,13 @@ class UniGeneParser( sgmllib.SGMLParser ):
                     self.master_key = key
         elif( self.context == 'general_info' ):
             self.master_key = key
-            if( string.find( key, 'SEQUENCE' ) != -1 ):
+            if 'SEQUENCE' in key:
                 self.context = 'seq_info'
             self.queue[ key ] = UserDict.UserDict()
         elif( self.context == 'seq_info' ):
             self.queue[ key ] = UserDict.UserDict()
             self.master_key = key
 
-
-
     def start_table( self, attrs ):
         self.open_tag_stack.append( self.open_tag )
         self.open_tag = 'open_table'
@@ -158,23 +148,20 @@ class UniGeneParser( sgmllib.SGMLParser ):
             if( text[ 0 ] == ':' ):
                 text = text[ 1: ]
             text = string.join( string.split( text ) )
-            if( ( self.context == 'general_info' ) or \
-                ( self.context == 'seq_info' ) ):
+            if self.context == 'general_info' or \
+               self.context == 'seq_info':
                 try:
                     contents = self.queue[ self.master_key ][ self.key_waiting ]
-                    if( type( contents ) == type( [] ) ):
+                    if isinstance(contents, list):
                         contents.append( text )
                     else:
                         self.queue[ self.master_key ][ self.key_waiting ] = \
-                            [ contents , text ]
+                            [ contents, text ]
                 except:
                     self.queue[ self.master_key ][ self.key_waiting ] = text
 
-
                 self.key_waiting = ''
 
-
-
     def start_td( self, attrs ):
         self.open_tag_stack.append( self.open_tag )
         self.open_tag = 'open_table_data'
@@ -191,31 +178,28 @@ class UniGeneParser( sgmllib.SGMLParser ):
         indent = '    '
         for j in range( 0, level ):
             indent = indent + '    '
-        if( type( item ) == type( '' ) ):
+        if isinstance(item, str):
             if( item != '' ):
-                print '%s%s' % ( indent, item )
-        elif( type( item ) == type([])):
+                print('%s%s' % ( indent, item ))
+        elif isinstance(item, list):
             for subitem in item:
                 self.print_item( subitem, level + 1 )
         elif( isinstance( item, UserDict.UserDict ) ):
             for subitem in item:
-                print '%skey is %s' % ( indent, subitem )
+                print('%skey is %s' % ( indent, subitem ))
                 self.print_item( item[ subitem ], level + 1 )
         else:
-            print item
+            print(item)
 
     def print_tags( self ):
         for key in self.queue:
-            print 'key %s' % key
+            print('key %s' % key)
             self.print_item( self.queue[ key ] )
 
 
-
 if( __name__ == '__main__' ):
-    handle = open( 'Hs13225.htm')
-    undo_handle = Bio.File.UndoHandle( handle )
-    unigene_parser = UniGeneParser()
-    unigene_parser.parse( handle )
-    unigene_parser.print_tags()
-
-
+    with open( 'Hs13225.htm') as handle:
+        undo_handle = Bio.File.UndoHandle( handle )
+        unigene_parser = UniGeneParser()
+        unigene_parser.parse( handle )
+        unigene_parser.print_tags()
