@@ -2,13 +2,22 @@
 #include <marshal.h>
 #include "trie.h"
 
-#if PY_VERSION_HEX < 0x02050000
-#define Py_ssize_t int
+#if PY_MAJOR_VERSION >= 3
+#define IS_PY3K
 #endif
 
+/* Must define Py_TYPE for Python 2.5 or older */
+#ifndef Py_TYPE
+# define Py_TYPE(o) ((o)->ob_type)
+#endif
 
+/* Must define PyVarObject_HEAD_INIT for Python 2.5 or older */
+#ifndef PyVarObject_HEAD_INIT
+#define PyVarObject_HEAD_INIT(type, size) \
+PyObject_HEAD_INIT(type) size,
+#endif
 
-staticforward PyTypeObject Trie_Type;
+static PyTypeObject Trie_Type;
 
 typedef struct {
     PyObject_HEAD
@@ -57,14 +66,33 @@ trie_subscript(trieobject *mp, PyObject *py_key)
 {
     const char *key;
     PyObject *py_value;
+#ifdef IS_PY3K
+    PyObject* bytes;
+#endif
 
     /* Make sure key is a string. */
+#ifdef IS_PY3K
+    if(!PyUnicode_Check(py_key)) {
+#else
     if(!PyString_Check(py_key)) {
+#endif
 	PyErr_SetString(PyExc_TypeError, "key must be a string");
 	return NULL;
     }
+#ifdef IS_PY3K
+    bytes = PyUnicode_AsASCIIString(py_key);
+    if(!bytes) {
+	PyErr_SetString(PyExc_TypeError, "key must be an ASCII string");
+	return NULL;
+    }
+    key = PyBytes_AsString(bytes);
+#else
     key = PyString_AS_STRING(py_key);
+#endif
     py_value = Trie_get(mp->trie, key);
+#ifdef IS_PY3K
+    Py_DECREF(bytes);
+#endif
     if(py_value == NULL)
 	PyErr_SetString(PyExc_KeyError, key);
     else
@@ -75,15 +103,32 @@ trie_subscript(trieobject *mp, PyObject *py_key)
 static int
 trie_ass_sub(trieobject *mp, PyObject *py_key, PyObject *py_value)
 {
+    int result = -1;
     const char *key;
     PyObject *py_prev;
+#ifdef IS_PY3K
+    PyObject* bytes;
+#endif
 
     /* Make sure key is a string. */
+#ifdef IS_PY3K
+    if(!PyUnicode_Check(py_key)) {
+#else
     if(!PyString_Check(py_key)) {
+#endif
 	PyErr_SetString(PyExc_TypeError, "key must be a string");
 	return -1;
     }
+#ifdef IS_PY3K
+    bytes = PyUnicode_AsASCIIString(py_key);
+    if(!bytes) {
+	PyErr_SetString(PyExc_TypeError, "key must be an ASCII string");
+	return -1;
+    }
+    key = PyBytes_AsString(bytes);
+#else
     key = PyString_AS_STRING(py_key);
+#endif
 
     /* Check to see whether something already exists at that key.  If
        there's already an object there, then I will have to remove it.
@@ -98,21 +143,58 @@ trie_ass_sub(trieobject *mp, PyObject *py_key, PyObject *py_value)
        NULL. */
     if(!py_value) {
 	/* If the key doesn't exist, raise a KeyError. */
-	if(!py_prev) {
+	if(!py_prev)
 	    PyErr_SetString(PyExc_KeyError, key);
-	    return -1;
-	}
-	Trie_set(mp->trie, key, NULL);
+        else {
+	    Trie_set(mp->trie, key, NULL);
+            result = 0;
+        }
     }
     /* The client wants to set a key in the dictionary. */
     else {
 	Py_INCREF(py_value);
-	if(Trie_set(mp->trie, key, py_value)) {
+	if(Trie_set(mp->trie, key, py_value))
 	    PyErr_SetString(PyExc_AssertionError, "error setting trie");
-	    return -1;
-	}
+        else
+            result = 0;
     }
-    return 0;
+#ifdef IS_PY3K
+    Py_DECREF(bytes);
+#endif
+    return result;
+}
+
+static int trie_contains(trieobject *mp, PyObject* py_key)
+{
+    int result;
+#ifdef IS_PY3K
+    PyObject* bytes;
+#endif
+    const char *key;
+    /* Make sure key is a string. */
+#ifdef IS_PY3K
+    if(!PyUnicode_Check(py_key)) {
+#else
+    if(!PyString_Check(py_key)) {
+#endif
+	PyErr_SetString(PyExc_TypeError, "key must be a string");
+	return -1;
+    }
+#ifdef IS_PY3K
+    bytes = PyUnicode_AsASCIIString(py_key);
+    if(!bytes) {
+	PyErr_SetString(PyExc_TypeError, "key must be an ASCII string");
+	return -1;
+    }
+    key = PyBytes_AsString(bytes);
+#else
+    key = PyString_AS_STRING(py_key);
+#endif
+    result = Trie_has_key(mp->trie, key);
+#ifdef IS_PY3K
+    Py_DECREF(bytes);
+#endif
+    return result;
 }
 
 static char has_key__doc__[] =
@@ -121,17 +203,13 @@ static char has_key__doc__[] =
 static PyObject *
 trie_has_key(trieobject *mp, PyObject *py_key)
 {
-    const char *key;
-    int has_key;
-
-    /* Make sure key is a string. */
-    if(!PyString_Check(py_key)) {
-	PyErr_SetString(PyExc_TypeError, "key must be a string");
-	return NULL;
-    }
-    key = PyString_AS_STRING(py_key);
-    has_key = Trie_has_key(mp->trie, key);
+    int has_key = trie_contains(mp, py_key);
+    if (has_key==-1) return NULL;
+#ifdef IS_PY3K
+    return PyLong_FromLong((long)has_key);
+#else
     return PyInt_FromLong((long)has_key);
+#endif
 }
 
 static PyObject *
@@ -144,7 +222,6 @@ trie_has_key_onearg(trieobject *mp, PyObject *py_args)
 }
 
 
-
 static char has_prefix__doc__[] =
 "D.has_prefix(k) -> 1 if D has a prefix k, else 0";
 
@@ -153,15 +230,36 @@ trie_has_prefix(trieobject *mp, PyObject *py_prefix)
 {
     const char *prefix;
     int has_prefix;
+#ifdef IS_PY3K
+    PyObject* bytes;
+#endif
 
     /* Make sure prefix is a string. */
+#ifdef IS_PY3K
+    if(!PyUnicode_Check(py_prefix)) {
+#else
     if(!PyString_Check(py_prefix)) {
-	PyErr_SetString(PyExc_TypeError, "k must be a string");
+#endif
+	PyErr_SetString(PyExc_TypeError, "prefix must be a string");
 	return NULL;
     }
+#ifdef IS_PY3K
+    bytes = PyUnicode_AsASCIIString(py_prefix);
+    if(!bytes) {
+	PyErr_SetString(PyExc_TypeError, "prefix must be an ASCII string");
+	return NULL;
+    }
+    prefix = PyBytes_AsString(bytes);
+#else
     prefix = PyString_AS_STRING(py_prefix);
+#endif
     has_prefix = Trie_has_prefix(mp->trie, prefix);
+#ifdef IS_PY3K
+    Py_DECREF(bytes);
+    return PyLong_FromLong((long)has_prefix);
+#else
     return PyInt_FromLong((long)has_prefix);
+#endif
 }
 
 static PyObject *
@@ -185,7 +283,11 @@ _trie_with_prefix_helper(const char *key, const void *value, void *data)
     if(PyErr_Occurred())
 	return;
 
+#ifdef IS_PY3K
+    if(!(py_key = PyUnicode_FromFormat(key)))
+#else
     if(!(py_key = PyString_FromString(key)))
+#endif
 	return;
     PyList_Append(py_list, py_key);
     Py_DECREF(py_key);
@@ -196,18 +298,37 @@ trie_with_prefix(trieobject *mp, PyObject *py_prefix)
 {
     const char *prefix;
     PyObject *py_list;
+#ifdef IS_PY3K
+    PyObject* bytes;
+#endif
 
     /* Make sure prefix is a string. */
+#ifdef IS_PY3K
+    if(!PyUnicode_Check(py_prefix)) {
+#else
     if(!PyString_Check(py_prefix)) {
-	PyErr_SetString(PyExc_TypeError, "k must be a string");
+#endif
+	PyErr_SetString(PyExc_TypeError, "prefix must be a string");
 	return NULL;
     }
+#ifdef IS_PY3K
+    bytes = PyUnicode_AsASCIIString(py_prefix);
+    if(!bytes) {
+	PyErr_SetString(PyExc_TypeError, "prefix must be an ASCII string");
+	return NULL;
+    }
+    prefix = PyBytes_AsString(bytes);
+#else
     prefix = PyString_AS_STRING(py_prefix);
+#endif
 
     if(!(py_list = PyList_New(0)))
 	return NULL;
     Trie_with_prefix(mp->trie, prefix,
 		     _trie_with_prefix_helper, (void *)py_list);
+#ifdef IS_PY3K
+    Py_DECREF(bytes);
+#endif
     if(PyErr_Occurred()) {
 	Py_DECREF(py_list);
 	return NULL;
@@ -237,7 +358,11 @@ _trie_keys_helper(const char *key, const void *value, void *data)
     if(PyErr_Occurred())
 	return;
 
+#ifdef IS_PY3K
+    if(!(py_key = PyUnicode_FromFormat(key)))
+#else
     if(!(py_key = PyString_FromString(key)))
+#endif
 	return;
     PyList_Append(py_list, py_key);
     Py_DECREF(py_key);
@@ -341,9 +466,17 @@ _trie_get_approximate_helper(const char *key, const void *value,
     if(PyErr_Occurred())
 	return;
 
+#ifdef IS_PY3K
+    if(!(py_key = PyUnicode_FromFormat(key)))
+#else
     if(!(py_key = PyString_FromString(key)))
+#endif
 	return;
+#ifdef IS_PY3K
+    if(!(py_mismatches = PyLong_FromLong(mismatches))) {
+#else
     if(!(py_mismatches = PyInt_FromLong(mismatches))) {
+#endif
 	Py_DECREF(py_key);
 	return;
     }
@@ -391,30 +524,25 @@ trie_nohash(PyObject *self)
 }
 
 static PyMappingMethods trie_as_mapping = {
-/* The first member of PyMappingMethods was redefined in Python 2.5. */
-#if PY_VERSION_HEX < 0x02050000
-    (inquiry)trie_length,        /*mp_length*/
-#else
     (lenfunc)trie_length,        /*mp_length*/
-#endif
     (binaryfunc)trie_subscript,  /*mp_subscript*/
     (objobjargproc)trie_ass_sub  /*mp_ass_subscript*/
 };
 
-static PyMethodDef trieobj_methods[] = {
-    /*  METH_O and METH_NOARGS require Python 2.2.
-    {"has_key", (PyCFunction)trie_has_key,  METH_O,
-     has_key__doc__},
-    {"has_prefix", (PyCFunction)trie_has_prefix,  METH_O,
-     has_prefix__doc__},
-    {"with_prefix", (PyCFunction)trie_with_prefix,  METH_O,
-     with_prefix__doc__},
-    {"keys",    (PyCFunction)trie_keys,     METH_NOARGS,
-     keys__doc__},
-    {"values",  (PyCFunction)trie_values,   METH_NOARGS,
-     values__doc__},
-    */
+static PySequenceMethods trie_as_sequence = {
+    (lenfunc)trie_length,        /* sq_length */
+    NULL,                        /* sq_concat */
+    NULL,                        /* sq_repeat */
+    NULL,                        /* sq_item */
+    NULL,                        /* sq_slice */
+    NULL,                        /* sq_ass_item */
+    NULL,                        /* sq_ass_slice */
+    (objobjproc)trie_contains,   /* sq_contains */
+    NULL,                        /* sq_inplace_concat */
+    NULL                         /* sq_inplace_repeat */
+};
 
+static PyMethodDef trieobj_methods[] = {
     {"has_key", (PyCFunction)trie_has_key_onearg,  METH_VARARGS,
      has_key__doc__},
     {"has_prefix", (PyCFunction)trie_has_prefix_onearg,  METH_VARARGS,
@@ -433,28 +561,39 @@ static PyMethodDef trieobj_methods[] = {
     {NULL, NULL}   /* sentinel */
 };
 
-static PyObject *trie_getattr(PyObject *obj, const char *name)
-{
-    return Py_FindMethod(trieobj_methods, obj, name);
-
-}
-
 static PyTypeObject Trie_Type = {
-    PyObject_HEAD_INIT(NULL)
-    0,
+    PyVarObject_HEAD_INIT(NULL, 0)
     "trie",
     sizeof(trieobject),
     0,
     trie_dealloc,       /*tp_dealloc*/
     0,                  /*tp_print*/
-    (getattrfunc)trie_getattr,                  /*tp_getattr*/
+    0,                  /*tp_getattr*/
     0,                  /*tp_setattr*/
     0,                  /*tp_compare*/
     0,                  /*tp_repr*/
     0,                  /*tp_as_number*/
-    0,                  /*tp_as_sequence*/
+    &trie_as_sequence,  /*tp_as_sequence*/
     &trie_as_mapping,   /*tp_as_mapping*/
     trie_nohash,        /*tp_hash */
+    0,                  /*tp_call */
+    0,                  /* tp_str */
+    0,                  /* tp_getattro */
+    0,                  /* tp_setattro */
+    0,                  /* tp_as_buffer */
+#ifdef IS_PY3K
+    0,                  /* tp_flags */
+#else
+    Py_TPFLAGS_HAVE_SEQUENCE_IN,    /* tp_flags */
+#endif
+    0,                  /* tp_doc */
+    0,                  /* tp_traverse */
+    0,                  /* tp_clear */
+    0,                  /* tp_richcompare */
+    0,                  /* tp_weaklistoffset */
+    0,                  /* tp_iter */
+    0,                  /* tp_iternext */
+    trieobj_methods,    /* tp_methods */
 };
 
 static int
@@ -482,7 +621,8 @@ _write_to_handle(const void *towrite, const int length, void *handle)
 static int _write_value_to_handle(const void *value, void *handle)
 {
     PyObject *py_value = (PyObject *)value,
-	*py_marshalled = NULL;
+	*py_marshalled = NULL,
+        *bytes = NULL;
     char *marshalled;
     Py_ssize_t length;
     int success = 0;
@@ -495,7 +635,16 @@ static int _write_value_to_handle(const void *value, void *handle)
     if(!(py_marshalled = PyMarshal_WriteObjectToString(py_value)))
         goto _write_value_to_handle_cleanup;
 #endif
+
+#ifdef IS_PY3K
+    if (!PyBytes_Check(py_marshalled)) {
+        PyErr_SetString(PyExc_TypeError, "marshalled data expected to be bytes");
+	goto _write_value_to_handle_cleanup;
+    }
+    if(PyBytes_AsStringAndSize(py_marshalled, &marshalled, &length) == -1)
+#else
     if(PyString_AsStringAndSize(py_marshalled, &marshalled, &length) == -1)
+#endif
 	goto _write_value_to_handle_cleanup;
     if(!_write_to_handle(&length, sizeof(length), handle))
 	goto _write_value_to_handle_cleanup;
@@ -506,9 +655,8 @@ static int _write_value_to_handle(const void *value, void *handle)
     success = 1;
 
  _write_value_to_handle_cleanup:
-    if(py_marshalled) {
-	Py_DECREF(py_marshalled);
-    }
+    Py_XDECREF(py_marshalled);
+    Py_XDECREF(bytes);
 
     return success;
 }
@@ -537,55 +685,45 @@ trie_save(PyObject *self, PyObject *args)
 static int
 _read_from_handle(void *wasread, const int length, void *handle)
 {
-    PyObject *py_handle = (PyObject *)handle,
-	*py_retval = NULL;
-    void *retval;
+    PyObject *py_handle = (PyObject *)handle;
+    PyObject *py_retval = NULL;
+#ifdef IS_PY3K
+    PyObject* bytes = NULL;
+#endif
     int success = 0;
-    PyBufferProcs *buffer;
-    int segment;
-    int bytes_read, bytes_left;
+    char* buffer;
 
     if(!length) {
         PyErr_SetString(PyExc_RuntimeError, "data length is zero");
-	goto _read_from_handle_cleanup;
-     }
-
-    if(!(py_retval = PyObject_CallMethod(py_handle, "read", "i", length)))
-	goto _read_from_handle_cleanup;
-    if(!py_retval->ob_type->tp_as_buffer) {
-	PyErr_SetString(PyExc_ValueError, "read method should return buffer");
-	goto _read_from_handle_cleanup;
-    }
-    if(!(py_retval->ob_type->tp_flags & Py_TPFLAGS_DEFAULT)) {
-	PyErr_SetString(PyExc_ValueError, "no bf_getcharbuffer slot");
-	goto _read_from_handle_cleanup;
-    }
-    buffer = py_retval->ob_type->tp_as_buffer;
-    if(!buffer->bf_getreadbuffer) {
-	PyErr_SetString(PyExc_ValueError, "no bf_getreadbuffer");
-	goto _read_from_handle_cleanup;
+	return 0;
     }
 
-    bytes_left = length;
-    segment = 0;
-    while(bytes_left > 0) {
-	if((bytes_read = buffer->bf_getreadbuffer(py_retval,
-						  segment, &retval)) == -1) {
-	    PyErr_SetString(PyExc_ValueError, "failed to read from buffer");
-	    goto _read_from_handle_cleanup;
-        }
-	memcpy(wasread, retval, bytes_read);
-	wasread = (void *)((char *)wasread + bytes_read);
-	bytes_left -= bytes_read;
-	segment += 1;
+    py_retval = PyObject_CallMethod(py_handle, "read", "i", length);
+#ifdef IS_PY3K
+    if(!PyUnicode_Check(py_retval)) {
+#else
+    if(!PyString_Check(py_retval)) {
+#endif
+        PyErr_SetString(PyExc_TypeError, "expected a string");
+        goto error;
     }
-
+#ifdef IS_PY3K
+    bytes = PyUnicode_AsASCIIString(py_retval);
+    if(!bytes) {
+	PyErr_SetString(PyExc_TypeError, "expected an ASCII string");
+	goto error;
+    }
+    buffer = PyBytes_AsString(bytes);
+#else
+    buffer = PyString_AS_STRING(py_retval);
+#endif
+    memcpy(wasread, buffer, length);
     success = 1;
-
- _read_from_handle_cleanup:
-    if(py_retval) {
-	Py_DECREF(py_retval);
-    }
+error:
+#ifdef IS_PY3K
+    Py_XDECREF(bytes);
+#endif
+    Py_XDECREF(py_retval);
     return success;
 }
 
@@ -665,10 +803,44 @@ load    Load a trie from a handle.\n\
 \n\
 ";
 
-DL_EXPORT(void)
-inittrie(void)
-{
-    Trie_Type.ob_type = &PyType_Type;
+#if PY_MAJOR_VERSION >= 3
 
-    (void) Py_InitModule3("trie", trie_methods, trie__doc__);
+static struct PyModuleDef moduledef = {
+        PyModuleDef_HEAD_INIT,
+        "trie",
+        trie__doc__,
+        -1,
+        trie_methods,
+        NULL,
+        NULL,
+        NULL,
+        NULL
+};
+
+PyObject *
+PyInit_trie(void)
+
+#else
+
+void inittrie(void)
+#endif
+{
+    Py_TYPE(&Trie_Type) = &PyType_Type;
+
+    if (PyType_Ready(&Trie_Type) < 0)
+#if PY_MAJOR_VERSION >= 3
+        return NULL;
+#else
+        return;
+#endif
+
+#if PY_MAJOR_VERSION >= 3
+    return PyModule_Create(&moduledef);
+#else
+    Py_InitModule4("trie",
+                   trie_methods,
+                   trie__doc__,
+                   NULL,
+                   PYTHON_API_VERSION);
+#endif
 }
