@@ -1,6 +1,7 @@
 # Copyright 2002 by Andrew Dalke.  All rights reserved.
 # Revisions 2007-2009 copyright by Peter Cock.  All rights reserved.
 # Revisions 2009 copyright by Cymon J. Cox.  All rights reserved.
+# Revisions 2013 copyright by Tiago Antao.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -12,11 +13,13 @@
 This provides interfaces for loading biological objects from a relational
 database, and is compatible with the BioSQL standards.
 """
+import os
+
 from Bio import BiopythonDeprecationWarning
 
-import BioSeq
-import Loader
-import DBUtils
+from . import BioSeq
+from . import Loader
+from . import DBUtils
 
 _POSTGRES_RULES_PRESENT = False  # Hack for BioSQL Bug 2839
 
@@ -43,12 +46,23 @@ def open_database(driver="MySQLdb", **kwargs):
         raise ValueError("Using BioSQL with psycopg (version one) is no "
                          "longer supported. Use psycopg2 instead.")
 
-    module = __import__(driver)
+    if os.name == "java":
+        from com.ziclix.python.sql import zxJDBC
+        module = zxJDBC
+        if driver in ["MySQLdb"]:
+            jdbc_driver = "com.mysql.jdbc.Driver"
+            url_pref = "jdbc:mysql://" + kwargs["host"] + "/"
+        elif driver in ["psycopg2"]:
+            jdbc_driver = "org.postgresql.Driver"
+            url_pref = "jdbc:postgresql://" + kwargs["host"] + "/"
+
+    else:
+        module = __import__(driver)
     connect = getattr(module, "connect")
 
     # Different drivers use different keywords...
     kw = kwargs.copy()
-    if driver == "MySQLdb":
+    if driver == "MySQLdb" and os.name != "java":
         if "database" in kw:
             kw["db"] = kw["database"]
             del kw["database"]
@@ -66,7 +80,15 @@ def open_database(driver="MySQLdb", **kwargs):
     if driver in ["psycopg2", "pgdb"] and not kw.get("database"):
         kw["database"] = "template1"
     # SQLite connect takes the database name as input
-    if driver in ["sqlite3"]:
+    if os.name == "java":
+        if driver in ["MySQLdb"]:
+            conn = connect(url_pref + kw.get("database", "mysql"),
+                           kw["user"], kw["password"], jdbc_driver)
+        elif driver in ["psycopg2"]:
+            conn = connect(url_pref + kw.get("database", "postgresql") +
+                           "?stringtype=unspecified",
+                           kw["user"], kw["password"], jdbc_driver)
+    elif driver in ["sqlite3"]:
         conn = connect(kw["database"])
     else:
         try:
@@ -80,10 +102,13 @@ def open_database(driver="MySQLdb", **kwargs):
             elif "db" in kw:
                 kw["dbname"] = kw["db"]
                 del kw["db"]
-            dsn = ' '.join(['='.join(i) for i in kw.items()])
+            dsn = ' '.join('='.join(i) for i in kw.items())
             conn = connect(dsn)
 
-    server = DBServer(conn, module)
+    if os.name == "java":
+        server = DBServer(conn, module, driver)
+    else:
+        server = DBServer(conn, module)
 
     # TODO - Remove the following once BioSQL Bug 2839 is fixed.
     # Test for RULES in PostgreSQL schema, see also Bug 2833.
@@ -150,11 +175,11 @@ class DBServer:
 
         def values(self):
             """List of BioSeqDatabase objects in the database."""
-            return [self[key] for key in self.keys()]
+            return [self[key] for key in self]
 
         def items(self):
             """List of (namespace, BioSeqDatabase) for entries in the database."""
-            return [(key, self[key]) for key in self.keys()]
+            return [(key, self[key]) for key in self]
 
         def iterkeys(self):
             """Iterate over namespaces (sub-databases) in the database."""
@@ -411,6 +436,8 @@ class Adaptor:
     def execute(self, sql, args=None):
         """Just execute an sql command.
         """
+        if os.name == "java":
+            sql = sql.replace("%s", "?")
         self.dbutils.execute(self.cursor, sql, args)
 
     def get_subseq_as_string(self, seqid, start, end):
@@ -520,7 +547,7 @@ class BioSeqDatabase:
         warnings.warn("Use bio_seq_database.keys() instead of "
                       "bio_seq_database.get_all_primary_ids()",
                       BiopythonDeprecationWarning)
-        return self.keys()
+        return list(self.keys())
 
     def __getitem__(self, key):
         return BioSeq.DBSeqRecord(self.adaptor, key)
@@ -566,11 +593,11 @@ class BioSeqDatabase:
 
         def values(self):
             """List of DBSeqRecord objects in the namespace (sub database)."""
-            return [self[key] for key in self.keys()]
+            return [self[key] for key in self]
 
         def items(self):
             """List of (id, DBSeqRecord) for the namespace (sub database)."""
-            return [(key, self[key]) for key in self.keys()]
+            return [(key, self[key]) for key in self]
 
         def iterkeys(self):
             """Iterate over ids (which may not be meaningful outside this database)."""
@@ -604,10 +631,10 @@ class BioSeqDatabase:
     def lookup(self, **kwargs):
         if len(kwargs) != 1:
             raise TypeError("single key/value parameter expected")
-        k, v = kwargs.items()[0]
+        k, v = list(kwargs.items())[0]
         if k not in _allowed_lookups:
-            raise TypeError("lookup() expects one of %s, not %r" %
-                            (repr(_allowed_lookups.keys())[1:-1], repr(k)))
+            raise TypeError("lookup() expects one of %r, not %r" %
+                            (list(_allowed_lookups.keys()), k))
         lookup_name = _allowed_lookups[k]
         lookup_func = getattr(self.adaptor, lookup_name)
         seqid = lookup_func(self.dbid, v)
