@@ -16,6 +16,8 @@ classes in this module directly. Rather, call the load() method on
 a database object.
 """
 # standard modules
+from __future__ import print_function
+
 from time import gmtime, strftime
 
 # biopython
@@ -25,6 +27,8 @@ from Bio import Entrez
 from Bio.Seq import UnknownSeq
 
 from Bio._py3k import _is_int_or_long
+from Bio._py3k import range
+from Bio._py3k import basestring
 
 
 class DatabaseLoader:
@@ -56,7 +60,7 @@ class DatabaseLoader:
         self._load_comment(record, bioentry_id)
         self._load_dbxrefs(record, bioentry_id)
         references = record.annotations.get('references', ())
-        for reference, rank in zip(references, range(len(references))):
+        for reference, rank in zip(references, list(range(len(references)))):
             self._load_reference(reference, rank, bioentry_id)
         self._load_annotations(record, bioentry_id)
         for seq_feature_num in range(len(record.features)):
@@ -320,7 +324,7 @@ class DatabaseLoader:
                 return " " + letter.lower()
             else:
                 return letter
-        answer = "".join([add_space(letter) for letter in entrez_name]).strip()
+        answer = "".join(add_space(letter) for letter in entrez_name).strip()
         assert answer == answer.lower()
         return answer
 
@@ -355,7 +359,7 @@ class DatabaseLoader:
 
         taxon_id = self.adaptor.execute_and_fetch_col0(
             "SELECT taxon_id FROM taxon WHERE ncbi_taxon_id = %s",
-            (ncbi_taxon_id,))
+            (int(ncbi_taxon_id),))
         if taxon_id:
             #Good, we have mapped the NCBI taxid to a taxon table entry
             return taxon_id[0]
@@ -389,7 +393,7 @@ class DatabaseLoader:
                 species_names = [("scientific name",
                                   taxonomic_record[0]["ScientificName"])]
                 try:
-                    for name_class, names in taxonomic_record[0]["OtherNames"].iteritems():
+                    for name_class, names in taxonomic_record[0]["OtherNames"].items():
                         name_class = self._fix_name_class(name_class)
                         if not isinstance(names, list):
                             #The Entrez parser seems to return single entry
@@ -479,7 +483,7 @@ class DatabaseLoader:
                 "INSERT INTO taxon(ncbi_taxon_id, parent_taxon_id, node_rank)"
                 " VALUES (%s, %s, %s)", (ncbi_taxon_id, parent_taxon_id, rank))
         taxon_id = self.adaptor.last_id("taxon")
-        assert isinstance(taxon_id, int) or isinstance(taxon_id, long), repr(taxon_id)
+        assert isinstance(taxon_id, (int, long)), repr(taxon_id)
         # ... and its name in taxon_name
         scientific_name = taxonomic_lineage[-1].get("ScientificName", None)
         if scientific_name:
@@ -653,7 +657,7 @@ class DatabaseLoader:
                    "(bioentry_id, term_id, value, rank)" \
                    " VALUES (%s, %s, %s, %s)"
         tag_ontology_id = self._get_ontology_id('Annotation Tags')
-        for key, value in record.annotations.iteritems():
+        for key, value in record.annotations.items():
             if key in ["references", "comment", "ncbi_taxid", "date"]:
                 #Handled separately
                 continue
@@ -798,31 +802,30 @@ class DatabaseLoader:
             from Bio import BiopythonWarning
             warnings.warn("%s location operators are not fully supported"
                           % feature.location_operator, BiopythonWarning)
+        #This will be a list of length one for simple FeatureLocation:
+        parts = feature.location.parts
+        if parts and set(loc.strand for loc in parts)==set([-1]):
+            #To mimic prior behaviour of Biopython+BioSQL, reverse order
+            parts = parts[::-1]
+            #TODO - Check what BioPerl does; see also BioSeq.py code
+        for rank, loc in enumerate(parts):
+            self._insert_location(loc, rank + 1, seqfeature_id)
 
-        # two cases, a simple location or a split location
-        if not feature.sub_features:    # simple location
-            self._insert_seqfeature_location(feature, 1, seqfeature_id)
-        else:  # split location
-            for rank, cur_feature in enumerate(feature.sub_features):
-                self._insert_seqfeature_location(cur_feature,
-                                                 rank + 1,
-                                                 seqfeature_id)
-
-    def _insert_seqfeature_location(self, feature, rank, seqfeature_id):
+    def _insert_location(self, location, rank, seqfeature_id):
         """Add a location of a SeqFeature to the seqfeature_location table (PRIVATE).
 
-        TODO - Add location_operators to location_qualifier_value.
+        TODO - Add location operator to location_qualifier_value?
         """
         # convert biopython locations to the 1-based location system
         # used in bioSQL
         # XXX This could also handle fuzzies
-        start = int(feature.location.start) + 1
-        end = int(feature.location.end)
+        start = int(location.start) + 1
+        end = int(location.end)
 
         # Biopython uses None when we don't know strand information but
         # BioSQL requires something (non null) and sets this as zero
         # So we'll use the strand or 0 if Biopython spits out None
-        strand = feature.strand or 0
+        strand = location.strand or 0
 
         # TODO - Record an ontology term for the location (location.term_id)
         # which for now like BioPerl we'll leave as NULL.
@@ -830,11 +833,11 @@ class DatabaseLoader:
         # doesn't really see how it could work for before/after fuzzy positions
         loc_term_id = None
 
-        if feature.ref:
+        if location.ref:
             # sub_feature remote locations when they are in the same db as the current
             # record do not have a value for ref_db, which the SeqFeature object
             # stores as None. BioSQL schema requires a varchar and is not NULL
-            dbxref_id = self._get_dbxref_id(feature.ref_db or "", feature.ref)
+            dbxref_id = self._get_dbxref_id(location.ref_db or "", location.ref)
         else:
             dbxref_id = None
 
