@@ -1,6 +1,8 @@
 #/usr/bin/env python
 """Small script to test timing of getting records from a BioSQL database.
 """
+from __future__ import print_function
+
 import time
 # set up the connection
 from BioSQL import BioSeqDatabase
@@ -10,24 +12,25 @@ db = server["embl_rod"]
 
 # -- do the fasta-only timing part
 start_time = time.time()
-all_records = db.items()
-for junk_id, record in all_records:
+num_records = 0
+for junk_id, record in db.items():
+    num_records += 1
     sequence = record.seq.data
     d = record.description
     i = record.id
     n = record.name
 
 end_time = time.time()
-num_records = len(all_records)
 elapsed_time = end_time - start_time
-print "Fasta"
-print "\tDid %s records in %s seconds for\n\t%f records per second" % \
-      (num_records, elapsed_time, float(num_records) / float(elapsed_time))
+print("Fasta")
+print("\tDid %s records in %s seconds for\n\t%f records per second" % \
+      (num_records, elapsed_time, float(num_records) / float(elapsed_time)))
 
 # -- do the "EMBL" timing part
 start_time = time.time()
-all_records = db.items()
-for junk_id, record in all_records:
+num_records = 0
+for junk_id, record in db.items():
+    num_records += 1
     sequence = record.seq.data
     d = record.description
     i = record.id
@@ -38,8 +41,7 @@ for junk_id, record in all_records:
     species = record.species
     keywords = record.keywords
 end_time = time.time()
-num_records = len(all_records)
 elapsed_time = end_time - start_time
-print "EMBL"
-print "\tDid %s records in %s seconds for\n\t%f records per second" % \
-      (num_records, elapsed_time, float(num_records) / float(elapsed_time))
+print("EMBL")
+print("\tDid %s records in %s seconds for\n\t%f records per second" % \
+      (num_records, elapsed_time, float(num_records) / float(elapsed_time)))
