@@ -10,7 +10,8 @@
 # Jan.O.Andersson@home.se
 # File: nextorf.py
 
-import commands
+from __future__ import print_function
+
 import re
 import sys
 import os
@@ -136,8 +137,8 @@ class NextOrf:
         n = len(seq)
         start_codons = self.table.start_codons
         stop_codons = self.table.stop_codons
-#        print 'Start codons', start_codons
-#        print 'Stop codons', stop_codons
+#        print('Start codons %s' % start_codons)
+#        print('Stop codons %s' % stop_codons)
         frame_coordinates = []
         for frame in range(0, 3):
             coordinates = []
@@ -171,9 +172,9 @@ class NextOrf:
                 elif codon_type == STOP:
                     if start_site == 0:
                         continue
-#                    if codon == 'XXX': print 'do something'
+#                    if codon == 'XXX': print('do something')
                     stop = pos + 2
-#                    print stop
+#                    print("stop")
                     length = stop - start_site + 1
                     if length >= minlength and length <= maxlength:
                         if nostart == '1' and start_site == 1:
@@ -207,35 +208,36 @@ class NextOrf:
 
             if out == 'aa':
                 orf = subs.translate(table=self.genetic_code)
-                print self.ToFasta(head, orf.data)
+                print(self.ToFasta(head, orf.data))
             elif out == 'nt':
-                print self.ToFasta(head, subs.data)
+                print(self.ToFasta(head, subs.data))
             elif out == 'pos':
-                print head
+                print(head)
 
 
 def help():
     global options
-    print 'Usage:', sys.argv[0], '(<options>) <FASTA file>'
+    print('Usage: %s (<options>) <FASTA file>' % sys.argv[0])
+    print("")
+    print('Options:                                                       default')
+    print('--start       Start position in sequence                             0')
+    print('--stop        Stop position in sequence            (end of seqence)')
+    print('--minlength   Minimum length of orf in bp                          100')
+    print('--maxlength   Maximum length of orf in bp, default           100000000')
+    print('--strand      Strand to analyse [both, plus, minus]               both')
+    print('--frame       Frame to analyse [1 2 3]                             all')
+    print('--noframe     Ignore start codons [0 1]                              0')
+    print('--output      Output to generate [aa nt pos]                        aa')
+    print('--gc          Creates GC statistics of ORF [0 1]                     0')
+    print('--table       Genetic code to use (see below)                        1')
 
-    print 'Options:                                                       default'
-    print '--start       Start position in sequence                             0'
-    print '--stop        Stop position in sequence            (end of seqence)'
-    print '--minlength   Minimum length of orf in bp                          100'
-    print '--maxlength   Maximum length of orf in bp, default           100000000'
-    print '--strand      Strand to analyse [both, plus, minus]               both'
-    print '--frame       Frame to analyse [1 2 3]                             all'
-    print '--noframe     Ignore start codons [0 1]                              0'
-    print '--output      Output to generate [aa nt pos]                        aa'
-    print '--gc          Creates GC statistics of ORF [0 1]                     0'
-    print '--table       Genetic code to use (see below)                        1'
-
-#    for a,b in options.items(): print '\t', a,b
-#    print ''
-    print "\nNCBI's Codon Tables:"
+#    for a,b in options.items():
+#        print("\t%s %s" % (a, b)
+#    print("")
+    print("\nNCBI's Codon Tables:")
     for key, table in CodonTable.ambiguous_dna_by_id.items():
-        print '\t', key, table._codon_table.names[0]
-    print '\ne.g.\n./nextorf.py --minlength 5 --strand plus --output nt --gc 1 testjan.fas'
+        print('\t%s %s' % (key, table._codon_table.names[0]))
+    print('\ne.g.\n./nextorf.py --minlength 5 --strand plus --output nt --gc 1 testjan.fas')
     sys.exit(0)
 
 
@@ -257,7 +259,7 @@ if __name__ == '__main__':
     show_help = len(sys.argv) <= 1
 
     shorts = 'hv'
-    longs = map(lambda x: x + '=', options.keys()) + ['help']
+    longs = [x + '=' for x in options] + ['help']
 
     optlist, args = getopt.getopt(args, shorts, longs)
     if show_help:
@@ -267,7 +269,7 @@ if __name__ == '__main__':
         if arg[0] == '-h' or arg[0] == '--help':
             help()
             sys.exit(0)
-        for key in options.keys():
+        for key in options:
             if arg[1].lower() == 'no':
                 arg[1] = 0
             elif arg[1].lower() == 'yes':
@@ -277,7 +279,7 @@ if __name__ == '__main__':
                 options[key] = arg[1]
 
         if arg[0] == '-v':
-            print 'OPTIONS', options
+            print('OPTIONS %s' % options)
 
     file = args[0]
     nextorf = NextOrf(file, options)
