@@ -3,10 +3,15 @@
 # as part of this package.
 """Tests for dealing with storage of biopython objects in a relational db.
 """
-# standard library
+from __future__ import print_function
+
 import os
+import platform
 import unittest
-from StringIO import StringIO
+
+from Bio._py3k import StringIO
+from Bio._py3k import zip
+from Bio._py3k import basestring
 
 # Hide annoying warnings from things like bonds in GenBank features,
 # or PostgreSQL schema rules. TODO - test these warnings are raised!
@@ -31,10 +36,14 @@ if __name__ == "__main__":
     raise RuntimeError("Call this via test_BioSQL_*.py not directly")
 
 global DBDRIVER, DBTYPE, DBHOST, DBUSER, DBPASSWD, TESTDB, DBSCHEMA, SQL_FILE
+global SYSTEM
+
+SYSTEM = platform.system()
 
 
 def check_config(dbdriver, dbtype, dbhost, dbuser, dbpasswd, testdb):
-    global DBDRIVER, DBTYPE, DBHOST, DBUSER, DBPASSWD, TESTDB, DBSCHEMA, SQL_FILE
+    global DBDRIVER, DBTYPE, DBHOST, DBUSER, DBPASSWD, TESTDB, DBSCHEMA
+    global SYSTEM, SQL_FILE
     DBDRIVER = dbdriver
     DBTYPE = dbtype
     DBHOST = dbhost
@@ -43,22 +52,32 @@ def check_config(dbdriver, dbtype, dbhost, dbuser, dbpasswd, testdb):
     TESTDB = testdb
 
     #Check the database driver is installed:
-    try:
-        __import__(DBDRIVER)
-    except ImportError:
-        message = "Install %s if you want to use %s with BioSQL " % (DBDRIVER, DBTYPE)
-        raise MissingExternalDependencyError(message)
+    if SYSTEM == "Java":
+        try:
+            if DBDRIVER in ["MySQLdb"]:
+                import com.mysql.jdbc.Driver
+            elif DBDRIVER in ["psycopg2"]:
+                import org.postgresql.Driver
+        except ImportError:
+            message = "Install the JDBC driver for %s to use BioSQL " % DBTYPE
+            raise MissingExternalDependencyError(message)
+    else:
+        try:
+            __import__(DBDRIVER)
+        except ImportError:
+            message = "Install %s if you want to use %s with BioSQL " % (DBDRIVER, DBTYPE)
+            raise MissingExternalDependencyError(message)
 
     try:
         if DBDRIVER in ["sqlite3"]:
-            server = BioSeqDatabase.open_database(driver = DBDRIVER, db = TESTDB)
+            server = BioSeqDatabase.open_database(driver=DBDRIVER, db=TESTDB)
         else:
-            server = BioSeqDatabase.open_database(driver = DBDRIVER,
-                                                  user = DBUSER, passwd = DBPASSWD,
-                                                  host = DBHOST)
-            server.close()
-            del server
-    except Exception, e:
+            server = BioSeqDatabase.open_database(driver=DBDRIVER,
+                                                  user=DBUSER, passwd=DBPASSWD,
+                                                  host=DBHOST)
+        server.close()
+        del server
+    except Exception as e:
         message = "Connection failed, check settings if you plan to use BioSQL: %s" % str(e)
         raise MissingExternalDependencyError(message)
 
@@ -101,10 +120,11 @@ def _do_db_create():
         sql = r"DROP DATABASE " + TESTDB
         server.adaptor.cursor.execute(sql, ())
     except (server.module.OperationalError,
-            server.module.DatabaseError), e:  # the database doesn't exist
+            server.module.Error,
+            server.module.DatabaseError) as e:  # the database doesn't exist
         pass
     except (server.module.IntegrityError,
-            server.module.ProgrammingError), e:  # ditto--perhaps
+            server.module.ProgrammingError) as e:  # ditto--perhaps
         if str(e).find('database "%s" does not exist' % TESTDB) == -1:
             raise
     # create a new database
@@ -191,7 +211,7 @@ class ReadTest(unittest.TestCase):
         server = self.server
         self.assertTrue("biosql-test" in server)
         self.assertEqual(1, len(server))
-        self.assertEqual(["biosql-test"], server.keys())
+        self.assertEqual(["biosql-test"], list(server.keys()))
         #Check we can delete the namespace...
         del server["biosql-test"]
         self.assertEqual(0, len(server))
@@ -204,14 +224,14 @@ class ReadTest(unittest.TestCase):
     def test_get_db_items(self):
         """Check list, keys, length etc"""
         db = self.db
-        items = db.values()
-        keys = db.keys()
+        items = list(db.values())
+        keys = list(db.keys())
         l = len(items)
         self.assertEqual(l, len(db))
-        self.assertEqual(l, len(list(db.iteritems())))
-        self.assertEqual(l, len(list(db.iterkeys())))
-        self.assertEqual(l, len(list(db.itervalues())))
-        for (k1, r1), (k2, r2) in zip(zip(keys, items), db.iteritems()):
+        self.assertEqual(l, len(list(db.items())))
+        self.assertEqual(l, len(list(db.keys())))
+        self.assertEqual(l, len(list(db.values())))
+        for (k1, r1), (k2, r2) in zip(zip(keys, items), db.items()):
             self.assertEqual(k1, k2)
             self.assertEqual(r1.id, r2.id)
         for k in keys:
@@ -229,7 +249,7 @@ class ReadTest(unittest.TestCase):
         self.db.lookup(accession = "X62281")
         try:
             self.db.lookup(accession = "Not real")
-            raise Assertionerror("No problem on fake id retrieval")
+            raise AssertionError("No problem on fake id retrieval")
         except IndexError:
             pass
         self.db.lookup(display_id = "ATKIN2")
@@ -351,10 +371,10 @@ class SeqInterfaceTest(unittest.TestCase):
         test_features = self.item.features
         cds_feature = test_features[6]
         self.assertEqual(cds_feature.type, "CDS")
-        self.assertEqual(str(cds_feature.location), "[103:579](+)")
-        for sub_feature in cds_feature.sub_features:
+        self.assertEqual(str(cds_feature.location), "join{[103:160](+), [319:390](+), [503:579](+)}")
+        for sub_feature in cds_feature._sub_features:
             self.assertEqual(sub_feature.type, "CDS")
-            self.assertEqual(sub_feature.location_operator, "join")
+            #self.assertEqual(sub_feature.location_operator, "join")
 
         try:
             self.assertEqual(cds_feature.qualifiers["gene"], ["kin2"])
@@ -411,7 +431,7 @@ class LoaderTest(unittest.TestCase):
 
         # do some simple tests to make sure we actually loaded the right
         # thing. More advanced tests in a different module.
-        items = self.db.values()
+        items = list(self.db.values())
         self.assertEqual(len(items), 6)
         self.assertEqual(len(self.db), 6)
         item_names = []
@@ -451,11 +471,12 @@ class DupLoadTest(unittest.TestCase):
         record = SeqRecord(Seq("ATGCTATGACTAT", Alphabet.generic_dna), id="Test1")
         try:
             count = self.db.load([record, record])
-        except Exception, err:
+        except Exception as err:
             #Good!
             #Note we don't do a specific exception handler because the
             #exception class will depend on which DB back end is in use.
             self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "AttributeError",
                                                        "OperationalError"],
                             err.__class__.__name__)
             return
@@ -468,9 +489,11 @@ class DupLoadTest(unittest.TestCase):
         self.assertEqual(count, 1)
         try:
             count = self.db.load([record])
-        except Exception, err:
+        except Exception as err:
             #Good!
-            self.assertEqual("IntegrityError", err.__class__.__name__)
+            self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "AttributeError"],
+                            err.__class__.__name__)
             return
         raise Exception("Should have failed! Loaded %i records" % count)
 
@@ -480,9 +503,11 @@ class DupLoadTest(unittest.TestCase):
         record2 = SeqRecord(Seq("GGGATGCGACTAT", Alphabet.generic_dna), id="TestA")
         try:
             count = self.db.load([record1, record2])
-        except Exception, err:
+        except Exception as err:
             #Good!
-            self.assertEqual("IntegrityError", err.__class__.__name__)
+            self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "AttributeError"],
+                            err.__class__.__name__)
             return
         raise Exception("Should have failed! Loaded %i records" % count)
 
@@ -665,7 +690,7 @@ class InDepthLoadTest(unittest.TestCase):
         """Make sure can't reimport existing records."""
         gb_file = os.path.join(os.getcwd(), "GenBank", "cor6_6.gb")
         gb_handle = open(gb_file, "r")
-        record = SeqIO.parse(gb_handle, "gb").next()
+        record = next(SeqIO.parse(gb_handle, "gb"))
         gb_handle.close()
         #Should be in database already...
         db_record = self.db.lookup(accession = "X55053")
@@ -676,9 +701,11 @@ class InDepthLoadTest(unittest.TestCase):
         #Good... now try reloading it!
         try:
             count = self.db.load([record])
-        except Exception, err:
+        except Exception as err:
             #Good!
-            self.assertEqual("IntegrityError", err.__class__.__name__)
+            self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "AttributeError"],
+                            err.__class__.__name__)
             return
         raise Exception("Should have failed! Loaded %i records" % count)
 
@@ -710,7 +737,7 @@ class InDepthLoadTest(unittest.TestCase):
         test_feature = features[0]
         self.assertEqual(test_feature.type, "source")
         self.assertEqual(str(test_feature.location), "[0:206](+)")
-        self.assertEqual(len(test_feature.qualifiers.keys()), 3)
+        self.assertEqual(len(list(test_feature.qualifiers.keys())), 3)
         self.assertEqual(test_feature.qualifiers["country"], ["Russia:Bashkortostan"])
         self.assertEqual(test_feature.qualifiers["organism"], ["Armoracia rusticana"])
         self.assertEqual(test_feature.qualifiers["db_xref"], ["taxon:3704"])
@@ -718,15 +745,15 @@ class InDepthLoadTest(unittest.TestCase):
         # test split locations
         test_feature = features[4]
         self.assertEqual(test_feature.type, "CDS")
-        self.assertEqual(str(test_feature.location), "[0:206](+)")
-        self.assertEqual(len(test_feature.sub_features), 2)
-        self.assertEqual(str(test_feature.sub_features[0].location), "[0:48](+)")
-        self.assertEqual(test_feature.sub_features[0].type, "CDS")
-        self.assertEqual(test_feature.sub_features[0].location_operator, "join")
-        self.assertEqual(str(test_feature.sub_features[1].location), "[142:206](+)")
-        self.assertEqual(test_feature.sub_features[1].type, "CDS")
-        self.assertEqual(test_feature.sub_features[1].location_operator, "join")
-        self.assertEqual(len(test_feature.qualifiers.keys()), 6)
+        self.assertEqual(str(test_feature.location), "join{[0:48](+), [142:206](+)}")
+        self.assertEqual(len(test_feature._sub_features), 2)
+        self.assertEqual(str(test_feature._sub_features[0].location), "[0:48](+)")
+        self.assertEqual(test_feature._sub_features[0].type, "CDS")
+        #self.assertEqual(test_feature._sub_features[0].location_operator, "join")
+        self.assertEqual(str(test_feature._sub_features[1].location), "[142:206](+)")
+        self.assertEqual(test_feature._sub_features[1].type, "CDS")
+        #self.assertEqual(test_feature._sub_features[1].location_operator, "join")
+        self.assertEqual(len(list(test_feature.qualifiers.keys())), 6)
         self.assertEqual(test_feature.qualifiers["gene"], ["csp14"])
         self.assertEqual(test_feature.qualifiers["codon_start"], ["2"])
         self.assertEqual(test_feature.qualifiers["product"],
@@ -741,7 +768,7 @@ class InDepthLoadTest(unittest.TestCase):
         test_record = self.db.lookup(accession = "AJ237582")
         test_feature = test_record.features[4]  # DNA, no complement
         self.assertEqual(test_feature.strand, 1)
-        for sub_feature in test_feature.sub_features:
+        for sub_feature in test_feature._sub_features:
             self.assertEqual(sub_feature.strand, 1)
 
         test_record = self.db.lookup(accession = "X55053")
@@ -760,12 +787,12 @@ class AutoSeqIOTests(unittest.TestCase):
     def setUp(self):
         """Connect to the database."""
         db_name = "biosql-test-seqio"
-        server = BioSeqDatabase.open_database(driver = DBDRIVER,
-                                              user = DBUSER,
-                                              passwd = DBPASSWD,
-                                              host = DBHOST, db = TESTDB)
+        server = BioSeqDatabase.open_database(driver=DBDRIVER,
+                                              user=DBUSER,
+                                              passwd=DBPASSWD,
+                                              host=DBHOST, db=TESTDB)
         self.server = server
-        if db_name not in server.keys():
+        if db_name not in server:
             self.db = server.new_database(db_name)
             server.commit()
         self.db = self.server[db_name]
@@ -787,9 +814,9 @@ class AutoSeqIOTests(unittest.TestCase):
 
         iterator = SeqIO.parse(handle=open(t_filename, "r"), format=t_format)
         for record in iterator:
-            #print " - %s, %s" % (checksum_summary(record), record.id)
+            #print(" - %s, %s" % (checksum_summary(record), record.id))
             key = record.name
-            #print " - Retrieving by name/display_id '%s'," % key,
+            #print(" - Retrieving by name/display_id '%s'," % key)
             db_rec = db.lookup(name=key)
             compare_record(record, db_rec)
             db_rec = db.lookup(display_id=key)
@@ -797,7 +824,7 @@ class AutoSeqIOTests(unittest.TestCase):
 
             key = record.id
             if key.count(".") == 1 and key.split(".")[1].isdigit():
-                #print " - Retrieving by version '%s'," % key,
+                #print(" - Retrieving by version '%s'," % key)
                 db_rec = db.lookup(version=key)
                 compare_record(record, db_rec)
 
@@ -806,14 +833,14 @@ class AutoSeqIOTests(unittest.TestCase):
                 key = record.annotations["accessions"][0]
                 assert key, "Blank accession in annotation %s" % repr(record.annotations)
                 if key != record.id:
-                    #print " - Retrieving by accession '%s'," % key,
+                    #print(" - Retrieving by accession '%s'," % key)
                     db_rec = db.lookup(accession=key)
                     compare_record(record, db_rec)
 
             if "gi" in record.annotations:
                 key = record.annotations['gi']
                 if key != record.id:
-                    #print " - Retrieving by GI '%s'," % key,
+                    #print(" - Retrieving by GI '%s'," % key)
                     db_rec = db.lookup(primary_id=key)
                     compare_record(record, db_rec)
 
