@@ -3,8 +3,10 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
+from __future__ import print_function
+
 import os
-from StringIO import StringIO
+from Bio._py3k import StringIO
 from Bio import SeqIO
 from Bio import AlignIO
 from Bio.Align.Generic import Alignment
@@ -30,8 +32,8 @@ test_files = [
     ("clustal", 7, 1, 'Clustalw/opuntia.aln'),
     ("clustal", 5, 1, 'Clustalw/hedgehog.aln'),
     ("clustal", 2, 1, 'Clustalw/odd_consensus.aln'),
-    ("clustal",20, 1, 'Clustalw/protein.aln'),  # Used in the tutorial
-    ("clustal",20, 1, 'Clustalw/promals3d.aln'),  # Nonstandard header
+    ("clustal", 20, 1, 'Clustalw/protein.aln'),  # Used in the tutorial
+    ("clustal", 20, 1, 'Clustalw/promals3d.aln'),  # Nonstandard header
 #Following examples are also used in test_GFF.py
     ("fasta", 3, 1, 'GFF/multi.fna'),  # Trivial nucleotide alignment
 #Following example is also used in test_Nexus.py
@@ -41,9 +43,9 @@ test_files = [
     ("stockholm", 6, 1, 'Stockholm/funny.sth'),
     ("phylip", 6, 1, 'Phylip/reference_dna.phy'),
     ("phylip", 6, 1, 'Phylip/reference_dna2.phy'),
-    ("phylip",10, 1, 'Phylip/hennigian.phy'),
-    ("phylip",10, 1, 'Phylip/horses.phy'),
-    ("phylip",10, 1, 'Phylip/random.phy'),
+    ("phylip", 10, 1, 'Phylip/hennigian.phy'),
+    ("phylip", 10, 1, 'Phylip/horses.phy'),
+    ("phylip", 10, 1, 'Phylip/random.phy'),
     ("phylip", 3, 1, 'Phylip/interlaced.phy'),
     ("phylip", 4, 1, 'Phylip/interlaced2.phy'),
     ("phylip-relaxed", 12, 1, 'ExtendedPhylip/primates.phyx'),
@@ -63,7 +65,7 @@ test_files = [
     ("fasta-m10", 2, 1, 'Fasta/output005.m10'),
     ("fasta-m10", 2, 1, 'Fasta/output006.m10'),
     ("fasta-m10", 2, 9, 'Fasta/output007.m10'),
-    ("fasta-m10", 2, 12,'Fasta/output008.m10'),
+    ("fasta-m10", 2, 12, 'Fasta/output008.m10'),
     ("ig", 16, 1, 'IntelliGenetics/VIF_mase-pro.txt'),
     ("pir", 2, 1,  'NBRF/clustalw.pir'),
     ]
@@ -85,23 +87,23 @@ def alignment_summary(alignment, index="  ", vertical_threshold=5):
         #Show each sequence row horizontally
         for record in alignment:
             answer.append("%s%s %s"
-            % (index,str_summary(str(record.seq)),record.id))
+            % (index, str_summary(str(record.seq)), record.id))
     else:
         #Show each sequence row vertically
-        for i in range(min(5,alignment_len)):
-            answer.append(index + str_summary(alignment[:,i])
+        for i in range(min(5, alignment_len)):
+            answer.append(index + str_summary(alignment[:, i])
                                 + " alignment column %i" % i)
         if alignment_len > 5:
             i = alignment_len - 1
             answer.append(index + str_summary("|" * rec_count)
                                 + " ...")
-            answer.append(index + str_summary(alignment[:,i])
+            answer.append(index + str_summary(alignment[:, i])
                                 + " alignment column %i" % i)
     return "\n".join(answer)
 
 
 def check_simple_write_read(alignments, indent=" "):
-    #print indent+"Checking we can write and then read back these alignments"
+    #print(indent+"Checking we can write and then read back these alignments")
     for format in test_write_read_align_with_seq_count:
         records_per_alignment = len(alignments[0])
         for a in alignments:
@@ -112,7 +114,7 @@ def check_simple_write_read(alignments, indent=" "):
         and format not in test_write_read_alignment_formats:
             continue
 
-        print indent+"Checking can write/read as '%s' format" % format
+        print(indent+"Checking can write/read as '%s' format" % format)
 
         #Going to write to a handle...
         handle = StringIO()
@@ -120,10 +122,10 @@ def check_simple_write_read(alignments, indent=" "):
         try:
             c = AlignIO.write(alignments, handle=handle, format=format)
             assert c == len(alignments)
-        except ValueError, e:
+        except ValueError as e:
             #This is often expected to happen, for example when we try and
             #write sequences of different lengths to an alignment file.
-            print indent+"Failed: %s" % str(e)
+            print(indent+"Failed: %s" % str(e))
             #Carry on to the next format:
             continue
 
@@ -134,7 +136,7 @@ def check_simple_write_read(alignments, indent=" "):
             try:
                 alignments2 = list(AlignIO.parse(handle=handle, format=format,
                                                  seq_count=records_per_alignment))
-            except ValueError, e:
+            except ValueError as e:
                 #This is BAD.  We can't read our own output.
                 #I want to see the output when called from the test harness,
                 #run_tests.py (which can be funny about new lines on Windows)
@@ -149,7 +151,7 @@ def check_simple_write_read(alignments, indent=" "):
             handle.seek(0)
             try:
                 alignments2 = list(AlignIO.parse(handle=handle, format=format))
-            except ValueError, e:
+            except ValueError as e:
                 #This is BAD.  We can't read our own output.
                 #I want to see the output when called from the test harness,
                 #run_tests.py (which can be funny about new lines on Windows)
@@ -170,7 +172,7 @@ def simple_alignment_comparison(alignments, alignments2, format):
     for a1, a2 in zip(alignments, alignments2):
         assert a1.get_alignment_length() == a2.get_alignment_length()
         assert len(a1) == len(a2)
-        for r1, r2 in zip(a1,a2):
+        for r1, r2 in zip(a1, a2):
             #Check the bare minimum (ID and sequence) as
             #many formats can't store more than that.
 
@@ -180,16 +182,16 @@ def simple_alignment_comparison(alignments, alignments2, format):
             #Beware of different quirks and limitations in the
             #valid character sets and the identifier lengths!
             if format in ["phylip", "phylip-sequential"]:
-                assert r1.id.replace("[","").replace("]","")[:10] == r2.id, \
+                assert r1.id.replace("[", "").replace("]", "")[:10] == r2.id, \
                        "'%s' vs '%s'" % (r1.id, r2.id)
             elif format=="phylip-relaxed":
                 assert r1.id.replace(" ", "").replace(':', '|') == r2.id, \
                         "'%s' vs '%s'" % (r1.id, r2.id)
             elif format=="clustal":
-                assert r1.id.replace(" ","_")[:30] == r2.id, \
+                assert r1.id.replace(" ", "_")[:30] == r2.id, \
                        "'%s' vs '%s'" % (r1.id, r2.id)
             elif format=="stockholm":
-                assert r1.id.replace(" ","_") == r2.id, \
+                assert r1.id.replace(" ", "_") == r2.id, \
                        "'%s' vs '%s'" % (r1.id, r2.id)
             elif format=="fasta":
                 assert r1.id.split()[0] == r2.id
@@ -214,7 +216,7 @@ def check_phylip_reject_duplicate():
         # This should raise a ValueError
         AlignIO.write(alignment, handle, 'phylip')
         assert False, "Duplicate IDs after truncation are not allowed."
-    except ValueError, e:
+    except ValueError as e:
         # Expected - check the error
         assert "Repeated name 'longsequen'" in str(e)
 
@@ -235,7 +237,7 @@ for t_format in list(AlignIO._FormatToWriter)+list(SeqIO._FormatToWriter):
            % t_format
 
 #Check writers reject non-alignments
-list_of_records = list(AlignIO.read(open("Clustalw/opuntia.aln"),"clustal"))
+list_of_records = list(AlignIO.read(open("Clustalw/opuntia.aln"), "clustal"))
 for t_format in list(AlignIO._FormatToWriter)+list(SeqIO._FormatToWriter):
     handle = StringIO()
     try:
@@ -249,12 +251,12 @@ del list_of_records, t_format
 
 #Main tests...
 for (t_format, t_per, t_count, t_filename) in test_files:
-    print "Testing reading %s format file %s with %i alignments" \
-          % (t_format, t_filename, t_count)
+    print("Testing reading %s format file %s with %i alignments" \
+          % (t_format, t_filename, t_count))
     assert os.path.isfile(t_filename), t_filename
 
     #Try as an iterator using handle
-    alignments = list(AlignIO.parse(handle=open(t_filename,"r"), format=t_format))
+    alignments = list(AlignIO.parse(handle=open(t_filename, "r"), format=t_format))
     assert len(alignments) == t_count, \
          "Found %i alignments but expected %i" % (len(alignments), t_count)
     for alignment in alignments:
@@ -270,19 +272,19 @@ for (t_format, t_per, t_count, t_filename) in test_files:
 
     #Try using the iterator with the next() method
     alignments3 = []
-    seq_iterator = AlignIO.parse(handle=open(t_filename,"r"), format=t_format)
+    seq_iterator = AlignIO.parse(handle=open(t_filename, "r"), format=t_format)
     while True:
         try:
-            record = seq_iterator.next()
+            record = next(seq_iterator)
         except StopIteration:
             break
         assert record is not None, "Should raise StopIteration not return None"
         alignments3.append(record)
 
     #Try a mixture of next() and list (a torture test!)
-    seq_iterator = AlignIO.parse(handle=open(t_filename,"r"), format=t_format)
+    seq_iterator = AlignIO.parse(handle=open(t_filename, "r"), format=t_format)
     try:
-        record = seq_iterator.next()
+        record = next(seq_iterator)
     except StopIteration:
         record = None
     if record is not None:
@@ -293,9 +295,9 @@ for (t_format, t_per, t_count, t_filename) in test_files:
     assert len(alignments4) == t_count
 
     #Try a mixture of next() and for loop (a torture test!)
-    seq_iterator = AlignIO.parse(handle=open(t_filename,"r"), format=t_format)
+    seq_iterator = AlignIO.parse(handle=open(t_filename, "r"), format=t_format)
     try:
-        record = seq_iterator.next()
+        record = next(seq_iterator)
     except StopIteration:
         record = None
     if record is not None:
@@ -315,38 +317,38 @@ for (t_format, t_per, t_count, t_filename) in test_files:
             alignment = AlignIO.read(open(t_filename), t_format)
             assert False, "Bio.AlignIO.read(...) should have failed"
         except ValueError:
-            #Expected to fail
+            # Expected to fail
             pass
 
-    #Print the alignment
-    for i,alignment in enumerate(alignments):
+    # Show the alignment
+    for i, alignment in enumerate(alignments):
         if i < 3 or i+1 == t_count:
-            print " Alignment %i, with %i sequences of length %i" \
+            print(" Alignment %i, with %i sequences of length %i" \
                   % (i,
                      len(alignment),
-                     alignment.get_alignment_length())
-            print alignment_summary(alignment)
+                     alignment.get_alignment_length()))
+            print(alignment_summary(alignment))
         elif i==3:
-            print " ..."
+            print(" ...")
 
-    #Check AlignInfo.SummaryInfo likes the alignment
+    # Check AlignInfo.SummaryInfo likes the alignment
     summary = AlignInfo.SummaryInfo(alignment)
     dumb_consensus = summary.dumb_consensus()
     #gap_consensus = summary.gap_consensus()
     if t_format != "nexus":
-        #Hack for bug 2535
+        # Hack for bug 2535
         pssm = summary.pos_specific_score_matrix()
         rep_dict = summary.replacement_dictionary()
         try:
             info_content = summary.information_content()
-        except ValueError, e:
+        except ValueError as e:
             if str(e) != "Error in alphabet: not Nucleotide or Protein, supply expected frequencies":
                 raise e
             pass
 
-    if t_count==1 and t_format not in ["nexus","emboss","fasta-m10"]:
-        #print " Trying to read a triple concatenation of the input file"
-        data = open(t_filename,"r").read()
+    if t_count==1 and t_format not in ["nexus", "emboss", "fasta-m10"]:
+        #print(" Trying to read a triple concatenation of the input file")
+        data = open(t_filename, "r").read()
         handle = StringIO()
         handle.write(data + "\n\n" + data + "\n\n" + data)
         handle.seek(0)
@@ -359,4 +361,4 @@ for (t_format, t_per, t_count, t_filename) in test_files:
     alignments.reverse()
     check_simple_write_read(alignments)
 
-print "Finished tested reading files"
+print("Finished tested reading files")
