@@ -7,6 +7,8 @@
 Created to check for any regressions from my new implementation of the
 parser.
 """
+from __future__ import print_function
+
 import os
 from Bio import AlignIO
 
@@ -26,19 +28,19 @@ test_files = [
     ("fasta-m10", 2, 1, 'Fasta/output005.m10'),
     ("fasta-m10", 2, 1, 'Fasta/output006.m10'),
     ("fasta-m10", 2, 9, 'Fasta/output007.m10'),
-    ("fasta-m10", 2, 12,'Fasta/output008.m10'),
+    ("fasta-m10", 2, 12, 'Fasta/output008.m10'),
     ]
 
 #Main tests...
 for (t_format, t_per, t_count, t_filename) in test_files:
     assert t_format == "fasta-m10" and t_per == 2
 
-    print "Testing reading %s format file %s with %i alignments" \
-          % (t_format, t_filename, t_count)
+    print("Testing reading %s format file %s with %i alignments" \
+          % (t_format, t_filename, t_count))
     assert os.path.isfile(t_filename), t_filename
 
     #Try as an iterator using handle
-    alignments = list(AlignIO.parse(handle=open(t_filename,"r"), format=t_format))
+    alignments = list(AlignIO.parse(handle=open(t_filename, "r"), format=t_format))
     assert len(alignments) == t_count, \
          "Found %i alignments but expected %i" % (len(alignments), t_count)
     for alignment in alignments:
@@ -47,25 +49,25 @@ for (t_format, t_per, t_count, t_filename) in test_files:
             % (t_per, len(alignment))
 
     #Print the alignment
-    for i,alignment in enumerate(alignments):
-        print "="*78
-        print "Alignment %i, with %i sequences of length %i" \
+    for i, alignment in enumerate(alignments):
+        print("="*78)
+        print("Alignment %i, with %i sequences of length %i" \
               % (i,
                  len(alignment),
-                 alignment.get_alignment_length())
+                 alignment.get_alignment_length()))
         for k in sorted(alignment._annotations):
-            print " - %s: %r" % (k, alignment._annotations[k])
+            print(" - %s: %r" % (k, alignment._annotations[k]))
         assert alignment[0].name == "query"
         assert alignment[1].name == "match"
         #Show each sequence row horizontally
         for record in alignment:
-            print "-"*78
-            print record.id
-            print record.description
-            print repr(record.seq)
+            print("-"*78)
+            print(record.id)
+            print(record.description)
+            print(repr(record.seq))
             assert not record.features
             assert not record.letter_annotations
             for k in sorted(record.annotations):
-                print " - %s: %r" % (k, record.annotations[k])
-    print "="*78
-print "Finished tested reading files"
+                print(" - %s: %r" % (k, record.annotations[k]))
+    print("="*78)
+print("Finished tested reading files")
