@@ -80,7 +80,7 @@ class TestCluster(unittest.TestCase):
                   [ 12.1, 92.0, 90.0, 95.0, 90.0 ]]
 
         # Matrix with bad cells
-        data4 = [  [ 7.1, 7.2, 7.3, 7.4, 7.5, ],
+        data4 = [  [ 7.1, 7.2, 7.3, 7.4, 7.5 ],
                    [ 7.1, 7.2, 7.3, 7.4, 'snoopy' ],
                    [ 7.1, 7.2, 7.3, None, None]]
 
@@ -91,7 +91,7 @@ class TestCluster(unittest.TestCase):
 
         # Various references that don't point to matrices at all
         data6 = "snoopy"
-        data7 = {'a': [[2.3,1.2],[3.3,5.6]]}
+        data7 = {'a': [[2.3, 1.2], [3.3, 5.6]]}
         data8 = []
         data9 = [None]
 
@@ -121,7 +121,7 @@ class TestCluster(unittest.TestCase):
 
         nclusters = 3
         # First data set
-        weight = numpy.array([1,1,1,1,1])
+        weight = numpy.array([1, 1, 1, 1, 1])
         data = numpy.array([[ 1.1, 2.2, 3.3, 4.4, 5.5],
                             [ 3.1, 3.2, 1.3, 2.4, 1.5],
                             [ 4.1, 2.2, 0.3, 5.4, 0.5],
@@ -137,13 +137,13 @@ class TestCluster(unittest.TestCase):
                                             method='a', dist='e')
         self.assertEqual(len(clusterid), len(data))
 
-        correct = [0,1,1,2]
+        correct = [0, 1, 1, 2]
         mapping = [clusterid[correct.index(i)] for i in range(nclusters)]
         for i in range(len(clusterid)):
             self.assertEqual(clusterid[i], mapping[correct[i]])
 
         # Second data set
-        weight = numpy.array([1,1])
+        weight = numpy.array([1, 1])
         data = numpy.array([[ 1.1, 1.2 ],
                       [ 1.4, 1.3 ],
                       [ 1.1, 1.5 ],
@@ -188,11 +188,11 @@ class TestCluster(unittest.TestCase):
             from Pycluster import clusterdistance
 
         # First data set
-        weight = numpy.array([ 1,1,1,1,1 ])
-        data = numpy.array([[  1.1, 2.2, 3.3, 4.4, 5.5, ],
-                            [  3.1, 3.2, 1.3, 2.4, 1.5, ],
-                            [  4.1, 2.2, 0.3, 5.4, 0.5, ],
-                            [ 12.1, 2.0, 0.0, 5.0, 0.0, ]])
+        weight = numpy.array([ 1, 1, 1, 1, 1 ])
+        data = numpy.array([[  1.1, 2.2, 3.3, 4.4, 5.5 ],
+                            [  3.1, 3.2, 1.3, 2.4, 1.5 ],
+                            [  4.1, 2.2, 0.3, 5.4, 0.5 ],
+                            [ 12.1, 2.0, 0.0, 5.0, 0.0 ]])
         mask = numpy.array([[ 1, 1, 1, 1, 1],
                             [ 1, 1, 1, 1, 1],
                             [ 1, 1, 1, 1, 1],
@@ -200,7 +200,7 @@ class TestCluster(unittest.TestCase):
 
         # Cluster assignments
         c1 = [0]
-        c2 = [1,2]
+        c2 = [1, 2]
         c3 = [3]
 
         distance = clusterdistance(data, mask=mask, weight=weight,
@@ -217,7 +217,7 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(distance, 15.118, places=3)
 
         # Second data set
-        weight = numpy.array([ 1,1 ])
+        weight = numpy.array([ 1, 1 ])
         data = numpy.array([[ 1.1, 1.2 ],
                          [ 1.4, 1.3 ],
                          [ 1.1, 1.5 ],
@@ -270,7 +270,7 @@ class TestCluster(unittest.TestCase):
             from Pycluster import treecluster
 
         # First data set
-        weight1 = [ 1,1,1,1,1 ]
+        weight1 = [ 1, 1, 1, 1, 1 ]
         data1 = numpy.array([   [  1.1, 2.2, 3.3, 4.4, 5.5],
                                 [  3.1, 3.2, 1.3, 2.4, 1.5],
                                 [  4.1, 2.2, 0.3, 5.4, 0.5],
@@ -338,7 +338,7 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(tree[2].distance, 32.508, places=3)
 
         # Second data set
-        weight2 = [ 1,1 ]
+        weight2 = [ 1, 1 ]
         data2 = numpy.array([[ 0.8223, 0.9295 ],
                              [ 1.4365, 1.3223 ],
                              [ 1.1623, 1.5364 ],
@@ -538,7 +538,7 @@ class TestCluster(unittest.TestCase):
             from Pycluster import somcluster
 
         # First data set
-        weight = [ 1,1,1,1,1 ]
+        weight = [ 1, 1, 1, 1, 1 ]
         data = numpy.array([[  1.1, 2.2, 3.3, 4.4, 5.5],
                             [  3.1, 3.2, 1.3, 2.4, 1.5],
                             [  4.1, 2.2, 0.3, 5.4, 0.5],
@@ -555,7 +555,7 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(clusterid[0]), 2)
 
         # Second data set
-        weight = [ 1,1 ]
+        weight = [ 1, 1 ]
         data = numpy.array([[ 1.1, 1.2 ],
                             [ 1.4, 1.3 ],
                             [ 1.1, 1.5 ],
@@ -695,36 +695,36 @@ class TestCluster(unittest.TestCase):
         mean, coordinates, pc, eigenvalues = pca(data)
         self.assertAlmostEqual(mean[0], 3.5461538461538464)
         self.assertAlmostEqual(mean[1], 3.5307692307692311)
-        self.assertAlmostEqual(coordinates[0,0],  2.0323189722653883)
-        self.assertAlmostEqual(coordinates[0,1],  1.2252420399694917)
-        self.assertAlmostEqual(coordinates[1,0],  3.0936985166252251)
-        self.assertAlmostEqual(coordinates[1,1], -0.10647619705157851)
-        self.assertAlmostEqual(coordinates[2,0],  3.1453186907749426)
-        self.assertAlmostEqual(coordinates[2,1], -0.46331699855941139)
-        self.assertAlmostEqual(coordinates[3,0],  2.5440202962223761)
-        self.assertAlmostEqual(coordinates[3,1],  0.20633980959571077)
-        self.assertAlmostEqual(coordinates[4,0],  2.4468278463376221)
-        self.assertAlmostEqual(coordinates[4,1], -0.28412285736824866)
-        self.assertAlmostEqual(coordinates[5,0],  2.4468278463376221)
-        self.assertAlmostEqual(coordinates[5,1], -0.28412285736824866)
-        self.assertAlmostEqual(coordinates[6,0], -3.2018619434743254)
-        self.assertAlmostEqual(coordinates[6,1],  0.019692314198662915)
-        self.assertAlmostEqual(coordinates[7,0], -3.2018619434743254)
-        self.assertAlmostEqual(coordinates[7,1],  0.019692314198662915)
-        self.assertAlmostEqual(coordinates[8,0],  0.46978641990344067)
-        self.assertAlmostEqual(coordinates[8,1], -0.17778754731982949)
-        self.assertAlmostEqual(coordinates[9,0], -2.5549912731867215)
-        self.assertAlmostEqual(coordinates[9,1],  0.19733897451533403)
-        self.assertAlmostEqual(coordinates[10,0], -2.5033710990370044)
-        self.assertAlmostEqual(coordinates[10,1], -0.15950182699250004)
-        self.assertAlmostEqual(coordinates[11,0], -2.4365601663089413)
-        self.assertAlmostEqual(coordinates[11,1], -0.23390813900973562)
-        self.assertAlmostEqual(coordinates[12,0], -2.2801521629852974)
-        self.assertAlmostEqual(coordinates[12,1],  0.0409309711916888)
-        self.assertAlmostEqual(pc[0,0], -0.66810932728062988)
-        self.assertAlmostEqual(pc[0,1], -0.74406312017235743)
-        self.assertAlmostEqual(pc[1,0],  0.74406312017235743)
-        self.assertAlmostEqual(pc[1,1], -0.66810932728062988)
+        self.assertAlmostEqual(coordinates[0, 0],  2.0323189722653883)
+        self.assertAlmostEqual(coordinates[0, 1],  1.2252420399694917)
+        self.assertAlmostEqual(coordinates[1, 0],  3.0936985166252251)
+        self.assertAlmostEqual(coordinates[1, 1], -0.10647619705157851)
+        self.assertAlmostEqual(coordinates[2, 0],  3.1453186907749426)
+        self.assertAlmostEqual(coordinates[2, 1], -0.46331699855941139)
+        self.assertAlmostEqual(coordinates[3, 0],  2.5440202962223761)
+        self.assertAlmostEqual(coordinates[3, 1],  0.20633980959571077)
+        self.assertAlmostEqual(coordinates[4, 0],  2.4468278463376221)
+        self.assertAlmostEqual(coordinates[4, 1], -0.28412285736824866)
+        self.assertAlmostEqual(coordinates[5, 0],  2.4468278463376221)
+        self.assertAlmostEqual(coordinates[5, 1], -0.28412285736824866)
+        self.assertAlmostEqual(coordinates[6, 0], -3.2018619434743254)
+        self.assertAlmostEqual(coordinates[6, 1],  0.019692314198662915)
+        self.assertAlmostEqual(coordinates[7, 0], -3.2018619434743254)
+        self.assertAlmostEqual(coordinates[7, 1],  0.019692314198662915)
+        self.assertAlmostEqual(coordinates[8, 0],  0.46978641990344067)
+        self.assertAlmostEqual(coordinates[8, 1], -0.17778754731982949)
+        self.assertAlmostEqual(coordinates[9, 0], -2.5549912731867215)
+        self.assertAlmostEqual(coordinates[9, 1],  0.19733897451533403)
+        self.assertAlmostEqual(coordinates[10, 0], -2.5033710990370044)
+        self.assertAlmostEqual(coordinates[10, 1], -0.15950182699250004)
+        self.assertAlmostEqual(coordinates[11, 0], -2.4365601663089413)
+        self.assertAlmostEqual(coordinates[11, 1], -0.23390813900973562)
+        self.assertAlmostEqual(coordinates[12, 0], -2.2801521629852974)
+        self.assertAlmostEqual(coordinates[12, 1],  0.0409309711916888)
+        self.assertAlmostEqual(pc[0, 0], -0.66810932728062988)
+        self.assertAlmostEqual(pc[0, 1], -0.74406312017235743)
+        self.assertAlmostEqual(pc[1, 0],  0.74406312017235743)
+        self.assertAlmostEqual(pc[1, 1], -0.66810932728062988)
         self.assertAlmostEqual(eigenvalues[0], 9.3110471246032844)
         self.assertAlmostEqual(eigenvalues[1], 1.4437456297481428)
 
@@ -739,34 +739,34 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(mean[3], 6.0500)
         self.assertAlmostEqual(mean[4], 6.2750)
         self.assertAlmostEqual(mean[5], 8.0750)
-        self.assertAlmostEqual(coordinates[0,0],  2.6460846688406905)
-        self.assertAlmostEqual(coordinates[0,1], -2.1421701432732418)
-        self.assertAlmostEqual(coordinates[0,2], -0.56620932754145858)
-        self.assertAlmostEqual(coordinates[0,3],  0.0)
-        self.assertAlmostEqual(coordinates[1,0],  2.0644120899917544)
-        self.assertAlmostEqual(coordinates[1,1],  0.55542108669180323)
-        self.assertAlmostEqual(coordinates[1,2],  1.4818772348457117)
-        self.assertAlmostEqual(coordinates[1,3],  0.0)
-        self.assertAlmostEqual(coordinates[2,0],  1.0686641862092987)
-        self.assertAlmostEqual(coordinates[2,1],  1.9994412069101073)
-        self.assertAlmostEqual(coordinates[2,2], -1.000720598980291)
-        self.assertAlmostEqual(coordinates[2,3],  0.0)
-        self.assertAlmostEqual(coordinates[3,0], -5.77916094504174)
-        self.assertAlmostEqual(coordinates[3,1], -0.41269215032867046)
-        self.assertAlmostEqual(coordinates[3,2],  0.085052691676038017)
-        self.assertAlmostEqual(coordinates[3,3],  0.0)
-        self.assertAlmostEqual(pc[0,0], -0.26379660005997291)
-        self.assertAlmostEqual(pc[0,1],  0.064814972617134495)
-        self.assertAlmostEqual(pc[0,2], -0.91763310094893846)
-        self.assertAlmostEqual(pc[0,3],  0.26145408875373249)
-        self.assertAlmostEqual(pc[1,0],  0.05073770520434398)
-        self.assertAlmostEqual(pc[1,1],  0.68616983388698793)
-        self.assertAlmostEqual(pc[1,2],  0.13819106187213354)
-        self.assertAlmostEqual(pc[1,3],  0.19782544121828985)
-        self.assertAlmostEqual(pc[2,0], -0.63000893660095947)
-        self.assertAlmostEqual(pc[2,1],  0.091155993862151397)
-        self.assertAlmostEqual(pc[2,2],  0.045630391256086845)
-        self.assertAlmostEqual(pc[2,3], -0.67456694780914772)
+        self.assertAlmostEqual(coordinates[0, 0],  2.6460846688406905)
+        self.assertAlmostEqual(coordinates[0, 1], -2.1421701432732418)
+        self.assertAlmostEqual(coordinates[0, 2], -0.56620932754145858)
+        self.assertAlmostEqual(coordinates[0, 3],  0.0)
+        self.assertAlmostEqual(coordinates[1, 0],  2.0644120899917544)
+        self.assertAlmostEqual(coordinates[1, 1],  0.55542108669180323)
+        self.assertAlmostEqual(coordinates[1, 2],  1.4818772348457117)
+        self.assertAlmostEqual(coordinates[1, 3],  0.0)
+        self.assertAlmostEqual(coordinates[2, 0],  1.0686641862092987)
+        self.assertAlmostEqual(coordinates[2, 1],  1.9994412069101073)
+        self.assertAlmostEqual(coordinates[2, 2], -1.000720598980291)
+        self.assertAlmostEqual(coordinates[2, 3],  0.0)
+        self.assertAlmostEqual(coordinates[3, 0], -5.77916094504174)
+        self.assertAlmostEqual(coordinates[3, 1], -0.41269215032867046)
+        self.assertAlmostEqual(coordinates[3, 2],  0.085052691676038017)
+        self.assertAlmostEqual(coordinates[3, 3],  0.0)
+        self.assertAlmostEqual(pc[0, 0], -0.26379660005997291)
+        self.assertAlmostEqual(pc[0, 1],  0.064814972617134495)
+        self.assertAlmostEqual(pc[0, 2], -0.91763310094893846)
+        self.assertAlmostEqual(pc[0, 3],  0.26145408875373249)
+        self.assertAlmostEqual(pc[1, 0],  0.05073770520434398)
+        self.assertAlmostEqual(pc[1, 1],  0.68616983388698793)
+        self.assertAlmostEqual(pc[1, 2],  0.13819106187213354)
+        self.assertAlmostEqual(pc[1, 3],  0.19782544121828985)
+        self.assertAlmostEqual(pc[2, 0], -0.63000893660095947)
+        self.assertAlmostEqual(pc[2, 1],  0.091155993862151397)
+        self.assertAlmostEqual(pc[2, 2],  0.045630391256086845)
+        self.assertAlmostEqual(pc[2, 3], -0.67456694780914772)
         # As the last eigenvalue is zero, the corresponding eigenvector is
         # strongly affected by roundoff error, and is not being tested here.
         # For PCA, this doesn't matter since all data have a zero coefficient
