@@ -3,12 +3,12 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-from __future__ import with_statement
+from __future__ import print_function
 
 import os.path
 import unittest
 import shutil
-from StringIO import StringIO
+from Bio._py3k import StringIO
 import tempfile
 
 from Bio import File
@@ -24,33 +24,33 @@ file"""
 
 h = File.UndoHandle(StringIO(data))
 
-print h.readline()   # 'This'
-print h.peekline()   # 'is'
-print h.readline()   # 'is'
+print(h.readline())   # 'This'
+print(h.peekline())   # 'is'
+print(h.readline())   # 'is'
 h.saveline("saved")
-print h.peekline()   # 'saved'
+print(h.peekline())   # 'saved'
 h.saveline("another")
-print h.readline()   # 'another'
-print h.readline()   # 'saved'
+print(h.readline())   # 'another'
+print(h.readline())   # 'saved'
 
 # Test readlines after saveline
 h.saveline("saved again")
 lines = h.readlines()
-print repr(lines[0])   # 'saved again'
-print repr(lines[1])   # 'a multi-line'
-print repr(lines[2])   # 'file'
+print(repr(lines[0]))   # 'saved again'
+print(repr(lines[1]))   # 'a multi-line'
+print(repr(lines[2]))   # 'file'
 
 # should be empty now
-print repr(h.readline())       # ''
+print(repr(h.readline()))       # ''
 
 h.saveline("save after empty")
-print h.readline()             # 'save after empty'
-print repr(h.readline())       # ''
+print(h.readline())             # 'save after empty'
+print(repr(h.readline()))       # ''
 
 # test read method
 h = File.UndoHandle(StringIO("some text"))
 h.saveline("more text")
-print h.read()                 # 'more textsome text'
+print(h.read())                 # 'more textsome text'
 
 
 class AsHandleTestCase(unittest.TestCase):
