@@ -17,7 +17,6 @@ from Bio.GA.Organism import Organism
 from Bio.GA.Repair.Stabilizing import AmbiguousRepair
 
 
-
 class TestAlphabet(Alphabet):
     """Simple test alphabet.
     """
@@ -25,14 +24,16 @@ class TestAlphabet(Alphabet):
                         "2": "2",
                         "3": "3",
                         "*": "123"}
-                        
+
     letters = ["1", "2", "3", "*"]
 
+
 def test_fitness(genome):
     """Simple class for calculating fitnesses.
     """
     return 1
 
+
 class AmbiguousRepairTest(unittest.TestCase):
     """Test for the ability to repair too many ambiguous genes in a genome.
     """
@@ -40,7 +41,6 @@ class AmbiguousRepairTest(unittest.TestCase):
         alphabet = TestAlphabet()
         test_genome = MutableSeq("11*22*33*", alphabet)
         self.organism = Organism(test_genome, test_fitness)
-        
         self.ambig_info = Schema(alphabet.alphabet_matches)
 
     def test_single_repair(self):
@@ -53,7 +53,7 @@ class AmbiguousRepairTest(unittest.TestCase):
             new_genome_seq = new_org.genome.toseq()
 
             assert new_genome_seq.count("*") == 2, \
-                   "Did not repair genome, got %s" % new_genome_seq.tostring()
+                   "Did not repair genome, got %s" % str(new_genome_seq)
 
     def test_multiple_repair(self):
         """Test repair of multiple ambiguous positions in a genome.
@@ -65,7 +65,7 @@ class AmbiguousRepairTest(unittest.TestCase):
             new_genome_seq = new_org.genome.toseq()
 
             assert new_genome_seq.count("*") == 0, \
-                   "Did not repair genome, got %s" % new_genome_seq.tostring()
+                   "Did not repair genome, got %s" % str(new_genome_seq)
 
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity = 2)
