@@ -24,14 +24,16 @@ from Bio.GA.Selection.RouletteWheel import RouletteWheelSelection
 
 class TestAlphabet(SingleLetterAlphabet):
     """Simple test alphabet.
-    """                        
+    """
     letters = ["0", "1", "2", "3"]
 
+
 def test_fitness(genome):
     """Simple class for calculating fitnesses.
     """
     genome_seq = genome.toseq()
-    return int(genome_seq.tostring())
+    return int(str(genome_seq))
+
 
 class NoSelection:
     """A simple 'selection' class that just returns the generated population.
@@ -39,24 +41,28 @@ class NoSelection:
     def select(self, population):
         return population
 
+
 class NoMutation:
     """Simple 'mutation' class that doesn't do anything.
     """
     def mutate(self, org):
         return org.copy()
 
+
 class NoCrossover:
     """Simple 'crossover' class that doesn't do anything.
     """
     def do_crossover(self, org_1, org_2):
         return org_1.copy(), org_2.copy()
 
+
 class NoRepair:
     """Simple 'repair' class that doesn't do anything.
     """
     def repair(self, org):
         return org.copy()
 
+
 def random_genome():
     """Return a random genome string.
     """
@@ -68,12 +74,14 @@ def random_genome():
 
     return MutableSeq(new_genome, alphabet)
 
+
 def random_organism():
     """Generate a random organism.
     """
     genome = random_genome()
     return Organism(genome, test_fitness)
 
+
 # --- the actual test classes
 
 class DiversitySelectionTest(unittest.TestCase):
@@ -114,6 +122,7 @@ class DiversitySelectionTest(unittest.TestCase):
         self.assertEqual(len(new_pop), len(pop),
                          "Did not maintain population size.")
 
+
 class TournamentSelectionTest(unittest.TestCase):
     """Test selection based on a tournament style scheme.
     """
@@ -134,7 +143,7 @@ class TournamentSelectionTest(unittest.TestCase):
         if org_2.fitness > org_1.fitness:
             org_1, org_2 = org_2, org_1
         self.assertTrue(org_1.fitness > org_2.fitness)
-        
+
         pop = [org_1, org_2]
         new_pop = self.selector.select(pop)
         for org in new_pop:
@@ -189,7 +198,7 @@ class RouletteWheelSelectionTest(unittest.TestCase):
         self.assertEqual(len(new_pop), len(pop),
                          "Did not maintain population size.")
 
-        
+
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity = 2)
     unittest.main(testRunner=runner)
