@@ -4,6 +4,8 @@
 Also tests Training methods.
 """
 # standard modules
+from __future__ import print_function
+
 import unittest
 import math
 
@@ -379,7 +381,7 @@ class ScaledDPAlgorithmsTest(unittest.TestCase):
                          ('2', 0) : .7}
         s_value = self.dp._calculate_s_value(1, previous_vars)
 
-        # print s_value
+        # print(s_value)
 
 
 class AbstractTrainerTest(unittest.TestCase):
