@@ -18,7 +18,7 @@ class KeyWListTest(unittest.TestCase):
         records = KeyWList.parse(handle)
 
         # Testing the first record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record["ID"], "2Fe-2S.")
         self.assertEqual(record["AC"], "KW-0001")
         self.assertEqual(record["DE"], "Protein which contains at least one 2Fe-2S iron-sulfur cluster: 2 iron atoms complexed to 2 inorganic sulfides and 4 sulfur atoms of cysteines from the protein.")
@@ -31,13 +31,13 @@ class KeyWListTest(unittest.TestCase):
         self.assertEqual(record["CA"], "Ligand.")
 
         # Testing the second record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record["IC"], "Molecular function.")
         self.assertEqual(record["AC"], "KW-9992")
         self.assertEqual(record["DE"], "Keywords assigned to proteins due to their particular molecular function.")
 
         # Testing the third record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record["ID"], "Zymogen.")
         self.assertEqual(record["AC"], "KW-0865")
         self.assertEqual(record["DE"], "The enzymatically inactive precursor of mostly proteolytic enzymes.")
@@ -56,7 +56,7 @@ class KeyWListTest(unittest.TestCase):
         records = KeyWList.parse(handle)
 
         # Testing the first record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record["ID"], "2Fe-2S.")
         self.assertEqual(record["AC"], "KW-0001")
         self.assertEqual(record["DE"], "Protein which contains at least one 2Fe-2S iron-sulfur cluster: 2 iron atoms complexed to 2 inorganic sulfides and 4 sulfur atoms of cysteines from the protein.")
@@ -69,7 +69,7 @@ class KeyWListTest(unittest.TestCase):
         self.assertEqual(record["CA"], "Ligand.")
 
         # Testing the second record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record["ID"], "3D-structure.")
         self.assertEqual(record["AC"], "KW-0002")
         self.assertEqual(record["DE"], "Protein, or part of a protein, whose three-dimensional structure has been resolved experimentally (for example by X-ray crystallography or NMR spectroscopy) and whose coordinates are available in the PDB database. Can also be used for theoretical models.")
@@ -78,7 +78,7 @@ class KeyWListTest(unittest.TestCase):
         self.assertEqual(record["CA"], "Technical term.")
 
         # Testing the third record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record["ID"], "3Fe-4S.")
         self.assertEqual(record["AC"], "KW-0003")
         self.assertEqual(record["DE"], "Protein which contains at least one 3Fe-4S iron-sulfur cluster: 3 iron atoms complexed to 4 inorganic sulfides and 3 sulfur atoms of cysteines from the protein. In a number of iron-sulfur proteins, the 4Fe-4S cluster can be reversibly converted by oxidation and loss of one iron ion to a 3Fe-4S cluster.")
