@@ -23,14 +23,15 @@ mafft_exe = None
 if sys.platform=="win32":
     raise MissingExternalDependencyError("Testing with MAFFT not implemented on Windows yet")
 else:
-    import commands
-    output = commands.getoutput("mafft -help")
+    from Bio._py3k import getoutput
+    output = getoutput("mafft -help")
     if "not found" not in output and "MAFFT" in output:
         mafft_exe = "mafft"
 if not mafft_exe:
-    raise MissingExternalDependencyError(\
+    raise MissingExternalDependencyError(
         "Install MAFFT if you want to use the Bio.Align.Applications wrapper.")
 
+
 def check_mafft_version(mafft_exe):
     child = subprocess.Popen("%s --help" % mafft_exe,
                              stdout=subprocess.PIPE,
@@ -52,20 +53,22 @@ def check_mafft_version(mafft_exe):
         index = output.find(marker)
         if index == -1:
             continue
-        version = output[index+len(marker):].strip().split(None,1)[0]
-        if int(version.split(".",1)[0]) < 6:
+        version = output[index+len(marker):].strip().split(None, 1)[0]
+        major = int(version.split(".", 1)[0])
+        if major < 6:
             raise MissingExternalDependencyError("Test requires MAFFT v6 or "
                                                  "later (found %s)." % version)
-        return True
+        return (major, version)
     raise MissingExternalDependencyError("Couldn't determine MAFFT version.")
 
 #This also checks it actually runs!
-check_mafft_version(mafft_exe)
+version_major, version_string = check_mafft_version(mafft_exe)
+
 
 class MafftApplication(unittest.TestCase):
 
     def setUp(self):
-        self.infile1  = "Fasta/f002"
+        self.infile1 = "Fasta/f002"
 
     def tearDown(self):
         if os.path.isfile("Fasta/f002.tree"):
@@ -109,6 +112,33 @@ class MafftApplication(unittest.TestCase):
         self.assertTrue(stdoutdata.startswith("CLUSTAL"), stdoutdata)
         self.assertTrue("$#=0" not in stderrdata)
 
+    if version_major >= 7:
+        def test_Mafft_with_PHYLIP_output(self):
+            """Simple round-trip through app with PHYLIP output"""
+            cmdline = MafftCommandline(mafft_exe, input=self.infile1,
+                                       phylipout=True)
+            self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
+            stdoutdata, stderrdata = cmdline()
+            #e.g. " 3 706\n" but allow some variation in the column count
+            self.assertTrue(stdoutdata.startswith(" 3 70"), stdoutdata)
+            self.assertTrue("gi|1348912 " in stdoutdata,
+                            stdoutdata)
+            self.assertTrue("gi|1348912|gb|G26680|G26680" not in stdoutdata,
+                            stdoutdata)
+            self.assertTrue("$#=0" not in stderrdata)
+
+        def test_Mafft_with_PHYLIP_namelength(self):
+            """Check PHYLIP with --namelength"""
+            cmdline = MafftCommandline(mafft_exe, input=self.infile1,
+                                       phylipout=True, namelength=50)
+            self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
+            stdoutdata, stderrdata = cmdline()
+            #e.g. " 3 706\n" but allow some variation in the column count
+            self.assertTrue(stdoutdata.startswith(" 3 70"), stdoutdata)
+            self.assertTrue("gi|1348912|gb|G26680|G26680" in stdoutdata,
+                            stdoutdata)
+            self.assertTrue("$#=0" not in stderrdata)
+
     def test_Mafft_with_complex_command_line(self):
         """Round-trip with complex command line."""
         cmdline = MafftCommandline(mafft_exe)
@@ -126,10 +156,10 @@ class MafftApplication(unittest.TestCase):
         cmdline.set_parameter("--treeout", True)
         cmdline.set_parameter("nuc", True)
         self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
-        self.assertEqual(str(cmdline), mafft_exe \
-                         + " --localpair --weighti 4.2 --retree 5 " \
-                         + "--maxiterate 200 --nofft --op 2.04 --ep 0.51" \
-                         + " --lop 0.233 --lep 0.2 --reorder --treeout" \
+        self.assertEqual(str(cmdline), mafft_exe
+                         + " --localpair --weighti 4.2 --retree 5 "
+                         + "--maxiterate 200 --nofft --op 2.04 --ep 0.51"
+                         + " --lop 0.233 --lep 0.2 --reorder --treeout"
                          + " --nuc Fasta/f002")
         stdoutdata, stderrdata = cmdline()
         self.assertTrue(stdoutdata.startswith(">gi|1348912|gb|G26680|G26680"))
