@@ -5,7 +5,12 @@
 # as part of this package.
 
 import unittest
-from Bio.Blast import NCBIStandalone
+
+import warnings
+from Bio import BiopythonDeprecationWarning
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore', BiopythonDeprecationWarning)
+    from Bio.Blast import NCBIStandalone
 
 
 class TestNCBIStandalone(unittest.TestCase):
@@ -20,7 +25,7 @@ class TestNCBIStandalone(unittest.TestCase):
                               "/tmp/example.fasta",
                               expectation=10**-4,
                               matrix="IDENTITY -F 0; cat /etc/passwd'")
-            except ValueError, e:
+            except ValueError as e:
                 self.assertEqual(str(e), "Rejecting suspicious argument for matrix")
                 #Good
             else:
@@ -37,7 +42,7 @@ class TestNCBIStandalone(unittest.TestCase):
                               nprocessors=4,
                               expectation="0.001",
                               filter= "F > /etc/passwd'")
-            except ValueError, e:
+            except ValueError as e:
                 self.assertEqual(str(e), "Rejecting suspicious argument for filter")
                 #Good
             else:
