@@ -15,21 +15,21 @@ from Bio.Pathway.Rep.MultiGraph import MultiGraph
 class GraphTestCase(unittest.TestCase):
 
     def testEquals(self):
-        a = Graph(['a','b','c'])
-        a.add_edge('a','b','label1')
-        a.add_edge('b','c','label1')
-        a.add_edge('b','a','label2')
-        b = Graph(['a','b','c'])
+        a = Graph(['a', 'b', 'c'])
+        a.add_edge('a', 'b', 'label1')
+        a.add_edge('b', 'c', 'label1')
+        a.add_edge('b', 'a', 'label2')
+        b = Graph(['a', 'b', 'c'])
         self.assertNotEqual(a, b, "equal to similar nodes, no edges")
-        b.add_edge('a','b','label1')
+        b.add_edge('a', 'b', 'label1')
         self.assertNotEqual(a, b, "equal to similar nodes, edge subset")
-        b.add_edge('b','c','label1')
-        b.add_edge('b','a','label2')
+        b.add_edge('b', 'c', 'label1')
+        b.add_edge('b', 'a', 'label2')
         self.assertEqual(a, b, "not equal to similar")
-        c = Graph(['a','b','c'])
-        c.add_edge('a','b','label2')
-        c.add_edge('b','c','label2')
-        c.add_edge('b','a','label1')
+        c = Graph(['a', 'b', 'c'])
+        c.add_edge('a', 'b', 'label2')
+        c.add_edge('b', 'c', 'label2')
+        c.add_edge('b', 'a', 'label1')
         self.assertNotEqual(a, c, "equal to similar with different labels")
         self.assertNotEqual(c, Graph(), "equal to empty graph")
         self.assertEqual(Graph(), Graph(), "empty graph not equal to self")
@@ -42,56 +42,54 @@ class GraphTestCase(unittest.TestCase):
         a.add_node('a')
         self.assertEqual(a.nodes(), ['a'], "duplicate node added")
         a.add_node('b')
-        l = a.nodes()
-        l.sort()
+        l = sorted(a.nodes())
         self.assertEqual(l, ['a', 'b'], "second node not added")
 
     def testEdges(self):
-        a = Graph(['a','b','c','d'])
-        a.add_edge('a','b','label1')
-        self.assertEqual(a.child_edges('a'), [('b','label1')])  # , "incorrect child edges")
-        a.add_edge('b','a','label2')
-        self.assertEqual(a.parent_edges('a'), [('b','label2')])  # , "incorrect parent edges")
-        a.add_edge('b','c','label3')
-        self.assertEqual(a.parent_edges('c'), [('b','label3')])  # , "incorrect parent edges")
-        l = a.children('b')
-        l.sort()
+        a = Graph(['a', 'b', 'c', 'd'])
+        a.add_edge('a', 'b', 'label1')
+        self.assertEqual(a.child_edges('a'), [('b', 'label1')])  # , "incorrect child edges")
+        a.add_edge('b', 'a', 'label2')
+        self.assertEqual(a.parent_edges('a'), [('b', 'label2')])  # , "incorrect parent edges")
+        a.add_edge('b', 'c', 'label3')
+        self.assertEqual(a.parent_edges('c'), [('b', 'label3')])  # , "incorrect parent edges")
+        l = sorted(a.children('b'))
         self.assertEqual(l, ['a', 'c'], "incorrect children")
         self.assertEqual(a.children('d'), [], "incorrect children for singleton")
         self.assertEqual(a.parents('a'), ['b'], "incorrect parents")
 
     def testRemoveNode(self):
-        a = Graph(['a','b','c','d','e'])
-        a.add_edge('a','e','label1')
-        a.add_edge('b','e','label1')
-        a.add_edge('c','e','label2')
-        a.add_edge('d','e','label3')
-        a.add_edge('e','d','label4')
-        a.add_edge('a','b','label5')
+        a = Graph(['a', 'b', 'c', 'd', 'e'])
+        a.add_edge('a', 'e', 'label1')
+        a.add_edge('b', 'e', 'label1')
+        a.add_edge('c', 'e', 'label2')
+        a.add_edge('d', 'e', 'label3')
+        a.add_edge('e', 'd', 'label4')
+        a.add_edge('a', 'b', 'label5')
         a.remove_node('e')
-        b = Graph(['a','b','c','d'])
-        b.add_edge('a','b','label5')
+        b = Graph(['a', 'b', 'c', 'd'])
+        b.add_edge('a', 'b', 'label5')
         self.assertEqual(a, b)  # , "incorrect node removal")
 
 
 class MultiGraphTestCase(unittest.TestCase):
 
     def testEquals(self):
-        a = MultiGraph(['a','b','c'])
-        a.add_edge('a','b','label1')
-        a.add_edge('b','c','label1')
-        a.add_edge('b','a','label2')
-        b = MultiGraph(['a','b','c'])
+        a = MultiGraph(['a', 'b', 'c'])
+        a.add_edge('a', 'b', 'label1')
+        a.add_edge('b', 'c', 'label1')
+        a.add_edge('b', 'a', 'label2')
+        b = MultiGraph(['a', 'b', 'c'])
         self.assertNotEqual(a, b, "equal to similar nodes, no edges")
-        b.add_edge('a','b','label1')
+        b.add_edge('a', 'b', 'label1')
         self.assertNotEqual(a, b, "equal to similar nodes, edge subset")
-        b.add_edge('b','c','label1')
-        b.add_edge('b','a','label2')
+        b.add_edge('b', 'c', 'label1')
+        b.add_edge('b', 'a', 'label2')
         self.assertEqual(a, b, "not equal to similar")
-        c = MultiGraph(['a','b','c'])
-        c.add_edge('a','b','label2')
-        c.add_edge('b','c','label2')
-        c.add_edge('b','a','label1')
+        c = MultiGraph(['a', 'b', 'c'])
+        c.add_edge('a', 'b', 'label2')
+        c.add_edge('b', 'c', 'label2')
+        c.add_edge('b', 'a', 'label1')
         self.assertNotEqual(a, c, "equal to similar with different labels")
         self.assertNotEqual(c, MultiGraph(), "equal to empty graph")
         self.assertEqual(MultiGraph(), MultiGraph(), "empty graph not equal to self")
@@ -104,22 +102,20 @@ class MultiGraphTestCase(unittest.TestCase):
         a.add_node('a')
         self.assertEqual(a.nodes(), ['a'], "duplicate node added")
         a.add_node('b')
-        l = a.nodes()
-        l.sort()
+        l = sorted(a.nodes())
         self.assertEqual(l, ['a', 'b'], "second node not added")
 
     def testEdges(self):
-        a = MultiGraph(['a','b','c','d'])
-        a.add_edge('a','b','label1')
-        self.assertEqual(a.child_edges('a'), [('b','label1')])  # , "incorrect child edges")
-        a.add_edge('a','b','label2')
-        l = a.child_edges('a')
-        l.sort()
-        self.assertEqual(l, [('b','label1'),('b','label2')])  # , "incorrect child edges")
-        a.add_edge('b','a','label2')
-        self.assertEqual(a.parent_edges('a'), [('b','label2')])  # , "incorrect parent edges")
-        a.add_edge('b','c','label3')
-        self.assertEqual(a.parent_edges('c'), [('b','label3')])  # , "incorrect parent edges")
+        a = MultiGraph(['a', 'b', 'c', 'd'])
+        a.add_edge('a', 'b', 'label1')
+        self.assertEqual(a.child_edges('a'), [('b', 'label1')])  # , "incorrect child edges")
+        a.add_edge('a', 'b', 'label2')
+        l = sorted(a.child_edges('a'))
+        self.assertEqual(l, [('b', 'label1'), ('b', 'label2')])  # , "incorrect child edges")
+        a.add_edge('b', 'a', 'label2')
+        self.assertEqual(a.parent_edges('a'), [('b', 'label2')])  # , "incorrect parent edges")
+        a.add_edge('b', 'c', 'label3')
+        self.assertEqual(a.parent_edges('c'), [('b', 'label3')])  # , "incorrect parent edges")
         l = a.children('b')
         l.sort()
         self.assertEqual(l, ['a', 'c'], "incorrect children")
@@ -127,19 +123,19 @@ class MultiGraphTestCase(unittest.TestCase):
         self.assertEqual(a.parents('a'), ['b'], "incorrect parents")
 
     def testRemoveNode(self):
-        a = MultiGraph(['a','b','c','d','e'])
-        a.add_edge('a','e','label1')
+        a = MultiGraph(['a', 'b', 'c', 'd', 'e'])
+        a.add_edge('a', 'e', 'label1')
         self.assertEqual(repr(a), "<MultiGraph: ('a': ('e', 'label1'))('b': )('c': )('d': )('e': )>")
-        a.add_edge('b','e','label1')
-        a.add_edge('c','e','label2')
-        a.add_edge('d','e','label3')
-        a.add_edge('e','d','label4')
-        a.add_edge('a','b','label5')
+        a.add_edge('b', 'e', 'label1')
+        a.add_edge('c', 'e', 'label2')
+        a.add_edge('d', 'e', 'label3')
+        a.add_edge('e', 'd', 'label4')
+        a.add_edge('a', 'b', 'label5')
         self.assertEqual(repr(a), "<MultiGraph: ('a': ('b', 'label5'),('e', 'label1'))('b': ('e', 'label1'))('c': ('e', 'label2'))('d': ('e', 'label3'))('e': ('d', 'label4'))>")
         a.remove_node('e')
         self.assertEqual(repr(a), "<MultiGraph: ('a': ('b', 'label5'))('b': )('c': )('d': )>")
-        b = MultiGraph(['a','b','c','d'])
-        b.add_edge('a','b','label5')
+        b = MultiGraph(['a', 'b', 'c', 'd'])
+        b.add_edge('a', 'b', 'label5')
         self.assertEqual(repr(b), "<MultiGraph: ('a': ('b', 'label5'))('b': )('c': )('d': )>")
         self.assertEqual(repr(a), repr(b))
         self.assertEqual(a, b)  # , "incorrect node removal")
