@@ -7,7 +7,8 @@
 
 import sys
 import unittest
-from cStringIO import StringIO
+from Bio._py3k import StringIO
+from io import BytesIO
 
 from Bio import Phylo
 from Bio.Phylo import PhyloXML, NewickIO
@@ -15,7 +16,9 @@ from Bio.Phylo import PhyloXML, NewickIO
 
 # Example Newick and Nexus files
 EX_NEWICK = 'Nexus/int_node_labels.nwk'
+EX_NEWICK2 = 'Nexus/test.new'
 EX_NEXUS = 'Nexus/test_Nexus_input.nex'
+EX_NEXUS2 = 'Nexus/bats.nex'
 
 # Example PhyloXML files
 EX_APAF = 'PhyloXML/apaf.xml'
@@ -30,6 +33,17 @@ class IOTests(unittest.TestCase):
         """Read a Newick file with one tree."""
         tree = Phylo.read(EX_NEWICK, 'newick')
         self.assertEqual(len(tree.get_terminals()), 28)
+        
+        tree = Phylo.read(EX_NEWICK2, 'newick')
+        self.assertEqual(len(tree.get_terminals()), 33)
+        self.assertEqual(tree.find_any('Homo sapiens').comment, 'modern human')
+        self.assertEqual(tree.find_any('Equus caballus').comment, "wild horse; also 'Equus ferus caballus'")
+        self.assertEqual(tree.root.confidence, 80)
+        tree = Phylo.read(EX_NEWICK2, 'newick', comments_are_confidence=True)
+        self.assertEqual(tree.root.confidence, 100)
+        
+        tree = Phylo.read(EX_NEXUS2, 'nexus')
+        self.assertEqual(len(tree.get_terminals()), 658)
 
     def test_newick_read_multiple(self):
         """Parse a Nexus file with multiple trees."""
@@ -54,6 +68,13 @@ class IOTests(unittest.TestCase):
                 if c is not None)
         self.assertEqual(internal_names, set(('E', 'F')))
 
+    def test_newick_read_scinot(self):
+        """Parse Newick branch lengths in scientific notation."""
+        tree = Phylo.read(StringIO("(foo:1e-1,bar:0.1)"), 'newick')
+        clade_a = tree.clade[0]
+        self.assertEqual(clade_a.name, 'foo')
+        self.assertAlmostEqual(clade_a.branch_length, 0.1)
+
     def test_format_branch_length(self):
         """Custom format string for Newick branch length serialization."""
         tree = Phylo.read(StringIO('A:0.1;'), 'newick')
@@ -67,12 +88,8 @@ class IOTests(unittest.TestCase):
     def test_convert(self):
         """Convert a tree between all supported formats."""
         mem_file_1 = StringIO()
+        mem_file_2 = BytesIO()
         mem_file_3 = StringIO()
-        if sys.version_info[0] == 3:
-            from io import BytesIO
-            mem_file_2 = BytesIO()
-        else:
-            mem_file_2 = StringIO()
         Phylo.convert(EX_NEWICK, 'newick', mem_file_1, 'nexus')
         mem_file_1.seek(0)
         Phylo.convert(mem_file_1, 'nexus', mem_file_2, 'phyloxml')
@@ -145,8 +162,8 @@ class TreeTests(unittest.TestCase):
             # Root is bifurcating
             self.assertEqual(len(tree.root.clades), 2)
             # Deepest tips under each child of the root are equally deep
-            deep_dist_0 = max(tree.clade[0].depths().itervalues())
-            deep_dist_1 = max(tree.clade[1].depths().itervalues())
+            deep_dist_0 = max(tree.clade[0].depths().values())
+            deep_dist_1 = max(tree.clade[1].depths().values())
             self.assertAlmostEqual(deep_dist_0, deep_dist_1)
 
     # Magic method
@@ -216,7 +233,7 @@ class MixinTests(unittest.TestCase):
         self.assertTrue(isinstance(octo[0], PhyloXML.Clade))
         self.assertEqual(octo[0].taxonomies[0].code, 'OCTVU')
         # string filter
-        dee = self.phylogenies[10].find_clades('D').next()
+        dee = next(self.phylogenies[10].find_clades('D'))
         self.assertEqual(dee.name, 'D')
 
     def test_find_terminal(self):
