@@ -3,6 +3,8 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
+from __future__ import print_function
+
 import os
 import shutil
 import tempfile
@@ -14,12 +16,22 @@ from Bio import MissingExternalDependencyError
 #Tests FDist2 related code. Note: this case requires fdist2 (four binaries)
 #test_PopGen_FDist_nodepend tests code that does not require fdist2 or Dfdist
 
+def is_pypy():
+    import platform
+    try:
+        if platform.python_implementation() == 'PyPy':
+            return True
+    except AttributeError:
+        #New in Python 2.6, not in Jython yet either
+        pass
+    return False
+
 wanted = dict()
 for path in os.environ['PATH'].split(os.pathsep):
     try:
         list = os.listdir(path)
         for file in os.listdir(path):
-            for f in ['fdist2', 'datacal', 'pv', 'cplot2']:
+            for f in ['fdist2', 'datacal', 'pv', 'cplot']:
                 if file == f or file.lower() == f.lower()+".exe":
                     wanted[f] = file
     except os.error:
@@ -29,6 +41,11 @@ if len(wanted) != 4:
         "Install fdist2, datacal, pv and cplot if you want to use FDist2 with Bio.PopGen.FDist.")
 del wanted
 
+import sys
+if not is_pypy() and sys.version_info[0] == 3 and sys.version_info < (3, 2, 4):
+    raise MissingExternalDependencyError("Under Python 3, please use Python 3.2.4"
+                                         " onwards for this test - see http://bugs.python.org/issue16903")
+
 
 class AppTest(unittest.TestCase):
     """Tests the fdist suite of applications.
@@ -98,6 +115,6 @@ class AppTest(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    print "Running fdist tests, which might take some time, please wait"
+    print("Running fdist tests, which might take some time, please wait")
     runner = unittest.TextTestRunner(verbosity = 2)
     unittest.main(testRunner=runner)
