@@ -3,11 +3,7 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-import commands
 import os
-import shutil
-import sys
-import tempfile
 import unittest
 from Bio.PopGen import SimCoal
 from Bio.PopGen.SimCoal.Template import generate_simcoal_from_template
@@ -15,28 +11,9 @@ from Bio.PopGen.SimCoal.Template import generate_simcoal_from_template
 #Tests simcoal related code. Note: this case doesn't require simcoal
 #test_PopGen_SimCoal tests code that requires simcoal
 
-def run_tests(argv):
-    test_suite = testing_suite()
-    runner = unittest.TextTestRunner(sys.stdout, verbosity = 2)
-    runner.run(test_suite)
-
-def testing_suite():
-    """Generate the suite of tests.
-    """
-    test_suite = unittest.TestSuite()
-
-    test_loader = unittest.TestLoader()
-    test_loader.testMethodPrefix = 't_'
-    tests = [TemplateTest]
-    
-    for test in tests:
-        cur_suite = test_loader.loadTestsFromTestCase(test)
-        test_suite.addTest(cur_suite)
-
-    return test_suite
 
 class TemplateTest(unittest.TestCase):
-    def t_template_full(self):
+    def test_template_full(self):
         """Full template creation test
         """
         generate_simcoal_from_template('simple',
@@ -46,16 +23,25 @@ class TemplateTest(unittest.TestCase):
             'PopGen')
         #Confirm the files match (ignoring any switch of line endings
         #possible if the input file used a different OS convention)
-        old = open('PopGen' + os.sep + 'simple.par', "rU").readlines()
-        new = open('PopGen' + os.sep + 'simple_100_30.par').readlines()
+        handle = open(os.path.join('PopGen', 'simple.par'), "rU")
+        old = handle.readlines()
+        handle.close()
+        handle = open(os.path.join('PopGen', 'simple_100_30.par'))
+        new = handle.readlines()
+        handle.close()
         assert old==new, "Error - Old:\n%s\n\nNew:\n%s\n" % (old, new)
         #assert(os.stat('PopGen' + os.sep + 'simple.par').st_size ==
         #       os.stat('PopGen' + os.sep + 'simple_100_30.par').st_size)
 
     def tearDown(self):
-        os.remove('PopGen' + os.sep + 'tmp.par')
-        os.remove('PopGen' + os.sep + 'simple_100_30.par')
-
+        if os.path.isfile(os.path.join('PopGen', 'tmp.par')):
+            #This is a temp file create by the Bio.PopGen.SimCoal.Template
+            #function generate_simcoal_from_template
+            os.remove(os.path.join('PopGen', 'tmp.par'))
+        if os.path.isfile(os.path.join('PopGen', 'simple_100_30.par')):
+            #This won't exist if the template generation failed:
+            os.remove(os.path.join('PopGen', 'simple_100_30.par'))
 
 if __name__ == "__main__":
-    sys.exit(run_tests(sys.argv))
+    runner = unittest.TextTestRunner(verbosity = 2)
+    unittest.main(testRunner=runner)
