@@ -7,8 +7,11 @@
 
 """Unit test for Scop"""
 
+from __future__ import print_function
+
 import unittest
-from StringIO import *
+from Bio._py3k import StringIO
+from Bio._py3k import zip
 
 from Bio.SCOP import *
 
@@ -24,8 +27,8 @@ class ScopTests(unittest.TestCase):
         """
         fields1 = cla_line_1.rstrip().split('\t')
         fields2 = cla_line_2.rstrip().split('\t')
-        print fields1
-        print fields2
+        print(fields1)
+        print(fields2)
         # compare the first five fields in a Cla line, which should be exactly
         # the same
         if fields1[:5] != fields2[:5]:
