@@ -1,20 +1,23 @@
-# Copyright 2009-2011 by Peter Cock.  All rights reserved.
+# Copyright 2009-2013 by Peter Cock.  All rights reserved.
 # Parts copyright 1999 by Jeffrey Chang.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
+from __future__ import print_function
+
 import unittest
-from StringIO import StringIO
+from Bio._py3k import StringIO
 
 from Bio import SeqIO
 from Bio.SeqIO.FastaIO import FastaIterator
 from Bio.Alphabet import generic_protein, generic_nucleotide, generic_dna
 
+
 def title_to_ids(title):
     """Function to convert a title into the id, name, and description.
 
-    This is just a quick-n-dirty implementation, and is definately not meant
+    This is just a quick-n-dirty implementation, and is definetely not meant
     to handle every FASTA title line case.
     """
     # first split the id information from the description
@@ -38,17 +41,21 @@ def title_to_ids(title):
 
     return id, name, descr
 
+
 def read_single_with_titles(filename, alphabet):
     global title_to_ids
-    iterator = FastaIterator(open(filename), alphabet, title_to_ids)
-    record = iterator.next()
+    handle = open(filename)
+    iterator = FastaIterator(handle, alphabet, title_to_ids)
+    record = next(iterator)
     try:
-        second = iterator.next()
+        second = next(iterator)
     except StopIteration:
         second = None
+    handle.close()
     assert record is not None and second is None
     return record
 
+
 def read_title_and_seq(filename):
     """Crude parser that gets the first record from a FASTA file."""
     handle = open(filename)
@@ -56,7 +63,8 @@ def read_title_and_seq(filename):
     assert title.startswith(">")
     seq = ""
     for line in handle:
-        if line.startswith(">") : break
+        if line.startswith(">"):
+            break
         seq += line.strip()
     handle.close()
     return title[1:], seq
@@ -66,7 +74,7 @@ class TitleFunctions(unittest.TestCase):
     """Cunning unit test where methods are added at run time."""
     def simple_check(self, filename, alphabet):
         """Basic test for parsing single record FASTA files."""
-        title, seq = read_title_and_seq(filename) #crude parser
+        title, seq = read_title_and_seq(filename)  # crude parser
         #First check using Bio.SeqIO.FastaIO directly with title function,
         record = read_single_with_titles(filename, alphabet)
         idn, name, descr = title_to_ids(title)
@@ -76,19 +84,20 @@ class TitleFunctions(unittest.TestCase):
         self.assertEqual(str(record.seq), seq)
         self.assertEqual(record.seq.alphabet, alphabet)
         #Now check using Bio.SeqIO (default settings)
-        record = SeqIO.read(open(filename), "fasta", alphabet)
+        record = SeqIO.read(filename, "fasta", alphabet)
         self.assertEqual(record.id, title.split()[0])
         self.assertEqual(record.name, title.split()[0])
         self.assertEqual(record.description, title)
         self.assertEqual(str(record.seq), seq)
         self.assertEqual(record.seq.alphabet, alphabet)
         #Uncomment this for testing the methods are calling the right files:
-        #print "{%s done}" % filename,
+        #print("{%s done}" % filename)
 
     def multi_check(self, filename, alphabet):
         """Basic test for parsing multi-record FASTA files."""
-        re_titled = list(FastaIterator(open(filename), alphabet, title_to_ids))
-        default = list(SeqIO.parse(open(filename), "fasta", alphabet))
+        with open(filename) as handle:
+            re_titled = list(FastaIterator(handle, alphabet, title_to_ids))
+        default = list(SeqIO.parse(filename, "fasta", alphabet))
         self.assertEqual(len(re_titled), len(default))
         for old, new in zip(default, re_titled):
             idn, name, descr = title_to_ids(old.description)
@@ -98,7 +107,7 @@ class TitleFunctions(unittest.TestCase):
             self.assertEqual(str(new.seq), str(old.seq))
             self.assertEqual(new.seq.alphabet, old.seq.alphabet)
         #Uncomment this for testing the methods are calling the right files:
-        #print "{%s done}" % filename,
+        #print("{%s done}" % filename)
 
     def test_no_name(self):
         """Test FASTA record with no identifier."""
@@ -125,37 +134,45 @@ multi_amino_files = ['Fasta/f002', 'Fasta/fa01']
 
 for filename in single_nucleic_files:
     name = filename.split(".")[0]
+
     def funct(fn):
         f = lambda x : x.simple_check(fn, generic_nucleotide)
         f.__doc__ = "Checking nucleotide file %s" % fn
         return f
+
     setattr(TitleFunctions, "test_nuc_%s"%name, funct(filename))
     del funct
 
 for filename in multi_dna_files:
     name = filename.split(".")[0]
+
     def funct(fn):
         f = lambda x : x.multi_check(fn, generic_dna)
         f.__doc__ = "Checking multi DNA file %s" % fn
         return f
+
     setattr(TitleFunctions, "test_mutli_dna_%s"%name, funct(filename))
     del funct
 
 for filename in single_amino_files:
     name = filename.split(".")[0]
+
     def funct(fn):
         f = lambda x : x.simple_check(fn, generic_nucleotide)
         f.__doc__ = "Checking protein file %s" % fn
         return f
+
     setattr(TitleFunctions, "test_pro_%s"%name, funct(filename))
     del funct
 
 for filename in multi_amino_files:
     name = filename.split(".")[0]
+
     def funct(fn):
         f = lambda x : x.multi_check(fn, generic_dna)
         f.__doc__ = "Checking multi protein file %s" % fn
         return f
+
     setattr(TitleFunctions, "test_mutli_pro_%s"%name, funct(filename))
     del funct
 
