@@ -1,19 +1,19 @@
-# Copyright 2009-2010 by Peter Cock.  All rights reserved.
+# Copyright 2009-2013 by Peter Cock.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
 """Additional unit tests for Bio.SeqIO.QualityIO (covering FASTQ and QUAL)."""
+
+from __future__ import print_function
+
 import os
 import unittest
 import warnings
 
-from StringIO import StringIO
-try:
-    #This is in Python 2.6+, but we need it on Python 3
-    from io import BytesIO
-except ImportError:
-    BytesIO = StringIO
+from Bio._py3k import range
+from Bio._py3k import StringIO
+from io import BytesIO
 
 from Bio import BiopythonWarning
 from Bio.Alphabet import generic_dna
@@ -42,7 +42,8 @@ def write_read(filename, in_format, out_format):
         mode = "rb"
     else:
         mode = "r"
-    records = list(SeqIO.parse(open(filename, mode),in_format))
+    with open(filename, mode) as handle:
+        records = list(SeqIO.parse(handle, in_format))
     #Write it out...
     if out_format in BINARY_FORMATS:
         handle = BytesIO()
@@ -51,7 +52,7 @@ def write_read(filename, in_format, out_format):
     SeqIO.write(records, handle, out_format)
     handle.seek(0)
     #Now load it back and check it agrees,
-    records2 = list(SeqIO.parse(handle,out_format))
+    records2 = list(SeqIO.parse(handle, out_format))
     compare_records(records, records2, truncation_expected(out_format))
 
 
@@ -78,16 +79,16 @@ def compare_record(old, new, truncate=None):
     if "phred_quality" in old.letter_annotations \
     and "phred_quality" in new.letter_annotations \
     and old.letter_annotations["phred_quality"] != new.letter_annotations["phred_quality"]:
-        if truncate and [min(q,truncate) for q in old.letter_annotations["phred_quality"]] == \
-                        [min(q,truncate) for q in new.letter_annotations["phred_quality"]]:
+        if truncate and [min(q, truncate) for q in old.letter_annotations["phred_quality"]] == \
+                        [min(q, truncate) for q in new.letter_annotations["phred_quality"]]:
             pass
         else:
             raise ValuerError("Mismatch in phred_quality")
     if "solexa_quality" in old.letter_annotations \
     and "solexa_quality" in new.letter_annotations \
     and old.letter_annotations["solexa_quality"] != new.letter_annotations["solexa_quality"]:
-        if truncate and [min(q,truncate) for q in old.letter_annotations["solexa_quality"]] == \
-                        [min(q,truncate) for q in new.letter_annotations["solexa_quality"]]:
+        if truncate and [min(q, truncate) for q in old.letter_annotations["solexa_quality"]] == \
+                        [min(q, truncate) for q in new.letter_annotations["solexa_quality"]]:
             pass
         else:
             raise ValueError("Mismatch in phred_quality")
@@ -98,12 +99,12 @@ def compare_record(old, new, truncate=None):
         converted = [round(QualityIO.solexa_quality_from_phred(q))
                      for q in old.letter_annotations["phred_quality"]]
         if truncate:
-            converted = [min(q,truncate) for q in converted]
+            converted = [min(q, truncate) for q in converted]
         if converted != new.letter_annotations["solexa_quality"]:
-            print
-            print old.letter_annotations["phred_quality"]
-            print converted
-            print new.letter_annotations["solexa_quality"]
+            print("")
+            print(old.letter_annotations["phred_quality"])
+            print(converted)
+            print(new.letter_annotations["solexa_quality"])
             raise ValueError("Mismatch in phred_quality vs solexa_quality")
     if "solexa_quality" in old.letter_annotations \
     and "phred_quality" in new.letter_annotations:
@@ -112,11 +113,11 @@ def compare_record(old, new, truncate=None):
         converted = [round(QualityIO.phred_quality_from_solexa(q))
                      for q in old.letter_annotations["solexa_quality"]]
         if truncate:
-            converted = [min(q,truncate) for q in converted]
+            converted = [min(q, truncate) for q in converted]
         if converted != new.letter_annotations["phred_quality"]:
-            print old.letter_annotations["solexa_quality"]
-            print converted
-            print new.letter_annotations["phred_quality"]
+            print(old.letter_annotations["solexa_quality"])
+            print(converted)
+            print(new.letter_annotations["phred_quality"])
             raise ValueError("Mismatch in solexa_quality vs phred_quality")
     return True
 
@@ -126,7 +127,7 @@ def compare_records(old_list, new_list, truncate_qual=None):
     if len(old_list) != len(new_list):
         raise ValueError("%i vs %i records" % (len(old_list), len(new_list)))
     for old, new in zip(old_list, new_list):
-        if not compare_record(old,new,truncate_qual):
+        if not compare_record(old, new, truncate_qual):
             return False
     return True
 
@@ -140,17 +141,17 @@ class TestFastqErrors(unittest.TestCase):
             handle = open(filename, "rU")
             records = SeqIO.parse(handle, format)
             for i in range(good_count):
-                record = records.next()  # Make sure no errors!
+                record = next(records)  # Make sure no errors!
                 self.assertTrue(isinstance(record, SeqRecord))
-            self.assertRaises(ValueError, records.next)
+            self.assertRaises(ValueError, next, records)
             handle.close()
 
     def check_general_fails(self, filename, good_count):
         handle = open(filename, "rU")
         tuples = QualityIO.FastqGeneralIterator(handle)
         for i in range(good_count):
-            title, seq, qual = tuples.next()  # Make sure no errors!
-        self.assertRaises(ValueError, tuples.next)
+            title, seq, qual = next(tuples)  # Make sure no errors!
+        self.assertRaises(ValueError, next, tuples)
         handle.close()
 
     def check_general_passes(self, filename, record_count):
@@ -191,9 +192,9 @@ tests = [("diff_ids", 2),
          ("trunc_at_plus", 4),
          ("trunc_at_qual", 4)]
 for base_name, good_count in tests:
-    def funct(name,c):
-        f = lambda x : x.check_all_fail("Quality/error_%s.fastq" % name,c)
-        f.__doc__ = "Reject FASTQ with %s" % name.replace("_"," ")
+    def funct(name, c):
+        f = lambda x : x.check_all_fail("Quality/error_%s.fastq" % name, c)
+        f.__doc__ = "Reject FASTQ with %s" % name.replace("_", " ")
         return f
     setattr(TestFastqErrors, "test_%s" % (base_name),
             funct(base_name, good_count))
@@ -209,9 +210,9 @@ tests = [("del", 3, 5),
          ("tab", 4, 5),
          ("null", 0, 5)]
 for base_name, good_count, full_count in tests:
-    def funct(name,c1,c2):
-        f = lambda x : x.check_qual_char("Quality/error_qual_%s.fastq"%name,c1,c2)
-        f.__doc__ = "Reject FASTQ with %s in quality" % name.replace("_"," ")
+    def funct(name, c1, c2):
+        f = lambda x : x.check_qual_char("Quality/error_qual_%s.fastq"%name, c1, c2)
+        f.__doc__ = "Reject FASTQ with %s in quality" % name.replace("_", " ")
         return f
     setattr(TestFastqErrors, "test_qual_%s" % (base_name),
             funct(base_name, good_count, full_count))
@@ -220,7 +221,7 @@ for base_name, good_count, full_count in tests:
 
 class TestReferenceSffConversions(unittest.TestCase):
     def check(self, sff_name, sff_format, out_name, format) :
-        wanted = list(SeqIO.parse(open(out_name), format))
+        wanted = list(SeqIO.parse(out_name, format))
         data = StringIO()
         count = SeqIO.convert(sff_name, sff_format, data, format)
         self.assertEqual(count, len(wanted))
@@ -282,9 +283,9 @@ class TestReferenceFastqConversions(unittest.TestCase):
                           % (base_name, in_variant)
             self.assertTrue(os.path.isfile(in_filename))
             #Load the reference output...
-            expected = open("Quality/%s_as_%s.fastq"
-                            % (base_name, out_variant),
-                            "rU").read()
+            with open("Quality/%s_as_%s.fastq"
+                      % (base_name, out_variant), "rU") as handle:
+                expected = handle.read()
             #Check matches using convert...
             handle = StringIO()
             SeqIO.convert(in_filename, "fastq-"+in_variant,
@@ -292,7 +293,7 @@ class TestReferenceFastqConversions(unittest.TestCase):
             self.assertEqual(expected, handle.getvalue())
             #Check matches using parse/write
             handle = StringIO()
-            SeqIO.write(SeqIO.parse(open(in_filename), "fastq-"+in_variant),
+            SeqIO.write(SeqIO.parse(in_filename, "fastq-"+in_variant),
                         handle, "fastq-"+out_variant)
             self.assertEqual(expected, handle.getvalue())
             if out_variant != "sanger":
@@ -309,8 +310,8 @@ tests = [("illumina_full_range", "illumina"),
 for base_name, variant in tests:
     assert variant in ["sanger", "solexa", "illumina"]
 
-    def funct(bn,var):
-        f = lambda x : x.simple_check(bn,var)
+    def funct(bn, var):
+        f = lambda x : x.simple_check(bn, var)
         f.__doc__ = "Reference conversions of %s file %s" % (var, bn)
         return f
 
@@ -323,38 +324,40 @@ class TestQual(unittest.TestCase):
     """Tests with QUAL files."""
     def test_paired(self):
         """Check FASTQ parsing matches FASTA+QUAL parsing"""
-        records1 = list(
-            QualityIO.PairedFastaQualIterator(open("Quality/example.fasta"),
-                                              open("Quality/example.qual")))
-        records2 = list(SeqIO.parse(open("Quality/example.fastq"),"fastq"))
+        with open("Quality/example.fasta") as f:
+            with open("Quality/example.qual") as q:
+                records1 = list(QualityIO.PairedFastaQualIterator(f, q ))
+        records2 = list(SeqIO.parse("Quality/example.fastq", "fastq"))
         self.assertTrue(compare_records(records1, records2))
 
     def test_qual(self):
         """Check FASTQ parsing matches QUAL parsing"""
-        records1 = list(SeqIO.parse(open("Quality/example.qual"),"qual"))
-        records2 = list(SeqIO.parse(open("Quality/example.fastq"),"fastq"))
+        records1 = list(SeqIO.parse("Quality/example.qual", "qual"))
+        records2 = list(SeqIO.parse("Quality/example.fastq", "fastq"))
         #Will ignore the unknown sequences :)
         self.assertTrue(compare_records(records1, records2))
 
     def test_qual_out(self):
         """Check FASTQ to QUAL output"""
-        records = SeqIO.parse(open("Quality/example.fastq"),"fastq")
-        h = StringIO("")
+        records = SeqIO.parse("Quality/example.fastq", "fastq")
+        h = StringIO()
         SeqIO.write(records, h, "qual")
-        self.assertEqual(h.getvalue(),open("Quality/example.qual").read())
+        with open("Quality/example.qual") as expected:
+            self.assertEqual(h.getvalue(), expected.read())
 
     def test_fasta(self):
         """Check FASTQ parsing matches FASTA parsing"""
-        records1 = list(SeqIO.parse(open("Quality/example.fasta"),"fasta"))
-        records2 = list(SeqIO.parse(open("Quality/example.fastq"),"fastq"))
+        records1 = list(SeqIO.parse("Quality/example.fasta", "fasta"))
+        records2 = list(SeqIO.parse("Quality/example.fastq", "fastq"))
         self.assertTrue(compare_records(records1, records2))
 
     def test_fasta_out(self):
         """Check FASTQ to FASTA output"""
-        records = SeqIO.parse(open("Quality/example.fastq"),"fastq")
-        h = StringIO("")
+        records = SeqIO.parse("Quality/example.fastq", "fastq")
+        h = StringIO()
         SeqIO.write(records, h, "fasta")
-        self.assertEqual(h.getvalue(),open("Quality/example.fasta").read())
+        with open("Quality/example.fasta") as expected:
+            self.assertEqual(h.getvalue(), expected.read())
 
     def test_qual_negative(self):
         """Check QUAL negative scores mapped to PHRED zero"""
@@ -394,7 +397,7 @@ class TestReadWrite(unittest.TestCase):
         """Read and write back simple example with upper case 2000bp read"""
         data = "@%s\n%s\n+\n%s\n" \
                % ("id descr goes here", "ACGT"*500, "!@a~"*500)
-        handle = StringIO("")
+        handle = StringIO()
         self.assertEqual(1, SeqIO.write(SeqIO.parse(StringIO(data), "fastq"), handle, "fastq"))
         self.assertEqual(data, handle.getvalue())
 
@@ -402,7 +405,7 @@ class TestReadWrite(unittest.TestCase):
         """Read and write back simple example with mixed case 1000bp read"""
         data = "@%s\n%s\n+\n%s\n" \
                % ("id descr goes here", "ACGTNncgta"*100, "abcd!!efgh"*100)
-        handle = StringIO("")
+        handle = StringIO()
         self.assertEqual(1, SeqIO.write(SeqIO.parse(StringIO(data), "fastq"), handle, "fastq"))
         self.assertEqual(data, handle.getvalue())
 
@@ -413,7 +416,7 @@ class TestReadWrite(unittest.TestCase):
                % ("id descr goes here",
                   ambiguous_dna_letters.upper(),
                   "".join(chr(33+q) for q in range(len(ambiguous_dna_letters))))
-        handle = StringIO("")
+        handle = StringIO()
         self.assertEqual(1, SeqIO.write(SeqIO.parse(StringIO(data), "fastq"), handle, "fastq"))
         self.assertEqual(data, handle.getvalue())
         #Now in lower case...
@@ -421,7 +424,7 @@ class TestReadWrite(unittest.TestCase):
                % ("id descr goes here",
                   ambiguous_dna_letters.lower(),
                   "".join(chr(33+q) for q in range(len(ambiguous_dna_letters))))
-        handle = StringIO("")
+        handle = StringIO()
         self.assertEqual(1, SeqIO.write(SeqIO.parse(StringIO(data), "fastq"), handle, "fastq"))
         self.assertEqual(data, handle.getvalue())
 
@@ -432,7 +435,7 @@ class TestReadWrite(unittest.TestCase):
                % ("id descr goes here",
                   ambiguous_rna_letters.upper(),
                   "".join(chr(33+q) for q in range(len(ambiguous_rna_letters))))
-        handle = StringIO("")
+        handle = StringIO()
         self.assertEqual(1, SeqIO.write(SeqIO.parse(StringIO(data), "fastq"), handle, "fastq"))
         self.assertEqual(data, handle.getvalue())
         #Now in lower case...
@@ -440,7 +443,7 @@ class TestReadWrite(unittest.TestCase):
                % ("id descr goes here",
                   ambiguous_rna_letters.lower(),
                   "".join(chr(33+q) for q in range(len(ambiguous_rna_letters))))
-        handle = StringIO("")
+        handle = StringIO()
         self.assertEqual(1, SeqIO.write(SeqIO.parse(StringIO(data), "fastq"), handle, "fastq"))
         self.assertEqual(data, handle.getvalue())
 
@@ -450,21 +453,21 @@ class TestWriteRead(unittest.TestCase):
     def test_generated(self):
         """Write and read back odd SeqRecord objects"""
         record1 = SeqRecord(Seq("ACGT"*500, generic_dna),  id="Test", description="Long "*500,
-                           letter_annotations={"phred_quality":[40,30,20,10]*500})
+                           letter_annotations={"phred_quality":[40, 30, 20, 10]*500})
         record2 = SeqRecord(MutableSeq("NGGC"*1000),  id="Mut", description="very "*1000+"long",
-                           letter_annotations={"phred_quality":[0,5,5,10]*1000})
-        record3 = SeqRecord(UnknownSeq(2000,character="N"),  id="Unk", description="l"+("o"*1000)+"ng",
-                           letter_annotations={"phred_quality":[0,1]*1000})
+                           letter_annotations={"phred_quality":[0, 5, 5, 10]*1000})
+        record3 = SeqRecord(UnknownSeq(2000, character="N"),  id="Unk", description="l"+("o"*1000)+"ng",
+                           letter_annotations={"phred_quality":[0, 1]*1000})
         record4 = SeqRecord(Seq("ACGT"*500),  id="no_descr", description="", name="",
-                           letter_annotations={"phred_quality":[40,50,60,62]*500})
-        record5 = SeqRecord(Seq("",generic_dna),  id="empty_p", description="(could have been trimmed lots)",
+                           letter_annotations={"phred_quality":[40, 50, 60, 62]*500})
+        record5 = SeqRecord(Seq("", generic_dna),  id="empty_p", description="(could have been trimmed lots)",
                            letter_annotations={"phred_quality":[]})
         record6 = SeqRecord(Seq(""),  id="empty_s", description="(could have been trimmed lots)",
                            letter_annotations={"solexa_quality":[]})
         record7 = SeqRecord(Seq("ACNN"*500),  id="Test_Sol", description="Long "*500,
-                           letter_annotations={"solexa_quality":[40,30,0,-5]*500})
+                           letter_annotations={"solexa_quality":[40, 30, 0, -5]*500})
         record8 = SeqRecord(Seq("ACGT"),  id="HighQual", description="With very large qualities that even Sanger FASTQ can't hold!",
-                           letter_annotations={"solexa_quality":[0,10,100,1000]})
+                           letter_annotations={"solexa_quality":[0, 10, 100, 1000]})
         #TODO - Record with no identifier?
         records = [record1, record2, record3, record4, record5, record6, record7, record8]
         #TODO - Have a Biopython defined "DataLossWarning?"
@@ -497,7 +500,7 @@ class TestWriteRead(unittest.TestCase):
         #TODO - On Python 2.6+ we can check this warning is really triggered
         warnings.simplefilter('ignore', BiopythonWarning)
         self.check(os.path.join("Quality", "sanger_93.fastq"), "fastq",
-                   ["fastq-solexa","fastq-illumina"])
+                   ["fastq-solexa", "fastq-illumina"])
         warnings.filters.pop()
 
     def test_sanger_faked(self):
@@ -615,7 +618,7 @@ class MappingTests(unittest.TestCase):
         self.assertEqual(6, round(QualityIO.solexa_quality_from_phred(7)))
         self.assertEqual(7, round(QualityIO.solexa_quality_from_phred(8)))
         self.assertEqual(8, round(QualityIO.solexa_quality_from_phred(9)))
-        for i in range(10,100):
+        for i in range(10, 100):
             self.assertEqual(i, round(QualityIO.solexa_quality_from_phred(i)))
 
     def test_phred_quality_from_solexa(self):
@@ -635,7 +638,7 @@ class MappingTests(unittest.TestCase):
         self.assertEqual(8, round(QualityIO.phred_quality_from_solexa(7)))
         self.assertEqual(9, round(QualityIO.phred_quality_from_solexa(8)))
         self.assertEqual(10, round(QualityIO.phred_quality_from_solexa(9)))
-        for i in range(10,100):
+        for i in range(10, 100):
             self.assertEqual(i, round(QualityIO.phred_quality_from_solexa(i)))
 
     def test_sanger_to_solexa(self):
@@ -644,11 +647,11 @@ class MappingTests(unittest.TestCase):
         #solexa_quality_from_phred function directly. For speed it uses a
         #cached dictionary of the mappings.
         seq = "N"*94
-        qual = "".join(chr(33+q) for q in range(0,94))
-        expected_sol = [min(62,int(round(QualityIO.solexa_quality_from_phred(q))))
-                        for q in range(0,94)]
-        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq,qual))
-        out_handle = StringIO("")
+        qual = "".join(chr(33+q) for q in range(0, 94))
+        expected_sol = [min(62, int(round(QualityIO.solexa_quality_from_phred(q))))
+                        for q in range(0, 94)]
+        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq, qual))
+        out_handle = StringIO()
         #Want to ignore the data loss warning
         #(on Python 2.6 we could check for it!)
         warnings.simplefilter('ignore', BiopythonWarning)
@@ -667,11 +670,11 @@ class MappingTests(unittest.TestCase):
         #solexa_quality_from_phred function directly. For speed it uses a
         #cached dictionary of the mappings.
         seq = "N"*68
-        qual = "".join(chr(64+q) for q in range(-5,63))
+        qual = "".join(chr(64+q) for q in range(-5, 63))
         expected_phred = [round(QualityIO.phred_quality_from_solexa(q))
-                          for q in range(-5,63)]
-        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq,qual))
-        out_handle = StringIO("")
+                          for q in range(-5, 63)]
+        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq, qual))
+        out_handle = StringIO()
         #Want to ignore the data loss warning
         #(on Python 2.6 we could check for it!)
         warnings.simplefilter('ignore', BiopythonWarning)
@@ -687,10 +690,10 @@ class MappingTests(unittest.TestCase):
     def test_sanger_to_illumina(self):
         """Mapping check for FASTQ Sanger (0 to 93) to Illumina (0 to 62)"""
         seq = "N"*94
-        qual = "".join(chr(33+q) for q in range(0,94))
-        expected_phred = [min(62,q) for q in range(0,94)]
-        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq,qual))
-        out_handle = StringIO("")
+        qual = "".join(chr(33+q) for q in range(0, 94))
+        expected_phred = [min(62, q) for q in range(0, 94)]
+        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq, qual))
+        out_handle = StringIO()
         #Want to ignore the data loss warning
         #(on Python 2.6 we could check for it!)
         warnings.simplefilter('ignore', BiopythonWarning)
@@ -706,10 +709,10 @@ class MappingTests(unittest.TestCase):
     def test_illumina_to_sanger(self):
         """Mapping check for FASTQ Illumina (0 to 62) to Sanger (0 to 62)"""
         seq = "N"*63
-        qual = "".join(chr(64+q) for q in range(0,63))
-        expected_phred = range(63)
-        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq,qual))
-        out_handle = StringIO("")
+        qual = "".join(chr(64+q) for q in range(0, 63))
+        expected_phred = list(range(63))
+        in_handle = StringIO("@Test\n%s\n+\n%s" % (seq, qual))
+        out_handle = StringIO()
         SeqIO.write(SeqIO.parse(in_handle, "fastq-illumina"),
                     out_handle, "fastq-sanger")
         out_handle.seek(0)
