@@ -15,15 +15,12 @@ except ImportError:
 import sys
 import os
 import unittest
+import tempfile
 import gzip
-from StringIO import StringIO
-try:
-    #This is in Python 2.6+, but we need it on Python 3
-    from io import BytesIO
-except ImportError:
-    BytesIO = StringIO
-from Bio._py3k import _as_bytes, _bytes_to_string
+import warnings
+from io import BytesIO
 
+from Bio._py3k import _as_bytes, _bytes_to_string, StringIO
 
 from Bio.SeqRecord import SeqRecord
 from Bio import SeqIO
@@ -32,6 +29,13 @@ from Bio.Alphabet import generic_protein, generic_nucleotide, generic_dna
 
 from seq_tests_common import compare_record
 
+from Bio import BiopythonParserWarning
+from Bio import MissingPythonDependencyError
+try:
+    from test_bgzf import _have_bug17666
+    do_bgzf = _have_bug17666()
+except MissingPythonDependencyError:
+    do_bgzf = False
 
 def add_prefix(key):
     """Dummy key_function for testing index code."""
@@ -94,6 +98,14 @@ if sqlite3:
 
 class IndexDictTests(unittest.TestCase):
     """Cunning unit test where methods are added at run time."""
+    def setUp(self):
+        h, self.index_tmp = tempfile.mkstemp("_idx.tmp")
+        os.close(h)
+
+    def tearDown(self):
+        if os.path.isfile(self.index_tmp):
+            os.remove(self.index_tmp)
+
     def simple_check(self, filename, format, alphabet, comp):
         """Check indexing (without a key function)."""
         if comp:
@@ -105,7 +117,7 @@ class IndexDictTests(unittest.TestCase):
 
         rec_dict = SeqIO.index(filename, format, alphabet)
         self.check_dict_methods(rec_dict, id_list, id_list)
-        rec_dict._proxy._handle.close()  # TODO - Better solution
+        rec_dict.close()
         del rec_dict
 
         if not sqlite3:
@@ -126,7 +138,7 @@ class IndexDictTests(unittest.TestCase):
                           ":memory:", filenames=["dummy"])
 
         #Saving to file...
-        index_tmp = filename + ".idx"
+        index_tmp = self.index_tmp
         if os.path.isfile(index_tmp):
             os.remove(index_tmp)
 
@@ -168,7 +180,7 @@ class IndexDictTests(unittest.TestCase):
         key_list = [add_prefix(id) for id in id_list]
         rec_dict = SeqIO.index(filename, format, alphabet, add_prefix)
         self.check_dict_methods(rec_dict, key_list, id_list)
-        rec_dict._proxy._handle.close()  # TODO - Better solution
+        rec_dict.close()
         del rec_dict
 
         if not sqlite3:
@@ -223,7 +235,7 @@ class IndexDictTests(unittest.TestCase):
         self.assertEqual(len(keys), len(rec_dict))
         #Make sure boolean evaluation works
         self.assertEqual(bool(keys), bool(rec_dict))
-        for key,id in zip(keys, ids):
+        for key, id in zip(keys, ids):
             self.assertTrue(key in rec_dict)
             self.assertEqual(id, rec_dict[key].id)
             self.assertEqual(id, rec_dict.get(key).id)
@@ -238,21 +250,18 @@ class IndexDictTests(unittest.TestCase):
         self.assertEqual(rec_dict.get(chr(0), chr(1)), chr(1))
         if hasattr(dict, "iteritems"):
             #Python 2.x
-            for key, rec in rec_dict.iteritems():
+            for key, rec in rec_dict.items():
                 self.assertTrue(key in keys)
                 self.assertTrue(isinstance(rec, SeqRecord))
                 self.assertTrue(rec.id in ids)
-            #Now check non-defined methods...
-            self.assertRaises(NotImplementedError, rec_dict.items)
-            self.assertRaises(NotImplementedError, rec_dict.values)
         else:
             #Python 3
             assert not hasattr(rec_dict, "iteritems")
-            for key, rec in rec_dict.iteritems():
+            for key, rec in rec_dict.items():
                 self.assertTrue(key in keys)
                 self.assertTrue(isinstance(rec, SeqRecord))
                 self.assertTrue(rec.id in ids)
-            for rec in rec_dict.itervalues():
+            for rec in rec_dict.values():
                 self.assertTrue(key in keys)
                 self.assertTrue(isinstance(rec, SeqRecord))
                 self.assertTrue(rec.id in ids)
@@ -281,8 +290,16 @@ class IndexDictTests(unittest.TestCase):
             h.close()
             id_list = [rec.id.lower() for rec in
                        SeqIO.parse(filename, format, alphabet)]
-        rec_dict = SeqIO.index(filename, format, alphabet,
-                               key_function = lambda x : x.lower())
+
+        if format in ["sff"]:
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore', BiopythonParserWarning)
+                rec_dict = SeqIO.index(filename, format, alphabet,
+                                       key_function = lambda x : x.lower())
+        else:
+            rec_dict = SeqIO.index(filename, format, alphabet,
+                                   key_function = lambda x : x.lower())
+
         self.assertEqual(set(id_list), set(rec_dict.keys()))
         self.assertEqual(len(id_list), len(rec_dict))
         for key in id_list:
@@ -331,7 +348,7 @@ class IndexDictTests(unittest.TestCase):
             else:
                 rec2 = SeqIO.read(handle, format, alphabet)
             self.assertEqual(True, compare_record(rec1, rec2))
-        rec_dict._proxy._handle.close()  # TODO - Better solution
+        rec_dict.close()
         del rec_dict
 
     if sqlite3:
@@ -356,8 +373,9 @@ tests = [
     ("Ace/consed_sample.ace", "ace", None),
     ("Ace/seq.cap.ace", "ace", generic_dna),
     ("Quality/wrapping_original_sanger.fastq", "fastq", None),
-    ("Quality/example.fastq", "fastq", None),
+    ("Quality/example.fastq", "fastq", None), #Unix newlines
     ("Quality/example.fastq", "fastq-sanger", generic_dna),
+    ("Quality/example_dos.fastq", "fastq", None), #DOS/Windows newlines
     ("Quality/tricky.fastq", "fastq", generic_nucleotide),
     ("Quality/sanger_faked.fastq", "fastq-sanger", generic_dna),
     ("Quality/solexa_faked.fastq", "fastq-solexa", generic_dna),
@@ -406,34 +424,34 @@ tests = [
 for filename, format, alphabet in tests:
     assert format in _FormatToRandomAccess
     tasks = [(filename, None)]
-    if os.path.isfile(filename + ".bgz"):
-        tasks.append((filename + ".bgz","bgzf"))
+    if do_bgzf and os.path.isfile(filename + ".bgz"):
+        tasks.append((filename + ".bgz", "bgzf"))
     for filename, comp in tasks:
 
-        def funct(fn,fmt,alpha,c):
+        def funct(fn, fmt, alpha, c):
             f = lambda x : x.simple_check(fn, fmt, alpha, c)
             f.__doc__ = "Index %s file %s defaults" % (fmt, fn)
             return f
         setattr(IndexDictTests, "test_%s_%s_simple"
-                    % (format, filename.replace("/","_").replace(".","_")),
+                    % (format, filename.replace("/", "_").replace(".", "_")),
                 funct(filename, format, alphabet, comp))
         del funct
 
-        def funct(fn,fmt,alpha,c):
+        def funct(fn, fmt, alpha, c):
             f = lambda x : x.key_check(fn, fmt, alpha, c)
             f.__doc__ = "Index %s file %s with key function" % (fmt, fn)
             return f
         setattr(IndexDictTests, "test_%s_%s_keyf"
-                    % (format, filename.replace("/","_").replace(".","_")),
+                    % (format, filename.replace("/", "_").replace(".", "_")),
                 funct(filename, format, alphabet, comp))
         del funct
 
-        def funct(fn,fmt,alpha,c):
+        def funct(fn, fmt, alpha, c):
             f = lambda x : x.get_raw_check(fn, fmt, alpha, c)
             f.__doc__ = "Index %s file %s get_raw" % (fmt, fn)
             return f
         setattr(IndexDictTests, "test_%s_%s_get_raw"
-                    % (format, filename.replace("/","_").replace(".","_")),
+                    % (format, filename.replace("/", "_").replace(".", "_")),
                 funct(filename, format, alphabet, comp))
         del funct
 
