@@ -4,6 +4,8 @@
 # as part of this package.
 
 """Unittests for the Seq objects."""
+from __future__ import print_function
+
 import unittest
 import sys
 if sys.version_info[0] == 3:
@@ -64,6 +66,7 @@ Chilodonella_uncinata_table = CodonTable(forward_table={
 
 class StringMethodTests(unittest.TestCase):
     _examples = [
+        #These are length 9, a multiple of 3 for translation tests:
         Seq("ACGTGGGGT", generic_protein),
         Seq("ACGTGGGGT", generic_nucleotide),
         Seq("ACGTGGGGT", generic_dna),
@@ -81,12 +84,12 @@ class StringMethodTests(unittest.TestCase):
         UnknownSeq(1, generic_rna),
         UnknownSeq(1, generic_rna, "n"),
         UnknownSeq(1, generic_rna, "N"),
-        UnknownSeq(10, generic_rna, "N"),
-        UnknownSeq(10, generic_dna, "N"),
-        UnknownSeq(10, generic_nucleotide, "N"),
-        UnknownSeq(10, generic_protein, "X"),
-        UnknownSeq(10, character="X"),
-        UnknownSeq(10),
+        UnknownSeq(12, generic_rna, "N"),
+        UnknownSeq(12, generic_dna, "N"),
+        UnknownSeq(12, generic_nucleotide, "N"),
+        UnknownSeq(12, generic_protein, "X"),
+        UnknownSeq(12, character="X"),
+        UnknownSeq(12),
         ]
     for seq in _examples[:]:
         if isinstance(seq, Seq):
@@ -108,8 +111,8 @@ class StringMethodTests(unittest.TestCase):
                     continue
                 str2 = str(example2)
 
-                i = getattr(example1,method_name)(str2)
-                j = getattr(str1,method_name)(str2)
+                i = getattr(example1, method_name)(str2)
+                j = getattr(str1, method_name)(str2)
                 if pre_comp_function:
                     i = pre_comp_function(i)
                     j = pre_comp_function(j)
@@ -122,8 +125,8 @@ class StringMethodTests(unittest.TestCase):
                                         j))
 
                 try:
-                    i = getattr(example1,method_name)(example2)
-                    j = getattr(str1,method_name)(str2)
+                    i = getattr(example1, method_name)(example2)
+                    j = getattr(str1, method_name)(str2)
                     if pre_comp_function:
                         i = pre_comp_function(i)
                         j = pre_comp_function(j)
@@ -140,8 +143,8 @@ class StringMethodTests(unittest.TestCase):
 
                 if start_end:
                     for start in self._start_end_values:
-                        i = getattr(example1,method_name)(str2, start)
-                        j = getattr(str1,method_name)(str2, start)
+                        i = getattr(example1, method_name)(str2, start)
+                        j = getattr(str1, method_name)(str2, start)
                         if pre_comp_function:
                             i = pre_comp_function(i)
                             j = pre_comp_function(j)
@@ -155,8 +158,8 @@ class StringMethodTests(unittest.TestCase):
                                                 j))
 
                         for end in self._start_end_values:
-                            i = getattr(example1,method_name)(str2, start, end)
-                            j = getattr(str1,method_name)(str2, start, end)
+                            i = getattr(example1, method_name)(str2, start, end)
+                            j = getattr(str1, method_name)(str2, start, end)
                             if pre_comp_function:
                                 i = pre_comp_function(i)
                                 j = pre_comp_function(j)
@@ -185,12 +188,7 @@ class StringMethodTests(unittest.TestCase):
     def test_str_startswith(self):
         """Check matches the python string startswith method."""
         self._test_method("startswith", start_end=True)
-
-        try:
-            self.assertTrue("ABCDE".startswith(("ABE","OBE","ABC")))
-        except TypeError:
-            #Base string only supports this on Python 2.5+, skip this
-            return
+        self.assertTrue("ABCDE".startswith(("ABE", "OBE", "ABC")))
 
         #Now check with a tuple of sub sequences
         for example1 in self._examples:
@@ -198,27 +196,22 @@ class StringMethodTests(unittest.TestCase):
                 #e.g. MutableSeq does not support this
                 continue
             subs = tuple([example1[start:start+2] for start
-                          in range(0, len(example1)-2,3)])
+                          in range(0, len(example1)-2, 3)])
             subs_str = tuple([str(s) for s in subs])
 
             self.assertEqual(str(example1).startswith(subs_str),
                              example1.startswith(subs))
             self.assertEqual(str(example1).startswith(subs_str),
                              example1.startswith(subs_str))  # strings!
-            self.assertEqual(str(example1).startswith(subs_str,3),
-                             example1.startswith(subs,3))
-            self.assertEqual(str(example1).startswith(subs_str,2,6),
-                             example1.startswith(subs,2,6))
+            self.assertEqual(str(example1).startswith(subs_str, 3),
+                             example1.startswith(subs, 3))
+            self.assertEqual(str(example1).startswith(subs_str, 2, 6),
+                             example1.startswith(subs, 2, 6))
 
     def test_str_endswith(self):
         """Check matches the python string endswith method."""
         self._test_method("endswith", start_end=True)
-
-        try:
-            self.assertTrue("ABCDE".endswith(("ABE","OBE","CDE")))
-        except TypeError:
-            #Base string only supports this on Python 2.5+, skip this
-            return
+        self.assertTrue("ABCDE".endswith(("ABE", "OBE", "CDE")))
 
         #Now check with a tuple of sub sequences
         for example1 in self._examples:
@@ -226,17 +219,17 @@ class StringMethodTests(unittest.TestCase):
                 #e.g. MutableSeq does not support this
                 continue
             subs = tuple([example1[start:start+2] for start
-                          in range(0, len(example1)-2,3)])
+                          in range(0, len(example1)-2, 3)])
             subs_str = tuple([str(s) for s in subs])
 
             self.assertEqual(str(example1).endswith(subs_str),
                              example1.endswith(subs))
             self.assertEqual(str(example1).startswith(subs_str),
                              example1.startswith(subs_str))  # strings!
-            self.assertEqual(str(example1).endswith(subs_str,3),
-                             example1.endswith(subs,3))
-            self.assertEqual(str(example1).endswith(subs_str,2,6),
-                             example1.endswith(subs,2,6))
+            self.assertEqual(str(example1).endswith(subs_str, 3),
+                             example1.endswith(subs, 3))
+            self.assertEqual(str(example1).endswith(subs_str, 2, 6),
+                             example1.endswith(subs, 2, 6))
 
     def test_str_strip(self):
         """Check matches the python string strip method."""
@@ -250,19 +243,22 @@ class StringMethodTests(unittest.TestCase):
         """Check matches the python string rstrip method."""
         #Calling (r)split should return a list of Seq-like objects, we'll
         #just apply str() to each of them so it matches the string method
-        self._test_method("rstrip", pre_comp_function=lambda x : map(str,x))
+        self._test_method("rstrip",
+                          pre_comp_function=lambda x: [str(y) for y in x])
 
     def test_str_rsplit(self):
         """Check matches the python string rstrip method."""
         #Calling (r)split should return a list of Seq-like objects, we'll
         #just apply str() to each of them so it matches the string method
-        self._test_method("rstrip", pre_comp_function=lambda x : map(str,x))
+        self._test_method("rstrip",
+                          pre_comp_function=lambda x: [str(y) for y in x])
 
     def test_str_lsplit(self):
         """Check matches the python string rstrip method."""
         #Calling (r)split should return a list of Seq-like objects, we'll
         #just apply str() to each of them so it matches the string method
-        self._test_method("rstrip", pre_comp_function=lambda x : map(str,x))
+        self._test_method("rstrip",
+                          pre_comp_function=lambda x: [str(y) for y in x])
 
     def test_str_length(self):
         """Check matches the python string __len__ method."""
@@ -278,7 +274,7 @@ class StringMethodTests(unittest.TestCase):
             str1 = str(example1)
             self.assertEqual(str(example1.upper()), str1.upper())
 
-    def test_str_upper(self):
+    def test_str_lower(self):
         """Check matches the python string lower method."""
         for example1 in self._examples:
             if isinstance(example1, MutableSeq):
@@ -297,10 +293,10 @@ class StringMethodTests(unittest.TestCase):
                 self.assertEqual(str(example1[i:]), str1[i:])
                 for j in self._start_end_values:
                     self.assertEqual(str(example1[i:j]), str1[i:j])
-                    for step in range(-3,4):
+                    for step in range(-3, 4):
                         if step == 0:
                             try:
-                                print example1[i:j:step]
+                                print(example1[i:j:step])
                                 self._assert(False)  # Should fail!
                             except ValueError:
                                 pass
@@ -344,20 +340,20 @@ class StringMethodTests(unittest.TestCase):
                 continue
             try :
                 comp = example1.complement()
-            except ValueError, e:
+            except ValueError as e:
                 self.assertEqual(str(e), "Proteins do not have complements!")
                 continue
             str1 = str(example1)
             #This only does the unambiguous cases
             if "U" in str1 or "u" in str1 \
             or example1.alphabet==generic_rna:
-                mapping = maketrans("ACGUacgu","UGCAugca")
+                mapping = maketrans("ACGUacgu", "UGCAugca")
             elif "T" in str1 or "t" in str1 \
             or example1.alphabet==generic_dna \
             or example1.alphabet==generic_nucleotide:
-                mapping = maketrans("ACGTacgt","TGCAtgca")
+                mapping = maketrans("ACGTacgt", "TGCAtgca")
             elif "A" not in str1 and "a" not in str1:
-                mapping = maketrans("CGcg","GCgc")
+                mapping = maketrans("CGcg", "GCgc")
             else :
                 #TODO - look at alphabet?
                 raise ValueError(example1)
@@ -372,20 +368,20 @@ class StringMethodTests(unittest.TestCase):
                 continue
             try :
                 comp = example1.reverse_complement()
-            except ValueError, e:
+            except ValueError as e:
                 self.assertEqual(str(e), "Proteins do not have complements!")
                 continue
             str1 = str(example1)
             #This only does the unambiguous cases
             if "U" in str1 or "u" in str1 \
             or example1.alphabet==generic_rna:
-                mapping = maketrans("ACGUacgu","UGCAugca")
+                mapping = maketrans("ACGUacgu", "UGCAugca")
             elif "T" in str1 or "t" in str1 \
             or example1.alphabet==generic_dna \
             or example1.alphabet==generic_nucleotide:
-                mapping = maketrans("ACGTacgt","TGCAtgca")
+                mapping = maketrans("ACGTacgt", "TGCAtgca")
             elif "A" not in str1 and "a" not in str1:
-                mapping = maketrans("CGcg","GCgc")
+                mapping = maketrans("CGcg", "GCgc")
             else :
                 #TODO - look at alphabet?
                 continue
@@ -400,14 +396,17 @@ class StringMethodTests(unittest.TestCase):
                     continue
                 try :
                     tran = example1.transcribe()
-                except ValueError, e:
+                except ValueError as e:
                     if str(e) == "Proteins cannot be transcribed!":
                         continue
                     if str(e) == "RNA cannot be transcribed!":
                         continue
                     raise e
                 str1 = str(example1)
-                self.assertEqual(str1.replace("T","U").replace("t","u"), str(tran))
+                if len(str1) % 3 != 0:
+                    #TODO - Check for or silence the expected warning?
+                    continue
+                self.assertEqual(str1.replace("T", "U").replace("t", "u"), str(tran))
                 self.assertEqual(tran.alphabet, generic_rna)  # based on limited examples
 
     def test_the_back_transcription(self):
@@ -418,14 +417,14 @@ class StringMethodTests(unittest.TestCase):
                     continue
                 try :
                     tran = example1.back_transcribe()
-                except ValueError, e:
+                except ValueError as e:
                     if str(e) == "Proteins cannot be back transcribed!":
                         continue
                     if str(e) == "DNA cannot be back transcribed!":
                         continue
                     raise e
                 str1 = str(example1)
-                self.assertEqual(str1.replace("U","T").replace("u","t"), str(tran))
+                self.assertEqual(str1.replace("U", "T").replace("u", "t"), str(tran))
                 self.assertEqual(tran.alphabet, generic_dna)  # based on limited examples
 
     def test_the_translate(self):
@@ -434,15 +433,18 @@ class StringMethodTests(unittest.TestCase):
             for example1 in self._examples:
                 if isinstance(example1, MutableSeq):
                     continue
+                if len(example1) % 3 != 0:
+                    #TODO - Check for or silence the expected warning?
+                    continue
                 try :
                     tran = example1.translate()
-                except ValueError, e:
+                except ValueError as e:
                     if str(e) == "Proteins cannot be translated!":
                         continue
                     raise e
                 #This is based on the limited example not having stop codons:
                 if tran.alphabet not in [extended_protein, protein, generic_protein]:
-                    print tran.alphabet
+                    print(tran.alphabet)
                     self.assertTrue(False)
                 #TODO - check the actual translation, and all the optional args
 
@@ -496,7 +498,7 @@ class StringMethodTests(unittest.TestCase):
                         Seq(codon, generic_dna),
                         Seq(codon, unambiguous_dna)]:
                 try :
-                    print nuc.translate()
+                    print(nuc.translate())
                     self.assertTrue(False, "Transating %s should fail" % codon)
                 except TranslationError :
                     pass
