@@ -18,8 +18,8 @@ if sys.platform=="win32":
     raise MissingExternalDependencyError(
         "Testing TCOFFEE on Windows not supported yet")
 else:
-    import commands
-    output = commands.getoutput("t_coffee -version")
+    from Bio._py3k import getoutput
+    output = getoutput("t_coffee -version")
     if "not found" not in output \
     and ("t_coffee" in output.lower() or "t-coffee" in output.lower()):
         t_coffee_exe = "t_coffee"
@@ -55,12 +55,12 @@ class TCoffeeApplication(unittest.TestCase):
         self.assertEqual(str(cmdline), t_coffee_exe + " -infile Fasta/fa01")
         stdout, stderr = cmdline()
         self.assertTrue(stderr.strip().startswith("PROGRAM: T-COFFEE"))
-        align = AlignIO.read(open(self.outfile1), "clustal")
-        records = list(SeqIO.parse(open(self.infile1),"fasta"))
-        self.assertEqual(len(records),len(align))
+        align = AlignIO.read(self.outfile1, "clustal")
+        records = list(SeqIO.parse(self.infile1, "fasta"))
+        self.assertEqual(len(records), len(align))
         for old, new in zip(records, align):
             self.assertEqual(old.id, new.id)
-            self.assertEqual(str(new.seq).replace("-",""), str(old.seq).replace("-",""))
+            self.assertEqual(str(new.seq).replace("-", ""), str(old.seq).replace("-", ""))
 
     def test_TCoffee_2(self):
         """Round-trip through app and read pir alignment from file
@@ -74,12 +74,12 @@ class TCoffeeApplication(unittest.TestCase):
         stdout, stderr = cmdline()
         #Can get warnings in stderr output
         self.assertTrue("error" not in stderr.lower(), stderr)
-        align = AlignIO.read(open(self.outfile3), "pir")
-        records = list(SeqIO.parse(open(self.infile1),"fasta"))
-        self.assertEqual(len(records),len(align))
+        align = AlignIO.read(self.outfile3, "pir")
+        records = list(SeqIO.parse(self.infile1, "fasta"))
+        self.assertEqual(len(records), len(align))
         for old, new in zip(records, align):
             self.assertEqual(old.id, new.id)
-            self.assertEqual(str(new.seq).replace("-",""), str(old.seq).replace("-",""))
+            self.assertEqual(str(new.seq).replace("-", ""), str(old.seq).replace("-", ""))
 
     def test_TCoffee_3(self):
         """Round-trip through app and read clustalw alignment from file
@@ -96,12 +96,12 @@ class TCoffeeApplication(unittest.TestCase):
                          "-type protein -outorder input -gapopen -2 -gapext -5")
         stdout, stderr = cmdline()
         self.assertTrue(stderr.strip().startswith("PROGRAM: T-COFFEE"))
-        align = AlignIO.read(open(self.outfile4), "clustal")
-        records = list(SeqIO.parse(open(self.infile1),"fasta"))
-        self.assertEqual(len(records),len(align))
+        align = AlignIO.read(self.outfile4, "clustal")
+        records = list(SeqIO.parse(self.infile1, "fasta"))
+        self.assertEqual(len(records), len(align))
         for old, new in zip(records, align):
             self.assertEqual(old.id, new.id)
-            self.assertEqual(str(new.seq).replace("-",""), str(old.seq).replace("-",""))
+            self.assertEqual(str(new.seq).replace("-", ""), str(old.seq).replace("-", ""))
 
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity = 2)
