@@ -1,12 +1,15 @@
-# Copyright 2010-2011 by Peter Cock.  All rights reserved.
+# Copyright 2010-2013 by Peter Cock.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
 """Testing Bio.TogoWS online code.
 """
+
+from __future__ import print_function
+
 import unittest
-from StringIO import StringIO
+from Bio._py3k import StringIO
 
 import requires_internet
 requires_internet.check()
@@ -31,65 +34,67 @@ class TogoFields(unittest.TestCase):
     def test_databases(self):
         """Check supported databases"""
         dbs = set(TogoWS._get_entry_dbs())
-        self.assert_(dbs.issuperset(['nuccore', 'nucest', 'nucgss',
-                                     'nucleotide', 'protein', 'gene',
-                                     'omim', 'homologene', 'snp',
-                                     'mesh', 'pubmed', 'embl',
-                                     'uniprot', 'uniparc', 'uniref100',
-                                     'uniref90', 'uniref50', 'ddbj',
-                                     'dad', 'pdb', 'compound', 'drug',
-                                     'enzyme', 'genes', 'glycan',
-                                     'orthology', 'reaction', 'module',
-                                     'pathway']), dbs)
+        expected = set(['nuccore', 'nucest', 'nucgss',
+                        'nucleotide', 'protein', 'gene',
+                        'homologene', 'snp',
+                        'mesh', 'pubmed', 'embl',
+                        'uniprot', 'uniparc', 'uniref100',
+                        'uniref90', 'uniref50', 'ddbj',
+                        'dad', 'pdb', 'compound', 'drug',
+                        'enzyme', 'genes', 'glycan',
+                        'orthology', 'reaction', 'module',
+                        'pathway'])
+        self.assertTrue(dbs.issuperset(expected),
+                        "Missing DB: %s" % ", ".join(sorted(expected.difference(dbs))))
 
     def test_pubmed(self):
         """Check supported fields for pubmed database"""
         fields = set(TogoWS._get_entry_fields("pubmed"))
-        self.assert_(fields.issuperset(['abstract', 'au', 'authors',
-                                        'doi', 'mesh', 'so', 'ti',
-                                        'title']), fields)
+        self.assertTrue(fields.issuperset(['abstract', 'au', 'authors',
+                                           'doi', 'mesh', 'so',
+                                           'title']), fields)
 
     def test_ncbi_protein(self):
         """Check supported fields for NCBI protein database"""
         fields = set(TogoWS._get_entry_fields("ncbi-protein"))
-        self.assert_(fields.issuperset(['entry_id', 'length', 'strand',
-                                        'moltype', 'linearity', 'division',
-                                        'date', 'definition', 'accession',
-                                        'accessions', 'version', 'versions',
-                                        'acc_version', 'gi', 'keywords',
-                                        'organism', 'common_name',
-                                        'taxonomy', 'comment', 'seq']),
-                                        fields)
+        self.assertTrue(fields.issuperset(['entry_id', 'length', 'strand',
+                                           'moltype', 'linearity', 'division',
+                                           'date', 'definition', 'accession',
+                                           'accessions', 'version', 'versions',
+                                           'acc_version', 'gi', 'keywords',
+                                           'organism', 'common_name',
+                                           'taxonomy', 'comment', 'seq']),
+                                           fields)
 
     def test_ddbj(self):
         """Check supported fields for ddbj database"""
         fields = set(TogoWS._get_entry_fields("ddbj"))
-        self.assert_(fields.issuperset(['entry_id', 'length', 'strand',
-                                        'moltype', 'linearity', 'division',
-                                        'date', 'definition', 'accession',
-                                        'accessions', 'version', 'versions',
-                                        'acc_version', 'gi', 'keywords',
-                                        'organism', 'common_name',
-                                        'taxonomy', 'comment', 'seq']),
-                                        fields)
+        self.assertTrue(fields.issuperset(['entry_id', 'length', 'strand',
+                                           'moltype', 'linearity', 'division',
+                                           'date', 'definition', 'accession',
+                                           'accessions', 'version', 'versions',
+                                           'acc_version', 'gi', 'keywords',
+                                           'organism', 'common_name',
+                                           'taxonomy', 'comment', 'seq']),
+                                           fields)
 
     def test_embl(self):
         """Check supported fields for embl database"""
         fields = set(TogoWS._get_entry_fields("embl"))
-        self.assert_(fields.issuperset(["definition", "entry_id", "seq"]),
-                     fields)
+        self.assertTrue(fields.issuperset(["definition", "entry_id", "seq"]),
+                        fields)
 
     def test_uniprot(self):
         """Check supported fields for uniprot database"""
         fields = set(TogoWS._get_entry_fields("uniprot"))
-        self.assert_(fields.issuperset(["definition", "entry_id", "seq"]),
-                     fields)
+        self.assertTrue(fields.issuperset(["definition", "entry_id", "seq"]),
+                        fields)
 
     def test_pdb(self):
         """Check supported fields for pdb database"""
         fields = set(TogoWS._get_entry_fields("pdb"))
-        self.assert_(fields.issuperset(["accession", "chains", "keywords",
-                                        "models"]), fields)
+        self.assertTrue(fields.issuperset(["accession", "chains", "keywords",
+                                           "models"]), fields)
 
 
 class TogoEntry(unittest.TestCase):
@@ -107,8 +112,8 @@ class TogoEntry(unittest.TestCase):
                                       'Hirakawa M'])
 
     def test_pubmed_16381885_ti(self):
-        """Bio.TogoWS.entry("pubmed", "16381885", field="ti")"""
-        handle = TogoWS.entry("pubmed", "16381885", field="ti")
+        """Bio.TogoWS.entry("pubmed", "16381885", field="title")"""
+        handle = TogoWS.entry("pubmed", "16381885", field="title")
         data = handle.read().strip()
         handle.close()
         self.assertEqual(data,
@@ -285,7 +290,7 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("ddbj", "X52960", format="gff")
         data = handle.read()
         handle.close()
-        self.assert_(data.startswith("##gff-version 3\nX52960\tDDBJ\t"), data)
+        self.assertTrue(data.startswith("##gff-version 3\nX52960\tDDBJ\t"), data)
 
     def test_genbank_gff3(self):
         """Bio.TogoWS.entry("nucleotide", "X52960", format="gff")"""
@@ -293,14 +298,14 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("nucleotide", "X52960", format="gff")
         data = handle.read()
         handle.close()
-        self.assert_(data.startswith("##gff-version 3\nX52960\tGenbank\t"), data)
+        self.assertTrue(data.startswith("##gff-version 3\nX52960\tGenbank\t"), data)
 
     def test_embl_AM905444_gff3(self):
         """Bio.TogoWS.entry("embl", "AM905444", format="gff")"""
         handle = TogoWS.entry("embl", "AM905444", format="gff")
         data = handle.read()
         handle.close()
-        self.assert_(data.startswith("##gff-version 3\nAM905444\tembl\t"), data)
+        self.assertTrue(data.startswith("##gff-version 3\nAM905444\tembl\t"), data)
 
     def test_embl_AM905444_seq(self):
         """Bio.TogoWS.entry("embl", "AM905444", field="seq")"""
@@ -321,9 +326,9 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("embl", "AM905444")
         record = SeqIO.read(handle, "embl")
         handle.close()
-        self.assert_("AM905444" in record.id, record.id)
-        self.assert_("AM905444" in record.name, record.name)
-        self.assert_("porin" in record.description, record.description)
+        self.assertTrue("AM905444" in record.id, record.id)
+        self.assertTrue("AM905444" in record.name, record.name)
+        self.assertTrue("porin" in record.description, record.description)
         self.assertEqual(len(record), 1164)
         self.assertEqual(seguid(record.seq), "G0HtLpwF7i4FXUaUjDUPTjok79c")
 
@@ -332,15 +337,15 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("ddbj", "X52960", "fasta")
         record = SeqIO.read(handle, "fasta")
         handle.close()
-        self.assert_("X52960" in record.id, record.id)
-        self.assert_("X52960" in record.name, record.name)
+        self.assertTrue("X52960" in record.id, record.id)
+        self.assertTrue("X52960" in record.name, record.name)
         self.assertEqual(len(record), 248)
         self.assertEqual(seguid(record.seq), "Ktxz0HgMlhQmrKTuZpOxPZJ6zGU")
 
     def test_uniprot_swiss(self):
         """Bio.TogoWS.entry("uniprot", ["A1AG1_HUMAN","A1AG1_MOUSE"])"""
         #Returns "swiss" format:
-        handle = TogoWS.entry("uniprot", ["A1AG1_HUMAN","A1AG1_MOUSE"])
+        handle = TogoWS.entry("uniprot", ["A1AG1_HUMAN", "A1AG1_MOUSE"])
         record1, record2 = SeqIO.parse(handle, "swiss")
         handle.close()
 
@@ -359,8 +364,8 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("nucleotide", "6273291", "fasta")
         record = SeqIO.read(handle, "fasta")
         handle.close()
-        self.assert_("6273291" in record.id, record.id)
-        self.assert_("6273291" in record.name, record.name)
+        self.assertTrue("6273291" in record.id, record.id)
+        self.assertTrue("6273291" in record.name, record.name)
         self.assertEqual(len(record), 902)
         self.assertEqual(seguid(record.seq), "bLhlq4mEFJOoS9PieOx4nhGnjAQ")
 
@@ -370,9 +375,9 @@ class TogoEntry(unittest.TestCase):
         record = SeqIO.read(handle, "fasta")
         handle.close()
         #Could use assertIn but requires Python 2.7+
-        self.assert_("16130152" in record.id, record.id)
-        self.assert_("16130152" in record.name, record.name)
-        self.assert_("porin protein" in record.description, record.description)
+        self.assertTrue("16130152" in record.id, record.id)
+        self.assertTrue("16130152" in record.name, record.name)
+        self.assertTrue("porin protein" in record.description, record.description)
         self.assertEqual(len(record), 367)
         self.assertEqual(seguid(record.seq), "fCjcjMFeGIrilHAn6h+yju267lg")
 
@@ -460,7 +465,7 @@ class TogoSearch(unittest.TestCase):
             raise ValueError("Only %i matches, expected at least %i"
                              % (search_count, len(expected_matches)))
         if search_count > 5000 and not limit:
-            print "%i results, skipping" % search_count
+            print("%i results, skipping" % search_count)
             return
         if limit:
             count = min(search_count, limit)
@@ -471,8 +476,8 @@ class TogoSearch(unittest.TestCase):
         search_iter = list(TogoWS.search_iter(database, search_term, limit))
         self.assertEqual(count, len(search_iter))
         for match in expected_matches:
-            self.assert_(match in search_iter,
-                         "Expected %s in results but not" % match)
+            self.assertTrue(match in search_iter,
+                            "Expected %s in results but not" % match)
 
 
 class TogoConvert(unittest.TestCase):
@@ -491,14 +496,16 @@ class TogoConvert(unittest.TestCase):
         """Conversion of GenBank to FASTA."""
         filename = "GenBank/NC_005816.gb"
         old = SeqIO.read(filename, "gb")
-        new = SeqIO.read(TogoWS.convert(open(filename), "genbank", "fasta"), "fasta")
+        with open(filename) as handle:
+            new = SeqIO.read(TogoWS.convert(handle, "genbank", "fasta"), "fasta")
         self.assertEqual(str(old.seq), str(new.seq))
 
     def test_genbank_to_embl(self):
         """Conversion of GenBank to EMBL."""
         filename = "GenBank/NC_005816.gb"
         old = SeqIO.read(filename, "gb")
-        new = SeqIO.read(TogoWS.convert(open(filename), "genbank", "embl"), "embl")
+        with open(filename) as handle:
+            new = SeqIO.read(TogoWS.convert(handle, "genbank", "embl"), "embl")
         self.assertEqual(str(old.seq), str(new.seq))
 
 if __name__ == "__main__":
