@@ -1,4 +1,9 @@
 #!/usr/bin/env python
+# Copyright 2010 by Andrea Pierleoni
+# Revisions copyright 2010-2013 by Peter Cock.  All rights reserved.
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
 """Test for the Uniprot parser on Uniprot XML files.
 """
 import os
@@ -26,9 +31,8 @@ class TestUniprot(unittest.TestCase):
 
         datafile = os.path.join('SwissProt', filename)
 
-        test_handle = open(datafile)
-        seq_record = SeqIO.read(test_handle, "uniprot-xml")
-        test_handle.close()
+        with open(datafile) as test_handle:
+            seq_record = SeqIO.read(test_handle, "uniprot-xml")
 
         self.assertTrue(isinstance(seq_record, SeqRecord))
 
@@ -311,7 +315,8 @@ class TestUniprot(unittest.TestCase):
         txt_list = list(SeqIO.parse("SwissProt/multi_ex.txt", "swiss"))
         xml_list = list(SeqIO.parse("SwissProt/multi_ex.xml", "uniprot-xml"))
         fas_list = list(SeqIO.parse("SwissProt/multi_ex.fasta", "fasta"))
-        ids = [x.strip() for x in open("SwissProt/multi_ex.list")]
+        with open("SwissProt/multi_ex.list") as handle:
+            ids = [x.strip() for x in handle]
         self.assertEqual(len(txt_list), len(ids))
         self.assertEqual(len(txt_list), len(fas_list))
         self.assertEqual(len(txt_list), len(xml_list))
@@ -325,7 +330,8 @@ class TestUniprot(unittest.TestCase):
         """Index SwissProt text and uniprot XML versions of several examples."""
         txt_list = list(SeqIO.parse("SwissProt/multi_ex.txt", "swiss"))
         xml_list = list(SeqIO.parse("SwissProt/multi_ex.xml", "uniprot-xml"))
-        ids = [x.strip() for x in open("SwissProt/multi_ex.list")]
+        with open("SwissProt/multi_ex.list") as handle:
+            ids = [x.strip() for x in handle]
         txt_index = SeqIO.index("SwissProt/multi_ex.txt", "swiss")
         xml_index = SeqIO.index("SwissProt/multi_ex.xml", "uniprot-xml")
         self.assertEqual(sorted(txt_index), sorted(ids))
@@ -338,6 +344,8 @@ class TestUniprot(unittest.TestCase):
         for old in xml_list:
             new = xml_index[old.id]
             compare_record(old, new)
+        txt_index.close()
+        xml_index.close()
 
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity = 2)
