@@ -1,11 +1,19 @@
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+#
+
 """Tests the basic functionality of the GEO parsers.
 """
 
-import os, sys
+from __future__ import print_function
+
+import os
+import sys
 
 import Bio.Geo
 
-testfiles   = [  'GSE16.txt', 'GSM645.txt', 'GSM691.txt', 'GSM700.txt', 'GSM804.txt'  ]
+testfiles = ['GSE16.txt', 'GSM645.txt', 'GSM691.txt', 'GSM700.txt', 'GSM804.txt']
 
 #Five additional files from the NCBI to document the GEO SOFT file format
 #changes made in 2005.  Note the new table_begin and table_end lines.
@@ -23,13 +31,9 @@ for file in testfiles:
         fh = open(os.path.join("Geo", file), encoding="latin")
     else:
         fh = open(os.path.join("Geo", file))
-    print "Testing Bio.Geo on " + file + "\n\n"
+    print("Testing Bio.Geo on " + file + "\n\n")
     records = Bio.Geo.parse(fh)
     for record in records:
-        print record
-    print "\n"
-
-
-
-
-
+        print(record)
+    print("\n")
+    fh.close()
