@@ -842,7 +842,7 @@ class TestProdocParse(unittest.TestCase):
         records = Prodoc.parse(handle)
 
         # Testing the first parsed record
-        record = records.next()
+        record = next(records)
         self.assertEqual(record.accession, "PDOC00000")
         self.assertEqual(len(record.prosite_refs), 0)
         self.assertEqual(record.text, """\
@@ -904,7 +904,7 @@ Acknowledgements:
 """)
 
         # Testing the second parsed record"
-        record = records.next()
+        record = next(records)
         self.assertEqual(record.accession, "PDOC00001")
         self.assertEqual(len(record.prosite_refs), 1)
         self.assertEqual(record.prosite_refs[0], ("PS00001", "ASN_GLYCOSYLATION"))
@@ -968,7 +968,7 @@ J. Biol. Chem. 265:11397-11404(1990).
 PubMed=1694179""")
 
         # Testing the third parsed record"
-        record = records.next()
+        record = next(records)
         self.assertEqual(record.accession, "PDOC00004")
         self.assertEqual(len(record.prosite_refs), 1)
         self.assertEqual(record.prosite_refs[0], ("PS00004", "CAMP_PHOSPHO_SITE"))
@@ -1010,7 +1010,7 @@ J. Biol. Chem. 261:2987-2993(1986).
 PubMed=3005275""")
 
         # Testing the fourth parsed record"
-        record = records.next()
+        record = next(records)
         self.assertEqual(record.accession, "PDOC60030")
         self.assertEqual(len(record.prosite_refs), 1)
         self.assertEqual(record.prosite_refs[0], ("PS60030", "BACTERIOCIN_IIA"))
