@@ -1,6 +1,8 @@
 # Make sure the translation functions work.
 # Start simple - unambiguous DNA to unambiguous protein
 
+from __future__ import print_function
+
 from Bio import Seq
 from Bio import Alphabet
 from Bio.Alphabet import IUPAC
@@ -26,17 +28,17 @@ assert str(dna)=='GAAAATTCATTTTCTTTGGACTTTCTCTGAAATCCGAGTCCTAGGAAAGATGCGTGAGATTC
 # use the standard table
 
 # Do some simple tests first
-s = "T"
+s = ""
 dna = Seq.Seq(s, IUPAC.unambiguous_dna)
 protein = dna.translate(to_stop=True)
 assert  str(protein)==""
 
-s = "TC"
+s = "TAA"
 dna = Seq.Seq(s, IUPAC.unambiguous_dna)
 protein = dna.translate(to_stop=True)
 assert str(protein)==""
 
-s = "GAAAATTCATTTTCTTTGGACTTTCTCTGAAATCCGAGTCCTAGGAAAGATGCGTGAGATTCTTCATATT"
+s = "GAAAATTCATTTTCTTTGGACTTTCTCTGAAATCCGAGTCCTAGGAAAGATGCGTGAGATTCTTCA"
 dna = Seq.Seq(s, IUPAC.unambiguous_dna)
 protein = dna.translate(to_stop=True)
 assert str(protein)=='ENSFSLDFL'
@@ -51,7 +53,7 @@ dna = Seq.Seq(s, IUPAC.unambiguous_dna)
 protein = dna.translate('Vertebrate Mitochondrial', to_stop=True)
 assert str(protein)=="M"
 
-s = "GAAAATTCATTTTCTTTGGACTTTCTCTGAAATCCGAGTCCTAGGAAAGATGCGTGAGATTCTTCATATT"
+s = "GAAAATTCATTTTCTTTGGACTTTCTCTGAAATCCGAGTCCTAGGAAAGATGCGTGAGATTCTTCATAT"
 dna = Seq.Seq(s, IUPAC.unambiguous_dna)
 protein = dna.translate('SGC8', to_stop=True)
 assert str(protein)=='ENSFSLDFLWNPSPSNDAWDSSY'
@@ -59,59 +61,57 @@ assert str(protein)=='ENSFSLDFLWNPSPSNDAWDSSY'
 # use the standard table
 
 s = "TCAAAAAGGTGCATCTAGATG"
-print "Starting with", s
+print("Starting with %s" % s)
 dna = Seq.Seq(s, IUPAC.unambiguous_dna)
 protein = dna.translate(to_stop=True)
 assert isinstance(protein.alphabet, IUPAC.IUPACProtein)
 
-print len(protein), "ungapped residues translated"
+print("%i ungapped residues translated" % len(protein))
 
 gapped_protein = dna.translate()
 assert isinstance(gapped_protein.alphabet, Alphabet.HasStopCodon)
-print str(protein)
+print(str(protein))
 
-print len(gapped_protein), "residues translated, including gaps"
-print str(gapped_protein)
+print("%i residues translated, including gaps" % len(gapped_protein))
+print(str(gapped_protein))
 
 # This has "AGG" as a stop codon
 p2 = dna.translate(table=2, to_stop=True)
-print len(p2), "SGC1 has a stop codon"
-print str(p2)
+print("%i SGC1 has a stop codon" % len(p2))
+print(str(p2))
 p2 = dna.translate(table=2)
-print "Actually, there are", p2.count("*"), "stops."
-print str(p2)
+print("Actually, there are %i stops." % p2.count("*"))
+print(str(p2))
 
 # Make sure I can change the stop character
 p2 = dna.translate(table=2, stop_symbol="+")
-print "Yep,", p2.count("+"), "stops."
-print str(p2)
+print("Yep, %i stops." % p2.count("+"))
+print(str(p2))
 
 
 # Some of the same things, with RNA
 # (The code is the same, so I'm not doing all of the tests.)
 rna = Seq.Seq(s.replace("T", "U"), IUPAC.unambiguous_rna)
 
-print "RNA translation ...",
 protein_from_rna = rna.translate(to_stop=True)
 assert protein.alphabet is protein_from_rna.alphabet
 assert str(protein) == str(protein_from_rna)
-print "works."
+print("RNA translation ... works.")
 
-print "RNA translation to stop ...",
 gapped_protein_from_rna = rna.translate()
 assert len(gapped_protein) == len(gapped_protein_from_rna)
 assert str(gapped_protein) == str(gapped_protein_from_rna)
-print "works."
+print("RNA translation to stop ... works.")
 
 # some tests for "by name"
 # How about some forward ambiguity?
-print "Forward ambiguous"
+print("Forward ambiguous")
 s = "RATGATTARAATYTA"
 #     B  D  *  N  L
 dna = Seq.Seq(s, IUPAC.ambiguous_dna)
 protein = dna.translate('Vertebrate Mitochondrial')
-print str(protein)
+print(str(protein))
 stop_protein = dna.translate('SGC1', to_stop=True)
-print str(stop_protein)
+print(str(stop_protein))
 
 # XXX (Backwards with ambiguity code is unfinished!)
